@@ -181,7 +181,7 @@ static GB_TYPE conv_type(const MYSQL_FIELD *f)
 	switch(f->type)
 	{
 		case FIELD_TYPE_TINY:
-			return (f->max_length == 1 && f->length == 1) ? GB_T_BOOLEAN : GB_T_INTEGER;
+			return (f->max_length <= 1 && f->length == 1) ? GB_T_BOOLEAN : GB_T_INTEGER;
 
 		case FIELD_TYPE_INT24:
 		case FIELD_TYPE_SHORT:
