@@ -167,7 +167,7 @@ static GB_TYPE conv_type(const MYSQL_FIELD *f)
 	switch(f->type)
 	{
 		case FIELD_TYPE_TINY:
-			return (f->max_length == 1 && f->length == 1) ? GB_T_BOOLEAN : GB_T_INTEGER;
+			return (f->max_length <= 1 && f->length == 1) ? GB_T_BOOLEAN : GB_T_INTEGER;
 
 		case FIELD_TYPE_INT24:
 		case FIELD_TYPE_SHORT:
@@ -581,7 +581,7 @@ BEGIN_METHOD(MySqlHelper_GetResultField, GB_POINTER result; GB_INTEGER field)
 	_type = conv_type(f);
 	_length = _type == GB_T_STRING ? f->max_length : 0;
 	
-	if (add_table && f->table)
+	if (add_table && f->table && *f->table)
 	{
 		name = GB.NewZeroString(f->table);
 		name = GB.AddChar(name, '.');
