@@ -21,18 +21,18 @@
 #include "el_div.h"
 #include "el_font.h"
 #include "el_tr.h"
-#include "el_li.h"
 #include <cmath>
 #include <cstdio>
 #include <algorithm>
-#include <functional>
 #include "gumbo.h"
 #include "utf8_strings.h"
+#include "render_item.h"
+#include "render_table.h"
+#include "render_block.h"
 
-litehtml::document::document(litehtml::document_container* objContainer, litehtml::context* ctx)
+litehtml::document::document(document_container* objContainer)
 {
 	m_container	= objContainer;
-	m_context	= ctx;
 }
 
 litehtml::document::~document()
@@ -40,28 +40,23 @@ litehtml::document::~document()
 	m_over_element = nullptr;
 	if(m_container)
 	{
-		for(auto & m_font : m_fonts)
+		for(auto& font : m_fonts)
 		{
-			m_container->delete_font(m_font.second.font);
+			m_container->delete_font(font.second.font);
 		}
 	}
 }
 
-litehtml::document::ptr litehtml::document::createFromString( const tchar_t* str, litehtml::document_container* objPainter, litehtml::context* ctx, litehtml::css* user_styles)
-{
-	return createFromUTF8(litehtml_to_utf8(str), objPainter, ctx, user_styles);
-}
-
-litehtml::document::ptr litehtml::document::createFromUTF8(const char* str, litehtml::document_container* objPainter, litehtml::context* ctx, litehtml::css* user_styles)
+litehtml::document::ptr litehtml::document::createFromString( const char* str, document_container* objPainter, const char* master_styles, const char* user_styles )
 {
 	// parse document into GumboOutput
-	GumboOutput* output = gumbo_parse((const char*) str);
+	GumboOutput* output = gumbo_parse(str);
 
 	// Create litehtml::document
-	litehtml::document::ptr doc = std::make_shared<litehtml::document>(objPainter, ctx);
+	document::ptr doc = std::make_shared<document>(objPainter);
 
 	// Create litehtml::elements.
-	elements_vector root_elements;
+	elements_list root_elements;
 	doc->create_node(output->root, root_elements, true);
 	if (!root_elements.empty())
 	{
@@ -70,15 +65,26 @@ litehtml::document::ptr litehtml::document::createFromUTF8(const char* str, lite
 	// Destroy GumboOutput
 	gumbo_destroy_output(&kGumboDefaultOptions, output);
 
+	if (master_styles && *master_styles)
+	{
+		doc->m_master_css.parse_stylesheet(master_styles, nullptr, doc, nullptr);
+		doc->m_master_css.sort_selectors();
+	}
+	if (user_styles && *user_styles)
+	{
+		doc->m_user_css.parse_stylesheet(user_styles, nullptr, doc, nullptr);
+		doc->m_user_css.sort_selectors();
+	}
+
 	// Let's process created elements tree
 	if (doc->m_root)
 	{
 		doc->container()->get_media_features(doc->m_media);
 
-		doc->m_root->set_pseudo_class(_t("root"), true);
+		doc->m_root->set_pseudo_class(_root_, true);
 
 		// apply master CSS
-		doc->m_root->apply_stylesheet(ctx->master_css());
+		doc->m_root->apply_stylesheet(doc->m_master_css);
 
 		// parse elements attributes
 		doc->m_root->parse_attributes();
@@ -110,77 +116,100 @@ litehtml::document::ptr litehtml::document::createFromUTF8(const char* str, lite
 		doc->m_root->apply_stylesheet(doc->m_styles);
 
 		// Apply user styles if any
-		if (user_styles)
-		{
-			doc->m_root->apply_stylesheet(*user_styles);
-		}
+		doc->m_root->apply_stylesheet(doc->m_user_css);
 
-		// Parse applied styles in the elements
-		doc->m_root->parse_styles();
+		// Initialize m_css
+		doc->m_root->compute_styles();
+
+		// Create rendering tree
+		doc->m_root_render = doc->m_root->create_render_item(nullptr);
 
 		// Now the m_tabular_elements is filled with tabular elements.
 		// We have to check the tabular elements for missing table elements 
 		// and create the anonymous boxes in visual table layout
 		doc->fix_tables_layout();
 
-		// Fanaly initialize elements
-		doc->m_root->init();
+		// Finally initialize elements
+		// init() return pointer to the render_init element because it can change its type
+		doc->m_root_render = doc->m_root_render->init();
 	}
 
 	return doc;
 }
 
-litehtml::uint_ptr litehtml::document::add_font( const tchar_t* name, int size, const tchar_t* weight, const tchar_t* style, const tchar_t* decoration, font_metrics* fm )
+litehtml::uint_ptr litehtml::document::add_font( const char* name, int size, const char* weight, const char* style, const char* decoration, font_metrics* fm )
 {
 	uint_ptr ret = 0;
 
-	if(!name || !t_strcasecmp(name, _t("inherit")))
+	if(!name)
 	{
 		name = m_container->get_default_font_name();
 	}
 
-	if(!size)
-	{
-		size = container()->get_default_font_size();
-	}
-
-	tchar_t strSize[20];
+	char strSize[20];
 	t_itoa(size, strSize, 20, 10);
 
-	tstring key = name;
-	key += _t(":");
+	string key = name;
+	key += ":";
 	key += strSize;
-	key += _t(":");
+	key += ":";
 	key += weight;
-	key += _t(":");
+	key += ":";
 	key += style;
-	key += _t(":");
+	key += ":";
 	key += decoration;
 
 	if(m_fonts.find(key) == m_fonts.end())
 	{
-		font_style fs = (font_style) value_index(style, font_style_strings, fontStyleNormal);
+		font_style fs = (font_style) value_index(style, font_style_strings, font_style_normal);
 		int	fw = value_index(weight, font_weight_strings, -1);
 		if(fw >= 0)
 		{
 			switch(fw)
 			{
-			case litehtml::fontWeightBold:
+			case litehtml::font_weight_bold:
 				fw = 700;
 				break;
-			case litehtml::fontWeightBolder:
+			case litehtml::font_weight_bolder:
 				fw = 600;
 				break;
-			case litehtml::fontWeightLighter:
+			case litehtml::font_weight_lighter:
 				fw = 300;
 				break;
-			default:
+			case litehtml::font_weight_normal:
 				fw = 400;
 				break;
+			case litehtml::font_weight_100:
+				fw = 100;
+				break;
+			case litehtml::font_weight_200:
+				fw = 200;
+				break;
+			case litehtml::font_weight_300:
+				fw = 300;
+				break;
+			case litehtml::font_weight_400:
+				fw = 400;
+				break;
+			case litehtml::font_weight_500:
+				fw = 500;
+				break;
+			case litehtml::font_weight_600:
+				fw = 600;
+				break;
+			case litehtml::font_weight_700:
+				fw = 700;
+				break;
+			case litehtml::font_weight_800:
+				fw = 800;
+				break;
+			case litehtml::font_weight_900:
+				fw = 900;
+				break;
 			}
 		} else
 		{
-			fw = t_atoi(weight);
+			fw = atoi(weight);
 			if(fw < 100)
 			{
 				fw = 400;
@@ -191,17 +220,17 @@ litehtml::uint_ptr litehtml::document::add_font( const tchar_t* name, int size,
 
 		if(decoration)
 		{
-			std::vector<tstring> tokens;
-			split_string(decoration, tokens, _t(" "));
+			std::vector<string> tokens;
+			split_string(decoration, tokens, " ");
 			for(auto & token : tokens)
 			{
-				if(!t_strcasecmp(token.c_str(), _t("underline")))
+				if(!t_strcasecmp(token.c_str(), "underline"))
 				{
 					decor |= font_decoration_underline;
-				} else if(!t_strcasecmp(token.c_str(), _t("line-through")))
+				} else if(!t_strcasecmp(token.c_str(), "line-through"))
 				{
 					decor |= font_decoration_linethrough;
-				} else if(!t_strcasecmp(token.c_str(), _t("overline")))
+				} else if(!t_strcasecmp(token.c_str(), "overline"))
 				{
 					decor |= font_decoration_overline;
 				}
@@ -221,29 +250,28 @@ litehtml::uint_ptr litehtml::document::add_font( const tchar_t* name, int size,
 	return ret;
 }
 
-litehtml::uint_ptr litehtml::document::get_font( const tchar_t* name, int size, const tchar_t* weight, const tchar_t* style, const tchar_t* decoration, font_metrics* fm )
+litehtml::uint_ptr litehtml::document::get_font( const char* name, int size, const char* weight, const char* style, const char* decoration, font_metrics* fm )
 {
-	if(!name || !t_strcasecmp(name, _t("inherit")))
+	if(!size)
+	{
+		return 0;
+	}
+	if(!name)
 	{
 		name = m_container->get_default_font_name();
 	}
 
-	if(!size)
-	{
-		size = m_container->get_default_font_size();
-	}
-
-	tchar_t strSize[20];
+	char strSize[20];
 	t_itoa(size, strSize, 20, 10);
 
-	tstring key = name;
-	key += _t(":");
+	string key = name;
+	key += ":";
 	key += strSize;
-	key += _t(":");
+	key += ":";
 	key += weight;
-	key += _t(":");
+	key += ":";
 	key += style;
-	key += _t(":");
+	key += ":";
 	key += decoration;
 
 	auto el = m_fonts.find(key);
@@ -264,21 +292,31 @@ int litehtml::document::render( int max_width, render_type rt )
 	int ret = 0;
 	if(m_root)
 	{
+		position client_rc;
+		m_container->get_client_rect(client_rc);
+		containing_block_context cb_context;
+		cb_context.width = max_width;
+		cb_context.width.type = containing_block_context::cbc_value_type_absolute;
+		cb_context.height = client_rc.height;
+		cb_context.height.type = containing_block_context::cbc_value_type_absolute;
+
 		if(rt == render_fixed_only)
 		{
 			m_fixed_boxes.clear();
-			m_root->render_positioned(rt);
+			m_root_render->render_positioned(rt);
 		} else
 		{
-			ret = m_root->render(0, 0, max_width);
-			if(m_root->fetch_positioned())
+			ret = m_root_render->render(0, 0, cb_context, nullptr);
+			if(m_root_render->fetch_positioned())
 			{
 				m_fixed_boxes.clear();
-				m_root->render_positioned(rt);
+				m_root_render->render_positioned(rt);
 			}
 			m_size.width	= 0;
 			m_size.height	= 0;
-			m_root->calc_document_size(m_size);
+			m_content_size.width = 0;
+			m_content_size.height = 0;
+			m_root_render->calc_document_size(m_size, m_content_size);
 		}
 	}
 	return ret;
@@ -286,14 +324,14 @@ int litehtml::document::render( int max_width, render_type rt )
 
 void litehtml::document::draw( uint_ptr hdc, int x, int y, const position* clip )
 {
-	if(m_root)
+	if(m_root && m_root_render)
 	{
-		m_root->draw(hdc, x, y, clip);
-		m_root->draw_stacking_context(hdc, x, y, clip, true);
+		m_root->draw(hdc, x, y, clip, m_root_render);
+		m_root_render->draw_stacking_context(hdc, x, y, clip, true);
 	}
 }
 
-int litehtml::document::cvt_units( const tchar_t* str, int fontSize, bool* is_percent/*= 0*/ ) const
+int litehtml::document::to_pixels( const char* str, int fontSize, bool* is_percent/*= 0*/ ) const
 {
 	if(!str)	return 0;
 	
@@ -303,10 +341,10 @@ int litehtml::document::cvt_units( const tchar_t* str, int fontSize, bool* is_pe
 	{
 		*is_percent = true;
 	}
-	return cvt_units(val, fontSize);
+	return to_pixels(val, fontSize);
 }
 
-int litehtml::document::cvt_units( css_length& val, int fontSize, int size ) const
+int litehtml::document::to_pixels( const css_length& val, int fontSize, int size ) const
 {
 	if(val.is_predefined())
 	{
@@ -320,23 +358,18 @@ int litehtml::document::cvt_units( css_length& val, int fontSize, int size ) con
 		break;
 	case css_units_em:
 		ret = round_f(val.val() * (float) fontSize);
-		val.set_value((float) ret, css_units_px);
 		break;
 	case css_units_pt:
 		ret = m_container->pt_to_px((int) val.val());
-		val.set_value((float) ret, css_units_px);
 		break;
 	case css_units_in:
 		ret = m_container->pt_to_px((int) (val.val() * 72));
-		val.set_value((float) ret, css_units_px);
 		break;
 	case css_units_cm:
 		ret = m_container->pt_to_px((int) (val.val() * 0.3937 * 72));
-		val.set_value((float) ret, css_units_px);
 		break;
 	case css_units_mm:
 		ret = m_container->pt_to_px((int) (val.val() * 0.3937 * 72) / 10);
-		val.set_value((float) ret, css_units_px);
 		break;
 	case css_units_vw:
 		ret = (int)((double)m_media.width * (double)val.val() / 100.0);
@@ -351,8 +384,7 @@ int litehtml::document::cvt_units( css_length& val, int fontSize, int size ) con
 		ret = (int)((double)std::max(m_media.height, m_media.width) * (double)val.val() / 100.0);
 		break;
 	case css_units_rem:
-		ret = (int) ((double) m_root->get_font_size() * (double) val.val());
-		val.set_value((float) ret, css_units_px);
+		ret = (int) ((double) m_root->css().get_font_size() * (double) val.val());
 		break;
 	default:
 		ret = (int) val.val();
@@ -361,6 +393,38 @@ int litehtml::document::cvt_units( css_length& val, int fontSize, int size ) con
 	return ret;
 }
 
+void litehtml::document::cvt_units( css_length& val, int fontSize, int size ) const
+{
+	if(val.is_predefined())
+	{
+		return;
+	}
+	int ret;
+	switch(val.units())
+	{
+		case css_units_em:
+			ret = round_f(val.val() * (float) fontSize);
+			val.set_value((float) ret, css_units_px);
+			break;
+		case css_units_pt:
+			ret = m_container->pt_to_px((int) val.val());
+			val.set_value((float) ret, css_units_px);
+			break;
+		case css_units_in:
+			ret = m_container->pt_to_px((int) (val.val() * 72));
+			val.set_value((float) ret, css_units_px);
+			break;
+		case css_units_cm:
+			ret = m_container->pt_to_px((int) (val.val() * 0.3937 * 72));
+			val.set_value((float) ret, css_units_px);
+			break;
+		case css_units_mm:
+			ret = m_container->pt_to_px((int) (val.val() * 0.3937 * 72) / 10);
+			val.set_value((float) ret, css_units_px);
+			break;
+	}
+}
+
 int litehtml::document::width() const
 {
 	return m_size.width;
@@ -371,7 +435,18 @@ int litehtml::document::height() const
 	return m_size.height;
 }
 
-void litehtml::document::add_stylesheet( const tchar_t* str, const tchar_t* baseurl, const tchar_t* media )
+int litehtml::document::content_width() const
+{
+	return m_content_size.width;
+}
+
+int litehtml::document::content_height() const
+{
+	return m_content_size.height;
+}
+
+
+void litehtml::document::add_stylesheet( const char* str, const char* baseurl, const char* media )
 {
 	if(str && str[0])
 	{
@@ -381,12 +456,12 @@ void litehtml::document::add_stylesheet( const tchar_t* str, const tchar_t* base
 
 bool litehtml::document::on_mouse_over( int x, int y, int client_x, int client_y, position::vector& redraw_boxes )
 {
-	if(!m_root)
+	if(!m_root || !m_root_render)
 	{
 		return false;
 	}
 
-	element::ptr over_el = m_root->get_element_by_point(x, y, client_x, client_y);
+	element::ptr over_el = m_root_render->get_element_by_point(x, y, client_x, client_y);
 
 	bool state_was_changed = false;
 
@@ -402,7 +477,7 @@ bool litehtml::document::on_mouse_over( int x, int y, int client_x, int client_y
 		m_over_element = over_el;
 	}
 
-	const tchar_t* cursor = nullptr;
+	string cursor;
 
 	if(m_over_element)
 	{
@@ -410,21 +485,21 @@ bool litehtml::document::on_mouse_over( int x, int y, int client_x, int client_y
 		{
 			state_was_changed = true;
 		}
-		cursor = m_over_element->get_cursor();
+		cursor = m_over_element->css().get_cursor();
 	}
 	
-	m_container->set_cursor(cursor ? cursor : _t("auto"));
+	m_container->set_cursor(cursor.c_str());
 	
 	if(state_was_changed)
 	{
-		return m_root->find_styles_changes(redraw_boxes, 0, 0);
+		return m_root->find_styles_changes(redraw_boxes);
 	}
 	return false;
 }
 
 bool litehtml::document::on_mouse_leave( position::vector& redraw_boxes )
 {
-	if(!m_root)
+	if(!m_root || !m_root_render)
 	{
 		return false;
 	}
@@ -432,7 +507,7 @@ bool litehtml::document::on_mouse_leave( position::vector& redraw_boxes )
 	{
 		if(m_over_element->on_mouse_leave())
 		{
-			return m_root->find_styles_changes(redraw_boxes, 0, 0);
+			return m_root->find_styles_changes(redraw_boxes);
 		}
 	}
 	return false;
@@ -440,12 +515,12 @@ bool litehtml::document::on_mouse_leave( position::vector& redraw_boxes )
 
 bool litehtml::document::on_lbutton_down( int x, int y, int client_x, int client_y, position::vector& redraw_boxes )
 {
-	if(!m_root)
+	if(!m_root || !m_root_render)
 	{
 		return false;
 	}
 
-	element::ptr over_el = m_root->get_element_by_point(x, y, client_x, client_y);
+	element::ptr over_el = m_root_render->get_element_by_point(x, y, client_x, client_y);
 
 	bool state_was_changed = false;
 
@@ -468,7 +543,7 @@ bool litehtml::document::on_lbutton_down( int x, int y, int client_x, int client
 		}
 	}
 
-	const tchar_t* cursor = nullptr;
+	string cursor;
 
 	if(m_over_element)
 	{
@@ -476,14 +551,14 @@ bool litehtml::document::on_lbutton_down( int x, int y, int client_x, int client
 		{
 			state_was_changed = true;
 		}
-		cursor = m_over_element->get_cursor();
+		cursor = m_over_element->css().get_cursor();
 	}
 
-	m_container->set_cursor(cursor ? cursor : _t("auto"));
+	m_container->set_cursor(cursor.c_str());
 
 	if(state_was_changed)
 	{
-		return m_root->find_styles_changes(redraw_boxes, 0, 0);
+		return m_root->find_styles_changes(redraw_boxes);
 	}
 
 	return false;
@@ -491,7 +566,7 @@ bool litehtml::document::on_lbutton_down( int x, int y, int client_x, int client
 
 bool litehtml::document::on_lbutton_up( int x, int y, int client_x, int client_y, position::vector& redraw_boxes )
 {
-	if(!m_root)
+	if(!m_root || !m_root_render)
 	{
 		return false;
 	}
@@ -499,13 +574,13 @@ bool litehtml::document::on_lbutton_up( int x, int y, int client_x, int client_y
 	{
 		if(m_over_element->on_lbutton_up())
 		{
-			return m_root->find_styles_changes(redraw_boxes, 0, 0);
+			return m_root->find_styles_changes(redraw_boxes);
 		}
 	}
 	return false;
 }
 
-litehtml::element::ptr litehtml::document::create_element(const tchar_t* tag_name, const string_map& attributes)
+litehtml::element::ptr litehtml::document::create_element(const char* tag_name, const string_map& attributes)
 {
 	element::ptr newTag;
 	document::ptr this_doc = shared_from_this();
@@ -515,54 +590,51 @@ litehtml::element::ptr litehtml::document::create_element(const tchar_t* tag_nam
 	}
 	if(!newTag)
 	{
-		if(!t_strcmp(tag_name, _t("br")))
+		if(!strcmp(tag_name, "br"))
 		{
 			newTag = std::make_shared<litehtml::el_break>(this_doc);
-		} else if(!t_strcmp(tag_name, _t("p")))
+		} else if(!strcmp(tag_name, "p"))
 		{
 			newTag = std::make_shared<litehtml::el_para>(this_doc);
-		} else if(!t_strcmp(tag_name, _t("img")))
+		} else if(!strcmp(tag_name, "img"))
 		{
 			newTag = std::make_shared<litehtml::el_image>(this_doc);
-		} else if(!t_strcmp(tag_name, _t("table")))
+		} else if(!strcmp(tag_name, "table"))
 		{
 			newTag = std::make_shared<litehtml::el_table>(this_doc);
-		} else if(!t_strcmp(tag_name, _t("td")) || !t_strcmp(tag_name, _t("th")))
+		} else if(!strcmp(tag_name, "td") || !strcmp(tag_name, "th"))
 		{
 			newTag = std::make_shared<litehtml::el_td>(this_doc);
-		} else if(!t_strcmp(tag_name, _t("link")))
+		} else if(!strcmp(tag_name, "link"))
 		{
 			newTag = std::make_shared<litehtml::el_link>(this_doc);
-		} else if(!t_strcmp(tag_name, _t("title")))
+		} else if(!strcmp(tag_name, "title"))
 		{
 			newTag = std::make_shared<litehtml::el_title>(this_doc);
-		} else if(!t_strcmp(tag_name, _t("a")))
+		} else if(!strcmp(tag_name, "a"))
 		{
 			newTag = std::make_shared<litehtml::el_anchor>(this_doc);
-		} else if(!t_strcmp(tag_name, _t("tr")))
+		} else if(!strcmp(tag_name, "tr"))
 		{
 			newTag = std::make_shared<litehtml::el_tr>(this_doc);
-		} else if(!t_strcmp(tag_name, _t("style")))
+		} else if(!strcmp(tag_name, "style"))
 		{
 			newTag = std::make_shared<litehtml::el_style>(this_doc);
-		} else if(!t_strcmp(tag_name, _t("base")))
+		} else if(!strcmp(tag_name, "base"))
 		{
 			newTag = std::make_shared<litehtml::el_base>(this_doc);
-		} else if(!t_strcmp(tag_name, _t("body")))
+		} else if(!strcmp(tag_name, "body"))
 		{
 			newTag = std::make_shared<litehtml::el_body>(this_doc);
-		} else if(!t_strcmp(tag_name, _t("div")))
+		} else if(!strcmp(tag_name, "div"))
 		{
 			newTag = std::make_shared<litehtml::el_div>(this_doc);
-		} else if(!t_strcmp(tag_name, _t("script")))
+		} else if(!strcmp(tag_name, "script"))
 		{
 			newTag = std::make_shared<litehtml::el_script>(this_doc);
-		} else if(!t_strcmp(tag_name, _t("font")))
+		} else if(!strcmp(tag_name, "font"))
 		{
 			newTag = std::make_shared<litehtml::el_font>(this_doc);
-		} else if(!t_strcmp(tag_name, _t("li")))
-		{
-			newTag = std::make_shared<litehtml::el_li>(this_doc);
 		} else
 		{
 			newTag = std::make_shared<litehtml::html_tag>(this_doc);
@@ -597,7 +669,7 @@ bool litehtml::document::media_changed()
 	if (update_media_lists(m_media))
 	{
 		m_root->refresh_styles();
-		m_root->parse_styles();
+		m_root->compute_styles();
 		return true;
 	}
 	return false;
@@ -607,18 +679,18 @@ bool litehtml::document::lang_changed()
 {
 	if(!m_media_lists.empty())
 	{
-		tstring culture;
+		string culture;
 		container()->get_language(m_lang, culture);
 		if(!culture.empty())
 		{
-			m_culture = m_lang + _t('-') + culture;
+			m_culture = m_lang + '-' + culture;
 		}
 		else
 		{
 			m_culture.clear();
 		}
 		m_root->refresh_styles();
-		m_root->parse_styles();
+		m_root->compute_styles();
 		return true;
 	}
 	return false;
@@ -648,7 +720,7 @@ void litehtml::document::add_media_list( const media_query_list::ptr& list )
 	}
 }
 
-void litehtml::document::create_node(void* gnode, elements_vector& elements, bool parseTextNode)
+void litehtml::document::create_node(void* gnode, elements_list& elements, bool parseTextNode)
 {
 	auto* node = (GumboNode*)gnode;
 	switch (node->type)
@@ -660,7 +732,7 @@ void litehtml::document::create_node(void* gnode, elements_vector& elements, boo
 			for (unsigned int i = 0; i < node->v.element.attributes.length; i++)
 			{
 				attr = (GumboAttribute*)node->v.element.attributes.data[i];
-				attrs[tstring(litehtml_from_utf8(attr->name))] = litehtml_from_utf8(attr->value);
+				attrs[attr->name] = attr->value;
 			}
 
 
@@ -668,7 +740,7 @@ void litehtml::document::create_node(void* gnode, elements_vector& elements, boo
 			const char* tag = gumbo_normalized_tagname(node->v.element.tag);
 			if (tag[0])
 			{
-				ret = create_element(litehtml_from_utf8(tag), attrs);
+				ret = create_element(tag, attrs);
 			}
 			else
 			{
@@ -677,7 +749,7 @@ void litehtml::document::create_node(void* gnode, elements_vector& elements, boo
 					std::string strA;
 					gumbo_tag_from_original_text(&node->v.element.original_tag);
 					strA.append(node->v.element.original_tag.data, node->v.element.original_tag.length);
-					ret = create_element(litehtml_from_utf8(strA.c_str()), attrs);
+					ret = create_element(strA.c_str(), attrs);
 				}
 			}
 			if (!strcmp(tag, "script"))
@@ -686,7 +758,7 @@ void litehtml::document::create_node(void* gnode, elements_vector& elements, boo
 			}
 			if (ret)
 			{
-				elements_vector child;
+				elements_list child;
 				for (unsigned int i = 0; i < node->v.element.children.length; i++)
 				{
 					child.clear();
@@ -704,37 +776,35 @@ void litehtml::document::create_node(void* gnode, elements_vector& elements, boo
 		break;
 	case GUMBO_NODE_TEXT:
 		{
-			std::wstring str;
-			std::wstring str_in = (const wchar_t*) (utf8_to_wchar(node->v.text.text));
 			if (!parseTextNode)
 			{
-				elements.push_back(std::make_shared<el_text>(litehtml_from_wchar(str_in).c_str(), shared_from_this()));
+				elements.push_back(std::make_shared<el_text>(node->v.text.text, shared_from_this()));
 			}
 			else
 			{
 				m_container->split_text(node->v.text.text,
-					[this, &elements](const tchar_t* text) { elements.push_back(std::make_shared<el_text>(text, shared_from_this())); },
-					[this, &elements](const tchar_t* text) { elements.push_back(std::make_shared<el_space>(text, shared_from_this())); });
+					[this, &elements](const char* text) { elements.push_back(std::make_shared<el_text>(text, shared_from_this())); },
+					[this, &elements](const char* text) { elements.push_back(std::make_shared<el_space>(text, shared_from_this())); });
 			}
 		}
 		break;
 	case GUMBO_NODE_CDATA:
 		{
 			element::ptr ret = std::make_shared<el_cdata>(shared_from_this());
-			ret->set_data(litehtml_from_utf8(node->v.text.text));
+			ret->set_data(node->v.text.text);
 			elements.push_back(ret);
 		}
 		break;
 	case GUMBO_NODE_COMMENT:
 		{
 			element::ptr ret = std::make_shared<el_comment>(shared_from_this());
-			ret->set_data(litehtml_from_utf8(node->v.text.text));
+			ret->set_data(node->v.text.text);
 			elements.push_back(ret);
 		}
 		break;
 	case GUMBO_NODE_WHITESPACE:
 		{
-			tstring str = litehtml_from_utf8(node->v.text.text);
+			string str = node->v.text.text;
 			for (size_t i = 0; i < str.length(); i++)
 			{
 				elements.push_back(std::make_shared<el_space>(str.substr(i, 1).c_str(), shared_from_this()));
@@ -748,36 +818,33 @@ void litehtml::document::create_node(void* gnode, elements_vector& elements, boo
 
 void litehtml::document::fix_tables_layout()
 {
-	size_t i = 0;
-	while (i < m_tabular_elements.size())
+	for (const auto& el_ptr : m_tabular_elements)
 	{
-		element::ptr el_ptr = m_tabular_elements[i];
-
-		switch (el_ptr->get_display())
+		switch (el_ptr->src_el()->css().get_display())
 		{
 		case display_inline_table:
 		case display_table:
-			fix_table_children(el_ptr, display_table_row_group, _t("table-row-group"));
+			fix_table_children(el_ptr, display_table_row_group, "table-row-group");
 			break;
 		case display_table_footer_group:
 		case display_table_row_group:
 		case display_table_header_group:
 			{
-				element::ptr parent = el_ptr->parent();
+				auto parent = el_ptr->parent();
 				if (parent)
 				{
-					if (parent->get_display() != display_inline_table)
-						fix_table_parent(el_ptr, display_table, _t("table"));
+					if (parent->src_el()->css().get_display() != display_inline_table)
+						fix_table_parent(el_ptr, display_table, "table");
 				}
-				fix_table_children(el_ptr, display_table_row, _t("table-row"));
+				fix_table_children(el_ptr, display_table_row, "table-row");
 			}
 			break;
 		case display_table_row:
-			fix_table_parent(el_ptr, display_table_row_group, _t("table-row-group"));
-			fix_table_children(el_ptr, display_table_cell, _t("table-cell"));
+			fix_table_parent(el_ptr, display_table_row_group, "table-row-group");
+			fix_table_children(el_ptr, display_table_cell, "table-cell");
 			break;
 		case display_table_cell:
-			fix_table_parent(el_ptr, display_table_row, _t("table-row"));
+			fix_table_parent(el_ptr, display_table_row, "table-row");
 			break;
 		// TODO: make table layout fix for table-caption, table-column etc. elements
 		case display_table_caption:
@@ -786,45 +853,54 @@ void litehtml::document::fix_tables_layout()
 		default:
 			break;
 		}
-		i++;
 	}
 }
 
-void litehtml::document::fix_table_children(element::ptr& el_ptr, style_display disp, const tchar_t* disp_str)
+void litehtml::document::fix_table_children(const std::shared_ptr<render_item>& el_ptr, style_display disp, const char* disp_str)
 {
-	elements_vector tmp;
-	auto first_iter = el_ptr->m_children.begin();
-	auto cur_iter = el_ptr->m_children.begin();
+	std::list<std::shared_ptr<render_item>> tmp;
+	auto first_iter = el_ptr->children().begin();
+	auto cur_iter = el_ptr->children().begin();
 
 	auto flush_elements = [&]()
 	{
-		element::ptr annon_tag = std::make_shared<html_tag>(shared_from_this());
-		annon_tag->add_style(tstring(_t("display:")) + disp_str, _t(""));
-		annon_tag->parent(el_ptr);
-		annon_tag->parse_styles();
-		std::for_each(tmp.begin(), tmp.end(),
-			[&annon_tag](element::ptr& el)
-			{
-				annon_tag->appendChild(el);
-			}
-		);
-		first_iter = el_ptr->m_children.insert(first_iter, annon_tag);
-		cur_iter = first_iter + 1;
-		while (cur_iter != el_ptr->m_children.end() && (*cur_iter)->parent() != el_ptr)
+		element::ptr annon_tag = std::make_shared<html_tag>(el_ptr->src_el(), string("display:") + disp_str);
+		std::shared_ptr<render_item> annon_ri;
+		if(annon_tag->css().get_display() == display_table_cell)
 		{
-			cur_iter = el_ptr->m_children.erase(cur_iter);
+			annon_tag->set_tagName("table_cell");
+			annon_ri = std::make_shared<render_item_block>(annon_tag);
+		} else if(annon_tag->css().get_display() == display_table_row)
+		{
+			annon_ri = std::make_shared<render_item_table_row>(annon_tag);
+		} else
+		{
+			annon_ri = std::make_shared<render_item_table_part>(annon_tag);
+		}
+		for(const auto& el : tmp)
+		{
+			annon_ri->add_child(el);
+		}
+		// add annon item as tabular for future processing
+		add_tabular(annon_ri);
+		annon_ri->parent(el_ptr);
+		first_iter = el_ptr->children().insert(first_iter, annon_ri);
+		cur_iter = std::next(first_iter);
+		while (cur_iter != el_ptr->children().end() && (*cur_iter)->parent() != el_ptr)
+		{
+			cur_iter = el_ptr->children().erase(cur_iter);
 		}
 		first_iter = cur_iter;
 		tmp.clear();
 	};
 
-	while (cur_iter != el_ptr->m_children.end())
+	while (cur_iter != el_ptr->children().end())
 	{
-		if ((*cur_iter)->get_display() != disp)
+		if ((*cur_iter)->src_el()->css().get_display() != disp)
 		{
-			if (!(*cur_iter)->is_table_skip() || ((*cur_iter)->is_table_skip() && !tmp.empty()))
+			if (!(*cur_iter)->src_el()->is_table_skip() || ((*cur_iter)->src_el()->is_table_skip() && !tmp.empty()))
 			{
-				if (disp != display_table_row_group || (*cur_iter)->get_display() != display_table_caption)
+				if (disp != display_table_row_group || (*cur_iter)->src_el()->css().get_display() != display_table_caption)
 				{
 					if (tmp.empty())
 					{
@@ -850,14 +926,14 @@ void litehtml::document::fix_table_children(element::ptr& el_ptr, style_display
 	}
 }
 
-void litehtml::document::fix_table_parent(element::ptr& el_ptr, style_display disp, const tchar_t* disp_str)
+void litehtml::document::fix_table_parent(const std::shared_ptr<render_item>& el_ptr, style_display disp, const char* disp_str)
 {
-	element::ptr parent = el_ptr->parent();
+	auto parent = el_ptr->parent();
 
-	if (parent->get_display() != disp)
+	if (parent->src_el()->css().get_display() != disp)
 	{
-		auto this_element = std::find_if(parent->m_children.begin(), parent->m_children.end(),
-			[&](element::ptr& el)
+		auto this_element = std::find_if(parent->children().begin(), parent->children().end(),
+			[&](const std::shared_ptr<render_item>& el)
 			{
 				if (el == el_ptr)
 				{
@@ -866,9 +942,9 @@ void litehtml::document::fix_table_parent(element::ptr& el_ptr, style_display di
 				return false;
 			}
 		);
-		if (this_element != parent->m_children.end())
+		if (this_element != parent->children().end())
 		{
-			style_display el_disp = el_ptr->get_display();
+			style_display el_disp = el_ptr->src_el()->css().get_display();
 			auto first = this_element;
 			auto last = this_element;
 			auto cur = this_element;
@@ -876,9 +952,9 @@ void litehtml::document::fix_table_parent(element::ptr& el_ptr, style_display di
 			// find first element with same display
 			while (true)
 			{
-				if (cur == parent->m_children.begin()) break;
+				if (cur == parent->children().begin()) break;
 				cur--;
-				if ((*cur)->is_table_skip() || (*cur)->get_display() == el_disp)
+				if ((*cur)->src_el()->is_table_skip() || (*cur)->src_el()->css().get_display() == el_disp)
 				{
 					first = cur;
 				}
@@ -893,9 +969,9 @@ void litehtml::document::fix_table_parent(element::ptr& el_ptr, style_display di
 			while (true)
 			{
 				cur++;
-				if (cur == parent->m_children.end()) break;
+				if (cur == parent->children().end()) break;
 
-				if ((*cur)->is_table_skip() || (*cur)->get_display() == el_disp)
+				if ((*cur)->src_el()->is_table_skip() || (*cur)->src_el()->css().get_display() == el_disp)
 				{
 					last = cur;
 				}
@@ -906,28 +982,33 @@ void litehtml::document::fix_table_parent(element::ptr& el_ptr, style_display di
 			}
 
 			// extract elements with the same display and wrap them with anonymous object
-			element::ptr annon_tag = std::make_shared<html_tag>(shared_from_this());
-			annon_tag->add_style(tstring(_t("display:")) + disp_str, _t(""));
-			annon_tag->parent(parent);
-			annon_tag->parse_styles();
-			std::for_each(first, last + 1,
-				[&annon_tag](element::ptr& el)
+			element::ptr annon_tag = std::make_shared<html_tag>(parent->src_el(), string("display:") + disp_str);
+			std::shared_ptr<render_item> annon_ri;
+			if(annon_tag->css().get_display() == display_table || annon_tag->css().get_display() == display_inline_table)
+			{
+				annon_ri = std::make_shared<render_item_table>(annon_tag);
+			} else if(annon_tag->css().get_display() == display_table_row)
+			{
+				annon_ri = std::make_shared<render_item_table_row>(annon_tag);
+			} else
+			{
+				annon_ri = std::make_shared<render_item_table_part>(annon_tag);
+			}
+			std::for_each(first, std::next(last, 1),
+				[&annon_ri](std::shared_ptr<render_item>& el)
 				{
-					annon_tag->appendChild(el);
+					annon_ri->add_child(el);
 				}
 			);
-			first = parent->m_children.erase(first, last + 1);
-			parent->m_children.insert(first, annon_tag);
+			first = parent->children().erase(first, std::next(last));
+			parent->children().insert(first, annon_ri);
+			add_tabular(annon_ri);
+			annon_ri->parent(parent);
 		}
 	}
 }
 
-void litehtml::document::append_children_from_string(element& parent, const tchar_t* str)
-{
-	append_children_from_utf8(parent, litehtml_to_utf8(str));
-}
-
-void litehtml::document::append_children_from_utf8(element& parent, const char* str)
+void litehtml::document::append_children_from_string(element& parent, const char* str)
 {
 	// parent must belong to this document
 	if (parent.get_document().get() != this)
@@ -936,10 +1017,10 @@ void litehtml::document::append_children_from_utf8(element& parent, const char*
 	}
 
 	// parse document into GumboOutput
-	GumboOutput* output = gumbo_parse((const char*) str);
+	GumboOutput* output = gumbo_parse(str);
 
 	// Create litehtml::elements.
-	elements_vector child_elements;
+	elements_list child_elements;
 	create_node(output->root, child_elements, true);
 
 	// Destroy GumboOutput
@@ -952,7 +1033,7 @@ void litehtml::document::append_children_from_utf8(element& parent, const char*
 		parent.appendChild(child);
 
 		// apply master CSS
-		child->apply_stylesheet(m_context->master_css());
+		child->apply_stylesheet(m_master_css);
 
 		// parse elements attributes
 		child->parse_attributes();
@@ -960,15 +1041,26 @@ void litehtml::document::append_children_from_utf8(element& parent, const char*
 		// Apply parsed styles.
 		child->apply_stylesheet(m_styles);
 
-		// Parse applied styles in the elements
-		child->parse_styles();
+		// Apply user styles if any
+		child->apply_stylesheet(m_user_css);
+
+		// Initialize m_css
+		child->compute_styles();
 
 		// Now the m_tabular_elements is filled with tabular elements.
 		// We have to check the tabular elements for missing table elements 
 		// and create the anonymous boxes in visual table layout
 		fix_tables_layout();
 
-		// Fanaly initialize elements
-		child->init();
+		// Finally initialize elements
+		//child->init();
+	}
+}
+
+void litehtml::document::dump(dumper& cout)
+{
+	if(m_root_render)
+	{
+		m_root_render->dump(cout);
 	}
 }
