@@ -1,18 +1,12 @@
 /***************************************************************************
 
   CConst.h
-  
-  (c) 2004-2006 - Daniel Campos Fernández <dcamposf@gmail.com>
-  
-  GTK+ component
 
-  Realizado para la Junta de Extremadura. 
-  Consejería de Educación Ciencia y Tecnología. 
-  Proyecto gnuLinEx
-  
+  (c) 2004-2006 - Daniel Campos Fernández <dcamposf@gmail.com>
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -22,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -32,13 +27,12 @@
 #include "gambas.h"
 
 #ifndef __CCONST_CPP
-extern GB_DESC CAlignDesc[];
-extern GB_DESC CArrangeDesc[];
-extern GB_DESC CBorderDesc[];
-extern GB_DESC CScrollDesc[];
-extern GB_DESC CLineDesc[];
-extern GB_DESC CFillDesc[];
-extern GB_DESC CSelectDesc[];
+extern GB_DESC AlignDesc[];
+extern GB_DESC ArrangeDesc[];
+extern GB_DESC BorderDesc[];
+extern GB_DESC ScrollDesc[];
+extern GB_DESC SelectDesc[];
+extern GB_DESC DirectionDesc[];
 #endif
 
 
