@@ -335,7 +335,7 @@ void InitControl(gControl *control, CWIDGET *widget)
 	{
 		char buffer[256 + 16];
 		n++;
-		sprintf(buffer, "%s.%u", GB.GetClassName(widget), n);
+		sprintf(buffer, "%s-%u", GB.GetClassName(widget), n);
 		control->setName(buffer);
 	}
 	else
