@@ -97,6 +97,8 @@ typedef
 	struct {
 		cairo_t *context;
 		GtkPrintContext *print_context;
+		float opacity;
+		float *opacity_stack;
 		gFont *font;
 		gFont **font_stack;
 		PangoLayout *layout;
@@ -106,7 +108,6 @@ typedef
 		double dy;
 		double bx;
 		double by;
-		float opacity;
 		float dash_offset;
 		bool invert;
 		}
@@ -202,6 +203,8 @@ static bool init_painting(GB_PAINT *d, cairo_surface_t *target, double w, double
 	cairo_get_matrix(CONTEXT(d), &EXTRA(d)->init);
 
 	dx->opacity = 1;
+	dx->opacity_stack = NULL;
+	
 	dx->dash_offset = 0;
 	
 	return FALSE;
@@ -464,7 +467,10 @@ static void End(GB_PAINT *d)
 	}
 
 	delete dx->font;
-
+	
+	if (dx->opacity_stack)
+		GB.FreeArray(POINTER(&dx->opacity_stack));
+	
 	if (GB.Is(device, CLASS_Picture))
 	{
 		gPicture *picture = ((CPICTURE *)device)->picture;
@@ -493,24 +499,36 @@ static void Save(GB_PAINT *d)
 	cairo_save(dx->context);
 
 	if (!dx->font_stack)
+	{
 		GB.NewArray(POINTER(&dx->font_stack), sizeof(void *), 0);
+		GB.NewArray(POINTER(&dx->opacity_stack), sizeof(float), 0);
+	}
 
 	pfont = (gFont **)GB.Add(POINTER(&dx->font_stack));
 	*pfont = dx->font->copy();
+	*(float *)GB.Add(POINTER(&dx->opacity_stack)) = dx->opacity;
 }
 
 static void Restore(GB_PAINT *d)
 {
 	GB_PAINT_EXTRA *dx = EXTRA(d);
+	int n;
 
 	cairo_restore(dx->context);
 
-	if (dx->font_stack && GB.Count(dx->font_stack) > 0)
+	if (dx->font_stack)
 	{
-		delete dx->font;
-		dx->font = dx->font_stack[GB.Count(dx->font_stack) - 1];
-		GB.Remove(POINTER(&dx->font_stack), GB.Count(dx->font_stack) - 1, 1);
-		update_layout(d);
+		n = GB.Count(dx->font_stack);
+		if (n > 0)
+		{
+			delete dx->font;
+			dx->font = dx->font_stack[n - 1];
+			GB.Remove(POINTER(&dx->font_stack), n - 1, 1);
+			update_layout(d);
+			
+			dx->opacity = dx->opacity_stack[n - 1];
+			GB.Remove(POINTER(&dx->opacity_stack), n - 1, 1);
+		}
 	}
 }
 
