@@ -88,7 +88,8 @@ static gboolean button_expose(GtkWidget *wid, GdkEventExpose *e, gButton *data)
 	bool rtl;
 	int x, w, wt, wp, hp;
 	int d = gDesktop::scale() / 2;
-	gColor fg = COLOR_DEFAULT;
+	gColor fg = GB_COLOR_DEFAULT;
+	int size;
 	
 	rtl = gtk_widget_get_direction(wid) == GTK_TEXT_DIR_RTL;
 	
@@ -122,7 +123,7 @@ static gboolean button_expose(GtkWidget *wid, GdkEventExpose *e, gButton *data)
 
 		fg = data->realForeground();
 
-		if (fg == COLOR_DEFAULT)
+		if (fg == GB_COLOR_DEFAULT)
 		{
 			g_object_set(G_OBJECT(data->rendtxt),
 				"foreground-set", FALSE,
@@ -167,6 +168,23 @@ static gboolean button_expose(GtkWidget *wid, GdkEventExpose *e, gButton *data)
 
 		wp = gdk_pixbuf_get_width(img);
 		hp = gdk_pixbuf_get_height(img);
+		
+		size = Min(data->width(), data->height()) - d * 2;
+		if (size <= 0)
+			wp = hp = 0;
+		else if (Max(wp, hp) > size)
+		{
+			if (wp > hp)
+			{
+				wp = size * wp / hp;
+				hp = size;
+			}
+			else
+			{
+				hp = size * hp / wp;
+				wp = size;
+			}
+		}
 	}
 
 	w = wt + wp;
@@ -185,7 +203,7 @@ static gboolean button_expose(GtkWidget *wid, GdkEventExpose *e, gButton *data)
 			cairo_clip(cr);
 		#endif
 		
-		gt_cairo_draw_pixbuf(cr, img, x, rect.y + (rect.height - hp) / 2, -1, -1, 1.0, NULL);
+		gt_cairo_draw_pixbuf(cr, img, x, rect.y + (rect.height - hp) / 2, wp, hp, 1.0, NULL);
 		
 		#ifndef GTK3
 			cairo_destroy(cr);
@@ -202,7 +220,7 @@ static gboolean button_expose(GtkWidget *wid, GdkEventExpose *e, gButton *data)
 		
 			g_object_set(G_OBJECT(data->rendtxt), "sensitive", !(f & GTK_STATE_INSENSITIVE), (void *)NULL);
 			
-			if (fg != COLOR_DEFAULT)
+			if (fg != GB_COLOR_DEFAULT)
 				state = (GtkCellRendererState)0;
 			else if (f & GTK_STATE_SELECTED)
 				state = GTK_CELL_RENDERER_SELECTED;
@@ -762,5 +780,5 @@ gColor gButton::defaultBackground() const
 	if (type == Check || type == Radio)
 		return gControl::defaultBackground();
 	else
-		return gDesktop::getColor(gDesktop::BUTTON_BACKGROUND, !isEnabled());
+		return gDesktop::getColor(COLOR_BUTTON_BACKGROUND, !isEnabled());
 }
