@@ -21,14 +21,6 @@
 
 ***************************************************************************/
 
-#ifndef GAMBAS_DIRECTFB
-#ifdef GDK_WINDOWING_X11
-#include <gdk/gdkx.h>
-#include <X11/X.h>
-#include <X11/Xlib.h>
-#endif
-#endif
-
 #include "widgets.h"
 #include "gapplication.h"
 #include "gmainwindow.h"
@@ -62,7 +54,7 @@ typedef
 static int _current_clipboard = gClipboard::Clipboard;
 static GtkClipboard *_clipboard = NULL;
 static GtkClipboard *_selection = NULL;
-static bool _clipboard_has_changed[2] = { FALSE };
+static bool _clipboard_has_changed[2] = { TRUE };
 
 static char *convert_format(char *fmt)
 {
@@ -145,7 +137,8 @@ int gClipboard::getCurrent()
 
 void gClipboard::clear()
 {
-	gtk_clipboard_clear(get_clipboard());
+	if (gApplication::isInit())
+		gtk_clipboard_clear(get_clipboard());
 }
 
 char *gClipboard::getFormat(int n)
@@ -157,7 +150,7 @@ char *gClipboard::getFormat(int n)
 
 	if (!gtk_clipboard_wait_for_targets(get_clipboard(), &targets, &n_tg))
 		return NULL;
-	
+
 	for (i = 0; i < n_tg; i++)
 	{
 		fmt = gdk_atom_name(targets[i]);
@@ -174,7 +167,7 @@ char *gClipboard::getFormat(int n)
 		}
 		n--;
 	}
-	
+
 	return NULL;
 }
 
@@ -206,7 +199,7 @@ gPicture * gClipboard::getImage()
   return new gPicture(gtk_clipboard_wait_for_image(get_clipboard()));
 }
 
-static void 
+static void
 gt_clipboard_set_text (GtkClipboard *clipboard, char *format, const gchar *text, gint len)
 {
   GtkTargetList *list;
@@ -226,11 +219,11 @@ gt_clipboard_set_text (GtkClipboard *clipboard, char *format, const gchar *text,
       GtkTargetPair *pair = (GtkTargetPair *)l->data;
       targets[i].target = gdk_atom_name (pair->target);
     }
-  
+
   if (len < 0)
     len = strlen (text);
-  
-  gtk_clipboard_set_with_data (clipboard, 
+
+  gtk_clipboard_set_with_data (clipboard,
 			       targets, n_targets,
 			       cb_get_text, cb_clear_text,
 			       g_strndup (text, len));
@@ -246,7 +239,7 @@ void gClipboard::setText(char *text, int len, char *format)
 {
 	if (!text)
 		return;
-		
+
 	gt_clipboard_set_text(get_clipboard(), format, text, len);
 }
 
@@ -261,37 +254,40 @@ char *gClipboard::getText(int *len, const char *format)
 	char *text;
 
 	*len = 0;
-	
+
 	if (!gtk_clipboard_wait_for_targets(get_clipboard(), &targets, &n_tg) || n_tg <= 0)
 		return NULL;
 	
+	if (format && !strcmp(format, "text/plain"))
+		format = "text/plain;charset=utf-8";
+
 	for (i = 0; i < n_tg; i++)
 	{
 		target = targets[i];
 		fmt = convert_format(gt_free_later(gdk_atom_name(target)));
 		if (!islower(fmt[0]))
 			continue;
-		if (!format && !strncasecmp(fmt, "text/", 5))
+		if (!format && !strncasecmp(fmt, "text/", 5) && strcasecmp(fmt, "text/plain"))
 			break;
 		if (format && !strcasecmp(fmt, format))
 			break;
 	}
-	
+
 	if (i >= n_tg)
 		return NULL;
-	
+
 	if (!gtk_clipboard_wait_is_target_available(get_clipboard(), target))
 		return NULL;
-	
+
 	data = gtk_clipboard_wait_for_contents(get_clipboard(), target);
 	*len = gtk_selection_data_get_length(data);
 	text = (char *)g_malloc(*len);
 	memcpy(text, gtk_selection_data_get_data(data), *len);
-	
+
 	gtk_selection_data_free(data);
-	
+
 	_clipboard_has_changed[_current_clipboard] = FALSE;
-	
+
 	return gt_free_later(text);
 }
 
@@ -302,6 +298,7 @@ char *gClipboard::getText(int *len, const char *format)
 ************************************************************************/
 
 bool gDrag::_active = false;
+bool gDrag::_has_data = false;
 gPicture *gDrag::_icon = NULL;
 int gDrag::_icon_x = 0;
 int gDrag::_icon_y = 0;
@@ -322,9 +319,10 @@ guint32 gDrag::_time = 0;
 bool gDrag::_local = false;
 volatile bool gDrag::_got_data = false;
 volatile bool gDrag::_end = false;
+gControl *gDrag::_current = NULL;
 
 void gDrag::setIcon(gPicture *vl)
-{  
+{
 	gPicture::assign(&_icon, vl);
 }
 
@@ -338,8 +336,11 @@ void gDrag::cancel()
 	setIcon(NULL);
 	setDropText(NULL);
 	setDropImage(NULL);
-	g_free(_format);
-	_format = NULL;
+	if (_format)
+	{
+		g_free(_format);
+		_format = NULL;
+	}
 	_source = NULL;
 	_destination = NULL;
 	_dest = NULL;
@@ -349,6 +350,9 @@ void gDrag::cancel()
 	_got_data = false;
 	_local = false;
 	_active = false;
+	_has_data = false;
+
+	gApplication::setButtonGrab(NULL);
 
 #if DEBUG_ME
 	fprintf(stderr, "_active -> false\n");
@@ -373,9 +377,9 @@ gControl *gDrag::drag(gControl *source, GtkTargetList *list)
 	button = gMouse::left() ? 1 : gMouse::middle() ? 2 : gMouse::right() ? 3 : 0;
 
 #if GTK_CHECK_VERSION(3, 10, 0)
-	ct = gtk_drag_begin_with_coordinates(source->border, list, GDK_ACTION_COPY, button, gApplication::lastEvent(), -1, -1);
+	ct = gtk_drag_begin_with_coordinates(source->border, list, GDK_ACTION_MOVE, button, gApplication::lastEvent(), -1, -1);
 #else
-	ct = gtk_drag_begin(source->border, list, GDK_ACTION_COPY, button, gApplication::lastEvent());
+	ct = gtk_drag_begin(source->border, list, GDK_ACTION_MOVE, button, gApplication::lastEvent());
 #endif
 	if (!ct)
 		return NULL;
@@ -395,15 +399,19 @@ gControl *gDrag::drag(gControl *source, GtkTargetList *list)
 			g_object_unref(G_OBJECT(icon));
 	}
 	
+	source->_dragging = true;
+	
 	_end = false;
 	while (!_end)
 		MAIN_do_iteration(true);
 	
+	source->_dragging = false;
+	
 	gtk_target_list_unref(list);	
 	
 	dest = _destination;
 	cancel();
-	
+
 #if DEBUG_ME
 	fprintf(stderr, "gDrag::drag: end\n");
 #endif
@@ -414,45 +422,45 @@ gControl *gDrag::drag(gControl *source, GtkTargetList *list)
 gControl *gDrag::dragText(gControl *source, char *text, char *format)
 {
 	GtkTargetList *list;
-	
+
 	//cancel();
-	
+
 	#if DEBUG_ME
 		fprintf(stderr, "gDrag::dragText: %s\n", text);
 	#endif
 
 	setDropText(text);
-	
+
 	list = gtk_target_list_new (NULL, 0);
 	if (format)
 		gtk_target_list_add(list, gdk_atom_intern(format, false), 0, 0);
 	gtk_target_list_add_text_targets(list, 0);
-	
+
 	//gtk_target_list_add (list,gdk_atom_intern("UTF8_STRING",false),0,0);
 	//gtk_target_list_add (list,gdk_atom_intern("COMPOUND_TEXT",false),0,0);
 	//gtk_target_list_add (list,gdk_atom_intern("TEXT",false),0,0);
 	//gtk_target_list_add (list,GDK_TARGET_STRING,0,0);
 	//gtk_target_list_add (list,gdk_atom_intern("text/plain;charset=utf-8",false),0,0);
 	//gtk_target_list_add (list,gdk_atom_intern("text/plain",false),0,0);
-	
+
 	setDropInfo(Text, format);
-	
+
 	return drag(source, list);
 }
 
 gControl *gDrag::dragImage(gControl *source, gPicture *image)
 {
 	GtkTargetList *list;
-	
+
 	setDropImage(image);
-	
+
 	list = gtk_target_list_new (NULL,0);
-	
+
 	gtk_target_list_add(list, gdk_atom_intern("image/png", false), 0, 0);
 	gtk_target_list_add(list, gdk_atom_intern("image/jpg", false), 0, 0);
 	gtk_target_list_add(list, gdk_atom_intern("image/jpeg", false), 0, 0);
 	gtk_target_list_add(list, gdk_atom_intern("image/gif", false), 0, 0);
-	
+
 	setDropInfo(Image, NULL);
 
 	return drag(source, list);
@@ -461,8 +469,12 @@ gControl *gDrag::dragImage(gControl *source, gPicture *image)
 void gDrag::setDropInfo(int type, char *format)
 {
 	_type = type;
-	g_free(_format);
-	_format = g_strdup(format);
+	if (_format)
+		g_free(_format);
+	if (format)
+		_format = g_strdup(format);
+	else
+		_format = NULL;
 }
 
 
@@ -477,13 +489,13 @@ void gDrag::setDropData(int action, int x, int y, gControl *source, gControl *de
 	_action = action;
 	_source = source;
 	_destination = dest;
-	_active = true;
+	_has_data = true;
 }
 
 void gDrag::setDropText(char *text, int len)
 {
 	#if DEBUG_ME
-		fprintf(stderr, "gDrag::setDropText: text = '%s' %d\n", text, len);
+		fprintf(stderr, "gDrag::setDropText: text = '%s' %d\n", text ? text : "(null)", len);
 	#endif
 
 	g_free(_text);
@@ -511,9 +523,9 @@ void gDrag::setDropImage(char *buf, int len)
 {
 	GdkPixbufLoader *ld;
 	GdkPixbuf *pixbuf = NULL;
-	
+
 	//g_debug("gDrag::setDropImage: buf = %p len = %d\n", buf, len);
-	
+
 	if (buf && len > 0)
 	{
 		ld = gdk_pixbuf_loader_new ();
@@ -524,7 +536,7 @@ void gDrag::setDropImage(char *buf, int len)
 		}
 		g_object_unref(G_OBJECT(ld));
 	}
-	
+
 	if (pixbuf)
 		setDropImage(new gPicture(pixbuf));
 	else
@@ -537,14 +549,14 @@ bool gDrag::checkThreshold(gControl *control, int x, int y, int sx, int sy)
 		return false;
 	else
 		return gtk_drag_check_threshold(control->border, sx, sy, x, y);
-} 
+}
 
 GdkDragContext *gDrag::enable(GdkDragContext *context, gControl *control, guint32 time)
 {
 	GdkDragContext *old = _context;
 
 	#if DEBUG_ME
-		fprintf(stderr, "gDrag::enable\n");
+		fprintf(stderr, "gDrag::enable: %p -> %p\n", old, context);
 	#endif
 
 	_enabled++;
@@ -559,7 +571,7 @@ GdkDragContext *gDrag::disable(GdkDragContext *context)
 	GdkDragContext *old = _context;
 
 	#if DEBUG_ME
-		fprintf(stderr, "gDrag::disable\n");
+		fprintf(stderr, "gDrag::disable: %p -> %p\n", old, context);
 	#endif
 
 	_context = context;
@@ -567,151 +579,34 @@ GdkDragContext *gDrag::disable(GdkDragContext *context)
 	return old;
 }
 
-//static GtkWidget *_frame_container = 0;
-static GdkWindow *_frame[4] = { 0 };
-static bool _frame_visible = false;
-static gControl *_frame_control = 0;
-
-static void hide_frame(gControl *control)
-{
-	int i;
-	
-	if (!_frame_visible)
-		return;
-		
-	if (control && control != _frame_control)
-		return;
-		
-	for (i = 0; i < 4; i++)
-		gdk_window_destroy(_frame[i]);
-		
-	_frame_visible = false;
-}
-
-static void move_frame_border(GdkWindow *window, int x, int y, int w, int h)
-{
-	gdk_window_move_resize(window, x, y, w, h);
-}
-
-static void show_frame(gControl *control, int x, int y, int w, int h)
-{
-	int i;
-	GdkWindowAttr attr = { 0 };
-	GdkWindow *window;
-	GdkWindow *parent;
-	GtkAllocation a;
-	
-	if (w < 0) w = control->width() - control->getFrameWidth() * 2;
-	if (h < 0) h = control->height() - control->getFrameWidth() * 2;
-	
-	if (w < 2 || h < 2)
-		return;
-	
-	//g_debug("show %p %d %d %d %d", control->border->window, x, y, w, h);
-	
-	if (control != _frame_control)
-		hide_frame(NULL);
-		
-	// Don't know why I should do that...
-	if (control->_scroll)
-	{
-		parent = gtk_widget_get_window(control->widget);
-	}
-	else
-	{
-		parent = gtk_widget_get_window(control->border);
-		gtk_widget_get_allocation(control->border, &a);
-		x += a.x;
-		y += a.y;
-	}
-	
-	
-	if (!_frame_visible)
-	{
-#ifdef GTK3
-		GdkRGBA rgba;
-		gt_from_color(0, &rgba);
-#else
-		GdkColor color;
-		fill_gdk_color(&color, 0);
-#endif
-		
-		attr.wclass = GDK_INPUT_OUTPUT;
-		attr.window_type = GDK_WINDOW_CHILD;
-		
-		for (i = 0; i < 4; i++)
-		{
-			window = gdk_window_new(parent, &attr, 0);
-#ifdef GTK3
-			gdk_window_set_background_rgba(window, &rgba);
-#else
-			gdk_window_set_background(window, &color);
-#endif
-			_frame[i] = window;
-		}
-	}
-	
-	//x -= 2;
-	//y -= 2;
-	//w += 4;
-	//h += 4;
-	move_frame_border(_frame[0], x, y, w, 2);
-	move_frame_border(_frame[1], x, y, 2, h);
-	move_frame_border(_frame[2], x + w - 2, y, 2, h);
-	move_frame_border(_frame[3], x, y + h - 2, w, 2);
-	
-	for (i = 0; i < 4; i++)
-		gdk_window_show(_frame[i]);
-	
-	_frame_control = control;
-	_frame_visible = true;
-}
-
-// static gboolean
-// cb_drag_highlight_expose (GtkWidget *widget,
-// 			   GdkEventExpose *event,
-// 			   gpointer        data)
-// {
-//   gint x, y, width, height;
-//   
-//   if (GTK_WIDGET_DRAWABLE (widget))
-//   {
-// 		cairo_t *cr;
-// 		
-// 		gDrag::getHighlight(&x, &y, &width, &height);
-// 		
-// 		if (GTK_WIDGET_NO_WINDOW (widget))
-// 		{
-// 			x += widget->allocation.x;
-// 			y += widget->allocation.y;
-// 		}
-// 
-// 		gtk_paint_shadow (widget->style, widget->window,
-// 					GTK_STATE_NORMAL, GTK_SHADOW_OUT,
-// 					NULL, widget, "dnd",
-// 		x, y, width, height);
-// 		
-// 		cr = gdk_cairo_create (widget->window);
-// 		cairo_set_source_rgb (cr, 0.0, 0.0, 0.0); /* black */
-// 		cairo_set_line_width (cr, 1.0);
-// 		cairo_rectangle (cr,
-// 					x + 0.5, y + 0.5,
-// 					width - 1, height - 1);
-// 		cairo_stroke (cr);
-// 		cairo_destroy (cr);
-// 	}
-// 
-//   return FALSE;
-// }
-
 void gDrag::show(gControl *control, int x, int y, int w, int h)
 {
-	show_frame(control, x, y, w, h);
+	static GB_FUNCTION func;
+	static bool init = FALSE;
+
+	if (!init)
+	{
+		GB.GetFunction(&func, (void *)GB.FindClass("_Gui"), "_ShowDNDFrame", NULL, NULL);
+		init = TRUE;
+	}
+
+	GB.Push(5, GB_T_OBJECT, control->hFree, GB_T_INTEGER, x, GB_T_INTEGER, y, GB_T_INTEGER, w, GB_T_INTEGER, h);
+	GB.Call(&func, 5, FALSE);
 }
 
 void gDrag::hide(gControl *control)
 {
-	hide_frame(control);
+	static GB_FUNCTION func;
+	static bool init = FALSE;
+
+	if (!init)
+	{
+		GB.GetFunction(&func, (void *)GB.FindClass("_Gui"), "_HideDNDFrame", NULL, NULL);
+		init = TRUE;
+	}
+
+	GB.Push(1, GB_T_OBJECT, control ? control->hFree : NULL);
+	GB.Call(&func, 1, FALSE);
 }
 
 
@@ -719,25 +614,25 @@ char *gDrag::getFormat(int n)
 {
 	GList *tg;
 	gchar *format, *cformat;
-	
+
 	//if (gDrag::getType()) // local DnD
 	//	return;
-	
+
 	//g_debug("set_from_context: non local\n");
-	
+
 	if (_format)
 		return n == 0 ? _format : NULL;
-		
+
 	if (!_context)
 		return NULL;
-	
+
 	tg = g_list_first(gdk_drag_context_list_targets(_context));
-	
+
 	while (tg)
 	{
 		format = gdk_atom_name((GdkAtom)tg->data);
 		cformat = convert_format(format);
-		
+
 		if (islower(cformat[0]))
 		{
 			if (n <= 0)
@@ -747,11 +642,11 @@ char *gDrag::getFormat(int n)
 			}
 			n--;
 		}
-		
+
 		g_free(format);
 		tg = g_list_next(tg);
 	}
-	
+
 	return NULL;
 }
 
@@ -759,16 +654,16 @@ int gDrag::getType()
 {
 	int i;
 	char *format;
-	
+
 	if (_type)
 		return _type;
-	
+
 	for (i = 0;; i++)
 	{
 		format = getFormat(i);
 		if (!format)
 			return Nothing;
-		if (strlen(format) >= 5 && !strncasecmp(format, "text/", 5)) 
+		if (strlen(format) >= 5 && !strncasecmp(format, "text/", 5))
 			return Text;
 		if (strlen(format) >= 6 &&! strncasecmp(format, "image/", 6))
 			return Image;
@@ -788,7 +683,7 @@ static void cb_drag_data_received(GtkWidget *widget, GdkDragContext *context, gi
 		else
 			gDrag::setDropText(NULL);
 	}
-	
+
 	if (gDrag::getType() == gDrag::Image)
 	{
 		//fprintf(stderr, "Image\n");
@@ -797,7 +692,7 @@ static void cb_drag_data_received(GtkWidget *widget, GdkDragContext *context, gi
 		else
 			gDrag::setDropImage(NULL);
 	}
-	
+
 	gDrag::_got_data = true;
 }
 
@@ -810,25 +705,25 @@ bool gDrag::getData(const char *prefix)
 	gulong id;
 	static bool norec = false;
 	gControl *dest;
-	
+
 #if DEBUG_ME
 	fprintf(stderr, "getData: norec = %d _local = %d\n", norec, _local);
 #endif
-	
+
 	if (norec || _local) // local DnD
 		return false;
-	
+
 	tg = g_list_first(gdk_drag_context_list_targets(_context));
-	
+
 	while (tg)
 	{
 		g_free(format);
 		format = gdk_atom_name((GdkAtom)tg->data);
 		cfmt = convert_format(format);
 		//fprintf(stderr, "getData: prefix = %s format = '%s'\n", prefix, format);
-		
+
 		if (strlen(cfmt) >= strlen(prefix) && !strncasecmp(cfmt, prefix, strlen(prefix)))
-		{ 
+		{
 			g_free(format);
 
 			dest = _dest;
@@ -837,25 +732,25 @@ bool gDrag::getData(const char *prefix)
 			//fprintf(stderr, "gDrag::getData: g_signal_connect -> %p %ld\n", dest->border, id);
 
 			_got_data = false;
-			
+
 			norec = true;
-			
+
 			gtk_drag_get_data (_dest->border, _context, (GdkAtom)tg->data, _time);
-			
+
 			while (!_got_data)
 				MAIN_do_iteration(true);
-	
+
 			norec = false;
-			
+
 			//fprintf(stderr, "gDrag::getData: g_signal_disconnect -> %p %ld\n", dest->border, id);
 			g_signal_handler_disconnect(dest->border, id);
 
 			return false;
 		}
-			
+
 		tg = g_list_next(tg);
 	}
-	
+
 	g_free(format);
 	return true;
 }
@@ -863,10 +758,14 @@ bool gDrag::getData(const char *prefix)
 char *gDrag::getText(int *len, const char *format, bool fromOutside)
 {
 	//setDropText(NULL);
-	
+
+#if DEBUG_ME
+	fprintf(stderr, "gDrag::getText: %s / %d\n", format, fromOutside);
+#endif
+
 	if (!format)
 		format = "text/";
-	
+
 	if (!fromOutside && getData(format))
 	{
 		*len = 0;
@@ -874,6 +773,9 @@ char *gDrag::getText(int *len, const char *format, bool fromOutside)
 	}
 	else
 	{
+#if DEBUG_ME
+	fprintf(stderr, "gDrag::getText: -> %d / %s \n", _text_len, _text);
+#endif
 		*len = _text_len;
 		return _text;
 	}
@@ -883,15 +785,48 @@ gPicture *gDrag::getImage(bool fromOutside)
 {
 	if (_picture)
 		return _picture;
-		
+
 	if (!fromOutside && getData("image/"))
 		return NULL;
-	
+
 	return _picture;
 }
 
 void gDrag::end()
 {
 	_end = true;
+	_has_data = false;
 	_active = false;
 }
+
+
+bool gDrag::setCurrent(gControl *control)
+{
+	gControl *current;
+	
+	//fprintf(stderr, "gDrag::setCurrent: %s -> %s\n", _current ? _current->name() : "NULL", control ? control->name() : "NULL");
+
+	if (_current == control)
+		return false;
+	
+	if (_current)
+	{
+		current = _current;
+		while (current)
+		{
+			CB_control_drag_leave(current);
+			current = current->_proxy_for;
+		}
+	}
+	
+	_current = control;
+	
+	while (control)
+	{
+		if (CB_control_drag(control))
+			return true;
+		control = control->_proxy_for;
+	}
+	
+	return false;
+}
