@@ -2,7 +2,7 @@
 
   gtextbox.h
 
-  (c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
+  (c) 2000-2017 Benoît Minisini <benoit.minisini@gambas-basic.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 class gTextBox : public gControl
 {
 public:
-	gTextBox(gContainer *parent, bool combo = false);
+	gTextBox(gContainer *parent);
 	~gTextBox();
 
 //"Properties"
@@ -70,10 +70,6 @@ public:
 	virtual void customStyleSheet(GString *css);
 #endif
 	
-//"Signals"
-	void (*onChange)(gTextBox *sender);
-	void (*onActivate)(gTextBox *sender);
-
 //"Private"
   virtual void updateCursor(GdkCursor *cursor);
   void initEntry();
@@ -94,10 +90,14 @@ public:
 	unsigned _changed : 1;
 	unsigned _has_border : 1;
 	unsigned _text_area_visible : 1;
-
-#ifndef GTK3
+	
+	int _last_position;
 	char *_placeholder;
-#endif
 };
 
+// Callbacks
+void CB_textbox_change(gTextBox *sender);
+void CB_textbox_activate(gTextBox *sender);
+void CB_textbox_cursor(gTextBox *sender);
+
 #endif
