@@ -55,7 +55,7 @@
 #include "CButton.h"
 #include "CTextBox.h"
 #include "CTextArea.h"
-#include "CSlider.h"
+#include "CScrollBar.h"
 #include "CTabStrip.h"
 #include "CTrayIcon.h"
 #include "cprinter.h"
@@ -220,7 +220,6 @@ GB_DESC *GB_CLASSES[] EXPORT =
 	CWindowDesc,
 	CWindowsDesc,
 	CFormDesc,
-	SliderDesc,
 	ScrollBarDesc,
 	CButtonDesc,
 	CToggleButtonDesc,
@@ -595,21 +594,21 @@ static void hook_wait(int duration)
 	{
 		MAIN_do_iteration(true);
 	}
-	else if (duration == -1)
+	else if (duration == GB_WAIT_NO_USER_INPUT)
 	{
 		bool d = gApplication::disableInputEvents(true);
 		int i;
 		
 		for (i = 0; i < 256; i++)
 		{
-			if (!gApplication::eventsPending())
+			if (!gApplication::eventsPending() && !_post_check)
 				break;
 			MAIN_do_iteration(true);
 		}
 
 		gApplication::disableInputEvents(d);
 	}
-	else if (duration == -2)
+	else if (duration == GB_WAIT_FOR_NEXT_EVENT)
 		MAIN_do_iteration(false);
 }
 
