@@ -30,36 +30,49 @@
 #include "CDrawingArea.h"
 #include "CScreen.h"
 
+#include "gb.form.const.h"
+#include "gb.form.gui.h"
 #include "gtrayicon.h"
 #include "gapplication.h"
 #include "gmainwindow.h"
 #include "cpaint_impl.h"
-#include "desktop.h"
 
 extern int CWINDOW_Embedder;
 extern bool CWINDOW_Embedded;
 
 extern int MAIN_scale;
 
-char *CAPPLICATION_Theme = 0;
+char *CAPPLICATION_Theme = NULL;
 GB_ARRAY CAPPLICATION_Restart = NULL;
+bool CAPPLICATION_MiddleClickPaste = TRUE;
 
 static int _busy = 0;
 
 #define MAX_SCREEN 16
 static CSCREEN *_screens[MAX_SCREEN] = { NULL };
 
-static bool _animations = FALSE;
-static bool _shadows = FALSE;
+static bool _animations = false;
+static bool _shadows = false;
+static int _change = CHANGE_NONE;
 
 //-------------------------------------------------------------------------
 
-static void send_change_event()
+void APPLICATION_send_change_event(int change)
 {
+	GB_FUNCTION func;
+
+	_change = change;
+
+	if (GB.GetFunction(&func, (void *)GB.Application.StartupClass(), "Application_Change", "", "") == 0)
+		GB.Call(&func, 0, FALSE);
+	else
+		GB.Error(NULL);
+
 	CDRAWINGAREA_send_change_event();
 	CUSERCONTROL_send_change_event();
-}
 
+	_change = CHANGE_NONE;
+}
 
 static CSCREEN *get_screen(int num)
 {
@@ -161,12 +174,6 @@ BEGIN_PROPERTY(Desktop_Scale)
 
 END_PROPERTY
 
-BEGIN_PROPERTY(Desktop_Type)
-
-	GB.ReturnConstZeroString(DESKTOP_get_type());
-
-END_PROPERTY
-
 BEGIN_PROPERTY(Desktop_Platform)
 
 	#ifdef GTK3
@@ -262,12 +269,22 @@ BEGIN_PROPERTY(Application_Animations)
 	else if (_animations != VPROP(GB_BOOLEAN))
 	{
 		_animations = VPROP(GB_BOOLEAN);
-		send_change_event();
+		APPLICATION_send_change_event(CHANGE_ANIMATION);
 	}
 
 END_PROPERTY
 
 
+BEGIN_PROPERTY(Application_MiddleClickPaste)
+
+	if (READ_PROPERTY)
+		GB.ReturnBoolean(CAPPLICATION_MiddleClickPaste);
+	else
+		CAPPLICATION_MiddleClickPaste = VPROP(GB_BOOLEAN);
+
+END_PROPERTY
+
+
 BEGIN_PROPERTY(Application_Shadows)
 
 	if (READ_PROPERTY)
@@ -275,7 +292,7 @@ BEGIN_PROPERTY(Application_Shadows)
 	else if (_shadows != VPROP(GB_BOOLEAN))
 	{
 		_shadows = VPROP(GB_BOOLEAN);
-		send_change_event();
+		APPLICATION_send_change_event(CHANGE_SHADOW);
 	}
 
 END_PROPERTY
@@ -323,35 +340,24 @@ END_PROPERTY
 
 BEGIN_PROPERTY(Application_Theme)
 
-	if (READ_PROPERTY) { GB.ReturnString(CAPPLICATION_Theme); return; }
-	GB.StoreString(PROP(GB_STRING), &CAPPLICATION_Theme);
+	if (READ_PROPERTY)
+		GB.ReturnString(CAPPLICATION_Theme);
+	else if (GB.CheckString(PROP(GB_STRING), CAPPLICATION_Theme))
+	{
+		GB.StoreString(PROP(GB_STRING), &CAPPLICATION_Theme);
+		CALL_GUI("_OnApplicationThemeChange", NULL, NULL, 0, FALSE);
+		APPLICATION_send_change_event(CHANGE_THEME);
+	}
 
 END_PROPERTY
 
 
 BEGIN_PROPERTY(Application_DarkTheme)
 
-	static bool _init = FALSE;
-	static bool _dark = FALSE;
-	
-	uint bg;
-	char *env;
-	
-	if (!_init)
-	{
-		_init = TRUE;
-		bg = gDesktop::getColor(gDesktop::BACKGROUND);
-		if (IMAGE.GetLuminance(bg) >= 128)
-		{
-			env = getenv("GB_GUI_DARK_THEME");
-			if (env && atoi(env))
-				_dark = TRUE;
-		}
-		else
-			_dark = TRUE;
-	}
-
-	GB.ReturnBoolean(_dark);
+	if (READ_PROPERTY)
+		GB.ReturnBoolean(gApplication::isDarkTheme());
+	else
+		gApplication::setDarkTheme(VPROP(GB_BOOLEAN));
 
 END_PROPERTY
 
@@ -372,6 +378,21 @@ BEGIN_PROPERTY(Application_DblClickTime)
 
 END_PROPERTY
 
+
+BEGIN_PROPERTY(Application_Change)
+
+	switch(_change)
+	{
+		case CHANGE_FONT: GB.ReturnConstZeroString("font"); break;
+		case CHANGE_COLOR: GB.ReturnConstZeroString("color"); break;
+		case CHANGE_ANIMATION: GB.ReturnConstZeroString("animation"); break;
+		case CHANGE_SHADOW: GB.ReturnConstZeroString("shadow"); break;
+		case CHANGE_THEME: GB.ReturnConstZeroString("theme"); break;
+		default: GB.ReturnVoidString();
+	}
+
+END_PROPERTY
+
 //-------------------------------------------------------------------------
 
 BEGIN_PROPERTY(Screens_Count)
@@ -521,7 +542,6 @@ GB_DESC DesktopDesc[] =
 	
 	GB_STATIC_METHOD("Screenshot", "Picture", Desktop_Screenshot, "[(X)i(Y)i(Width)i(Height)i]"),
 
-	GB_STATIC_PROPERTY_READ("Type", "s", Desktop_Type),
 	GB_STATIC_PROPERTY_READ("Platform", "s", Desktop_Platform),
 
 	GB_END_DECLARE
@@ -542,12 +562,14 @@ GB_DESC ApplicationDesc[] =
 	GB_STATIC_PROPERTY("ShowTooltips", "b", Application_ShowTooltips),
 	GB_STATIC_PROPERTY("Animations", "b", Application_Animations),
 	GB_STATIC_PROPERTY("Shadows", "b", Application_Shadows),
+	GB_STATIC_PROPERTY("MiddleClickPaste", "b", Application_MiddleClickPaste),
 	GB_STATIC_PROPERTY("Embedder", "i", Application_Embedder),
 	GB_STATIC_PROPERTY("Theme", "s", Application_Theme),
-	GB_STATIC_PROPERTY_READ("DarkTheme", "s", Application_DarkTheme),
+	GB_STATIC_PROPERTY("DarkTheme", "s", Application_DarkTheme),
 	GB_STATIC_PROPERTY("Restart", "String[]", Application_Restart),
 	GB_STATIC_PROPERTY_READ("DblClickTime", "i", Application_DblClickTime),
-	
+	GB_STATIC_PROPERTY_READ("Change", "s", Application_Change),
+
 	GB_END_DECLARE
 };
 
