@@ -758,7 +758,7 @@ END_METHOD
 BEGIN_PROPERTY(Window_Opacity)
 
 	if (READ_PROPERTY)
-		GB.ReturnInteger(WINDOW->opacity() * 100);
+		GB.ReturnInteger(WINDOW->opacity() * 100 + 0.5);
 	else
 	{
 		double opacity = VPROP(GB_INTEGER) / 100.0;
