@@ -1592,19 +1592,22 @@ void gControl::updateAcceptDrops()
 
 bool gControl::acceptDrops() const
 {
-	if (_proxy)
+	/*if (_proxy)
 		return _proxy->acceptDrops();
-	else
+	else*/
 		return _accept_drops;
 }
 
 void gControl::setAcceptDrops(bool vl)
 {
-	if (_proxy)
+	/*if (_proxy)
 	{
 		_proxy->setAcceptDrops(vl);
 		return;
-	}
+	}*/
+	
+	if (_accept_drops == vl)
+		return;
 	
 	_accept_drops = vl;
 	updateAcceptDrops();
@@ -1745,39 +1748,42 @@ static bool _do_not_patch = false;
 
 static bool must_patch(GtkWidget *widget)
 {
-	GtkWidget *parent;
-	gControl *parent_control;
+	GtkWidget *parent, *grand_parent;
+	gControl *parent_control; //, *grand_parent_control;
 
 	if (_do_not_patch)
 		return false;
 
 	if (gt_get_control(widget))
-	{
-		//fprintf(stderr, "must_patch: %p -> 1\n", widget);
 		return true;
-	}
 
 	parent = gtk_widget_get_parent(widget);
 	if (!parent)
-	{
-		//fprintf(stderr, "must_patch: %p -> 0\n", widget);
 		return false;
-	}
 	
-	if (GTK_IS_NOTEBOOK(parent) && GTK_IS_FIXED(widget))
+	if (GTK_IS_BOX(widget) && GTK_IS_NOTEBOOK(parent))
+		return false;
+	
+	if (gt_get_control(parent))
 		return true;
 	
+	grand_parent = gtk_widget_get_parent(parent);
+	
+	if (GTK_IS_FIXED(widget))
+	{
+		if (GTK_IS_NOTEBOOK(parent))
+			return true;
+	}
+	
 	if (GTK_IS_SCROLLED_WINDOW(parent))
 	{
-		parent = gtk_widget_get_parent(parent);
-		if (!parent)
+		if (!grand_parent)
 			return false;
 	}
 	
 	if (GTK_IS_ENTRY(widget))
 	{
-		parent = gtk_widget_get_parent(parent);
-		if (GTK_IS_COMBO_BOX(parent))
+		if (grand_parent && GTK_IS_COMBO_BOX(grand_parent))
 			return true;
 	}
 
@@ -1831,7 +1837,7 @@ PATCH_DECLARE(GTK_TYPE_TEXT_VIEW)
 PATCH_DECLARE(GTK_TYPE_SCROLLBAR)
 PATCH_DECLARE(GTK_TYPE_SCALE)
 
-#if GTK_CHECK_VERSION(3,10,0)
+#if GTK_CHECK_VERSION(3, 10, 0)
 PATCH_DECLARE_BASELINE(GTK_TYPE_ENTRY)
 PATCH_DECLARE_BASELINE(GTK_TYPE_COMBO_BOX)
 PATCH_DECLARE_BASELINE(GTK_TYPE_SPIN_BUTTON)
@@ -2912,6 +2918,9 @@ void gControl::createBorder(GtkWidget *new_border, bool keep_widget)
 		createWidget();
 	}
 
+#ifdef GTK3
+	gt_patch_control(border);
+#endif
 	updateAcceptDrops();
 }
 
@@ -2978,3 +2987,33 @@ void gControl::checkVisibility()
 	_allow_show = true;
 	setVisibility(_visible);
 }
+
+CWIDGET_PROXY *gControl::saveProxy()
+{
+	CWIDGET_PROXY *data = new CWIDGET_PROXY;
+	
+	data->bg = background();
+	data->fg = foreground();
+	data->mouse = mouse();
+	data->cursor = cursor();
+	//data->drop = acceptDrops();
+	data->no_tab_focus = isNoTabFocus();
+	data->tracking = isTracking();
+	
+	return data;
+}
+
+void gControl::applyProxy(CWIDGET_PROXY *data)
+{
+	setBackground(data->bg);
+	setForeground(data->fg);
+	setMouse(data->mouse);
+	setCursor(data->cursor);
+	if (data->cursor)
+		delete data->cursor;
+	//setAcceptDrops(data->drop);
+	setNoTabFocus(data->no_tab_focus);
+	setTracking(data->tracking);
+	
+	delete data;
+}
