@@ -124,6 +124,13 @@ static gboolean cb_show(GtkWidget *widget, gMainWindow *data)
 		CB_window_show(data);
 	}
 
+	double op = data->opacity();
+	if (op < 1)
+	{
+		data->setOpacity(1);
+		data->setOpacity(op);
+	}
+	
 	data->_not_spontaneous = false;
 	return false;
 }
@@ -245,8 +252,8 @@ static gboolean cb_configure(GtkWidget *widget, GdkEventConfigure *event, gMainW
 
 	data->calcCsdSize();
 
-	data->bufW = event->width - data->_csd_w;
-	data->bufH = event->height - data->_csd_h;
+	data->bufW = event->width - Max(0, data->_csd_w);
+	data->bufH = event->height - Max(0, data->_csd_h);
 	
 	if (data->isTopLevel() && !data->_minimized && !data->_maximized && !data->_fullscreen)
 	{
@@ -699,13 +706,11 @@ void gMainWindow::updateSize()
 	else
 	{
 		setGeometryHints();
+		
 		if (isResizable())
 			gtk_window_resize(GTK_WINDOW(border), width(), height());
 		else
-		{
-			//fprintf(stderr, "gMainWindow::updateSize: %s: %d %d\n", name(), width() + Max(_csd_w, 0), height() + Max(_csd_h, 0));
 			gtk_widget_set_size_request(border, width() + Max(_csd_w, 0), height() + Max(_csd_h, 0));
-		}
 
 		if (isVisible())
 			gtk_widget_show(border);
@@ -1452,6 +1457,7 @@ void gMainWindow::reparent(gContainer *newpr, int x, int y)
 	int w, h;
 	gColor fg, bg;
 	bool was_visible;
+	double op;
 
 	if (_xembed)
 		return;
@@ -1459,6 +1465,7 @@ void gMainWindow::reparent(gContainer *newpr, int x, int y)
 	bg = background();
 	fg = foreground();
 	was_visible = isVisible();
+	op = opacity();
 
 	if (isTopLevel() && newpr)
 	{
@@ -1515,6 +1522,7 @@ void gMainWindow::reparent(gContainer *newpr, int x, int y)
 		
 		setBackground(bg);
 		setForeground(fg);
+		setOpacity(op);
 		setFont(font());
 		setText(text());
 
@@ -1947,6 +1955,8 @@ void gMainWindow::setGeometryHints()
 		fprintf(stderr, "setGeometryHints: %s: min size: %d %d (%d x %d)\n", name(), geometry.min_width, geometry.min_height, width(), height());
 		#endif
 		gtk_window_set_geometry_hints(GTK_WINDOW(border), NULL, &geometry, (GdkWindowHints)(GDK_HINT_MIN_SIZE | GDK_HINT_MAX_SIZE));
+		gtk_window_set_resizable(GTK_WINDOW(border), isResizable());
+
 		//gdk_window_set_geometry_hints(gtk_widget_get_window(border), &geometry, (GdkWindowHints)(GDK_HINT_MIN_SIZE | GDK_HINT_POS));
 	}
 }
@@ -1998,6 +2008,7 @@ void gMainWindow::setTransparent(bool vl)
 
 #ifdef GTK3
 	gtk_widget_set_visual(border, visual);
+	gtk_window_resize(GTK_WINDOW(border), width(), height());
 #else
 	gtk_widget_set_colormap(border, colormap);
 #endif
