@@ -358,6 +358,10 @@ void gMenu::update()
 					parent->_popup = (GtkMenu *)gtk_menu_new();
 					g_object_ref_sink(parent->_popup);
 					
+					#if GTK_CHECK_VERSION(2, 18, 0)
+					gtk_menu_set_reserve_toggle_size(parent->_popup, FALSE);
+					#endif
+					
 					//fprintf(stderr, "creates a new child menu container in parent %s\n", parent->name());
 					
 					//g_signal_connect(G_OBJECT(parent->_popup), "size-allocate", G_CALLBACK(cb_size_allocate), (gpointer)parent);
@@ -424,6 +428,12 @@ void gMenu::update()
 		
 		//setColor();
 		setFont();
+
+		if (_disabled)
+		{
+			gtk_widget_set_sensitive(GTK_WIDGET(menu), FALSE);
+			updateShortcutRecursive();
+		}
 	}
 
 	//g_debug("%p: END UPDATE", this);	
@@ -663,7 +673,7 @@ bool gMenu::isFullyEnabled() const
 		if (menu->_exec)
 			return true;
 
-		if (!menu->isEnabled())
+		if (!menu->isEnabled() || !menu->isVisible())
 			return false;
 
 		if (menu->isTopLevel())
@@ -688,7 +698,7 @@ void gMenu::updateShortcut()
 		_shortcut_key = 0;
 	}
 	
-	if (isFullyEnabled() && _shortcut)
+	if (isVisible() && isFullyEnabled() && _shortcut)
 	{
 		gt_shortcut_parse(_shortcut, &_shortcut_key, &_shortcut_mods);
 		if (_shortcut_key)
@@ -704,8 +714,8 @@ void gMenu::updateShortcutRecursive()
 	gMenu *ch;
 	int i;
 	
-	if (_exec)
-		return;
+	/*if (_exec)
+		return;*/
 
 	updateShortcut();
 
@@ -729,7 +739,7 @@ void gMenu::setText(const char *text)
 	update();
 }
 
-bool gMenu::isVisible()
+bool gMenu::isVisible() const
 {
 	if (!menu) return false;
 	return _visible;	
@@ -745,6 +755,7 @@ void gMenu::updateVisible()
 	//fprintf(stderr, "gMenu::updateVisible: %s '%s' %d\n", name(), text(), vl);
 	
 	gtk_widget_set_visible(GTK_WIDGET(menu), vl);
+	updateShortcutRecursive();
 	//g_object_set(G_OBJECT(menu),"visible",vl,(void *)NULL);
 	
 	if (_toplevel && pr)
@@ -837,7 +848,7 @@ static void position_menu(GtkMenu *menu, gint *x, gint *y, gboolean *push_in, Me
 }
 #endif
 
-void gMenu::doPopup(bool move, int x, int y)
+void gMenu::doPopup(bool move, int x, int y, gControl *ref)
 {
 	if (!_popup)
 		return;
@@ -851,7 +862,8 @@ void gMenu::doPopup(bool move, int x, int y)
 	_in_popup++;
 	_popup_count++;
 	_exec = true;
-	
+	updateShortcutRecursive();
+
 #if GTK_CHECK_VERSION(3, 22, 0)
 
 	GdkWindow *win;
@@ -873,7 +885,7 @@ void gMenu::doPopup(bool move, int x, int y)
 	else
 	{
 		event->button.button = 1;
-		event->button.window = gtk_widget_get_window(window()->border);
+		event->button.window = ref ? gtk_widget_get_window(ref->window()->border) : gtk_widget_get_window(window()->border);
 	}
 	
 	gdk_event_set_device(event, gMouse::getPointer());
@@ -920,6 +932,7 @@ void gMenu::doPopup(bool move, int x, int y)
 		MAIN_do_iteration(false);
 
 	_exec = false;
+	updateShortcutRecursive();
 
 	_current_popup = save_current_popup;
 	gApplication::_popup_grab = save_grab;
@@ -938,9 +951,9 @@ void gMenu::doPopup(bool move, int x, int y)
 		MAIN_do_iteration(false);
 }
 
-void gMenu::popup(int x, int y)
+void gMenu::popup(int x, int y, gControl *ref)
 {
-	doPopup(true, x, y);
+	doPopup(true, x, y, ref);
 }
 
 void gMenu::popup()
@@ -1131,8 +1144,8 @@ void gMenu::setFont()
 {
 	gMainWindow *win = window();
 #ifdef GTK3
-	if (label) gt_widget_update_css(GTK_WIDGET(label), win->font(), COLOR_DEFAULT, COLOR_DEFAULT);
-	if (shlabel) gt_widget_update_css(GTK_WIDGET(shlabel), win->font(), COLOR_DEFAULT, COLOR_DEFAULT);
+	if (label) gt_widget_update_css(GTK_WIDGET(label), win->font(), GB_COLOR_DEFAULT, GB_COLOR_DEFAULT);
+	if (shlabel) gt_widget_update_css(GTK_WIDGET(shlabel), win->font(), GB_COLOR_DEFAULT, GB_COLOR_DEFAULT);
 #else
 	if (label) gtk_widget_modify_font(GTK_WIDGET(label), win->font()->desc());
 	if (shlabel) gtk_widget_modify_font(GTK_WIDGET(shlabel), win->font()->desc());
@@ -1187,7 +1200,7 @@ void gMenu::updateFont(gMainWindow *win)
 	{
 		//fprintf(stderr, "set menu bar font\n");
 #ifdef GTK3
-		gt_widget_update_css(GTK_WIDGET(win->menuBar), win->ownFont() ? win->font() : NULL, COLOR_DEFAULT, COLOR_DEFAULT);
+		gt_widget_update_css(GTK_WIDGET(win->menuBar), win->ownFont() ? win->font() : NULL, GB_COLOR_DEFAULT, GB_COLOR_DEFAULT);
 #else
 		gtk_widget_modify_font(GTK_WIDGET(win->menuBar), win->ownFont() ? win->font()->desc() : NULL);
 #endif
