@@ -387,7 +387,9 @@ void gMouse::finishEvent()
 {
 	if (_control)
 	{
+		validate();
 		CB_control_mouse(_control, gEvent_MouseRelease);
+		invalidate();
 		_control = NULL;
 	}
 }
