@@ -154,6 +154,8 @@ struct _GtkTextViewPrivate
   guint in_scroll : 1;
 };
 
+#define TEXT_AREA(_textview) (gtk_text_view_get_window(GTK_TEXT_VIEW(_textview), GTK_TEXT_WINDOW_TEXT))
+
 #else
 
 // Private structure took from GTK+ 2.10 code. Used for setting the text area cursor.
@@ -178,6 +180,9 @@ void gtk_text_layout_get_size(struct _GtkTextLayout  *layout, gint *width, gint
 void gtk_text_layout_invalidate (struct _GtkTextLayout *layout, const GtkTextIter *start, const GtkTextIter *end);
 void gtk_text_layout_validate (struct _GtkTextLayout *layout, gint max_pixels);
 }
+
+#define TEXT_AREA(_textview) (((PrivateGtkTextWindow *)GTK_TEXT_VIEW(_textview)->text_window)->bin_window)
+
 #endif
 
 #if !GLIB_CHECK_VERSION(2, 32, 0)
@@ -326,7 +331,8 @@ void gTextAreaAction::addText(char *add, int len)
 
 static void cb_changed(GtkTextBuffer *buf, gTextArea *data)
 {
-	data->emit(SIGNAL(data->onChange));
+	data->updateFixSpacing();
+	CB_textarea_change(data);
 } 
 
 static void cb_mark_set(GtkTextBuffer *buf, GtkTextIter *location, GtkTextMark *mark, gTextArea *data)
@@ -341,7 +347,7 @@ static void cb_insert_text(GtkTextBuffer *buf, GtkTextIter *location, gchar *tex
 	
 	if (gKey::gotCommit())
 	{
-		gcb_im_commit(NULL, text, NULL);
+		gcb_im_commit(NULL, text, ctrl);
 		if (gKey::canceled())
 		{
 			g_signal_stop_emission_by_name(G_OBJECT(buf), "insert-text");
@@ -463,43 +469,84 @@ static gboolean cb_keypress(GtkWidget *widget, GdkEvent *event, gTextArea *ctrl)
 	return false;
 }
 
+#ifdef GTK3
+static gboolean cb_border_draw(GtkWidget *wid, cairo_t *cr, gTextArea *control)
+{
+	gt_draw_border(cr, gtk_widget_get_style_context(wid), gtk_widget_get_state_flags(control->widget), control->getBorder() ? BORDER_SUNKEN : BORDER_NONE, GB_COLOR_DEFAULT, 0, 0, control->width(), control->height(), TRUE);
+	return false;
+}
+#else
+static gboolean cb_border_expose(GtkWidget *wid, GdkEventExpose *e, gTextArea *control)
+{
+	GdkRectangle clip;
+	gdk_region_get_clipbox(e->region, &clip);
+
+	gt_draw_border(wid, &clip, control->getBorder() ? BORDER_SUNKEN : BORDER_NONE, GB_COLOR_DEFAULT, TRUE);
+	return false;
+}
+#endif
+
 // TextArea
 
 gTextArea::gTextArea(gContainer *parent) : gControl(parent)
 {
-	g_typ = Type_gTextArea;
 	_align_normal = false;
 	_last_pos = -1;
-	
-	have_cursor = true;
 	_undo_stack = NULL;
 	_redo_stack = NULL;
 	_not_undoable_action = 0;
 	_undo_in_progress = false;
 	_has_input_method = true;
 	_use_wheel = true;
+	_fix_spacing_tag = NULL;
+	_has_native_popup = true;
+	_eat_return_key = true;
+	_text_area_visible = false;
+	_no_background = true;
+	_has_border = false;
 	
-	onChange = 0;
-	onCursor = 0;
-
 	textview = gtk_text_view_new();
-	realizeScrolledWindow(textview);
+#if GTK_CHECK_VERSION(3,18,0)
+	gtk_text_view_set_bottom_margin(GTK_TEXT_VIEW(textview), gApplication::getScrollbarSize() + 1);
+	gtk_text_view_set_right_margin(GTK_TEXT_VIEW(textview), gApplication::getScrollbarSize() + 1);
+#endif
+
+	_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview));
+
+#ifdef GTK3
+		border = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
+		border = gtk_alignment_new(0, 0, 1, 1);
+#endif
+
+	ON_DRAW_BEFORE(border, this, cb_border_expose, cb_border_draw);
+
+	frame = gtk_scrolled_window_new(NULL, NULL);
+#ifdef GTK3
+	gtk_widget_set_hexpand(frame, TRUE);
+#endif
+	setBorder(true);
+	
+	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(frame), GTK_SHADOW_NONE);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(frame), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#if GTK_CHECK_VERSION(3,16,0)
+	gtk_scrolled_window_set_overlay_scrolling(GTK_SCROLLED_WINDOW(frame), FALSE);
+#endif
+	
+	widget = textview;
+	
+	realize(false);
 
 	setColorBase();
 
 	//g_signal_connect_after(G_OBJECT(textview), "motion-notify-event", G_CALLBACK(cb_motion_notify_event), (gpointer)this);
 	g_signal_connect(G_OBJECT(textview), "key-press-event", G_CALLBACK(cb_keypress), (gpointer)this);
 	
-	_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview));
 	g_signal_connect_after(G_OBJECT(_buffer), "changed", G_CALLBACK(cb_changed), (gpointer)this);
 	g_signal_connect_after(G_OBJECT(_buffer), "mark-set", G_CALLBACK(cb_mark_set), (gpointer)this);
 	g_signal_connect(G_OBJECT(_buffer), "insert-text", G_CALLBACK(cb_insert_text), (gpointer)this);
 	g_signal_connect(G_OBJECT(_buffer), "delete-range", G_CALLBACK(cb_delete_range), (gpointer)this);
 
-	/*gtk_text_view_set_left_margin(GTK_TEXT_VIEW(textview), 2);
-	gtk_text_view_set_right_margin(GTK_TEXT_VIEW(textview), 2);*/
-
-	setBorder(true);
 	setWrap(false);
 }
 
@@ -534,7 +581,7 @@ gTextArea::~gTextArea()
 	clearUndoStack();
 }
 
-char *gTextArea::text()
+char *gTextArea::text() const
 {
 	GtkTextIter start;
 	GtkTextIter end;
@@ -559,9 +606,11 @@ void gTextArea::setText(const char *txt, int len)
 	begin();
 	gtk_text_buffer_set_text(_buffer, (const gchar *)txt, len);
 	end();
+
+	refresh();
 }
 
-bool gTextArea::readOnly()
+bool gTextArea::readOnly() const
 {
 	return !gtk_text_view_get_editable(GTK_TEXT_VIEW(textview));
 }
@@ -570,9 +619,10 @@ void gTextArea::setReadOnly(bool vl)
 {
 	gtk_text_view_set_editable(GTK_TEXT_VIEW(textview), !vl);
 	gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(textview), !vl);
+	_eat_return_key = !vl;
 }
 
-GtkTextIter *gTextArea::getIterAt(int pos)
+GtkTextIter *gTextArea::getIterAt(int pos) const
 {
 	static GtkTextIter iter;
 	
@@ -584,7 +634,7 @@ GtkTextIter *gTextArea::getIterAt(int pos)
 	return &iter;
 }
 
-int gTextArea::line()
+int gTextArea::line() const
 {
 	return gtk_text_iter_get_line(getIterAt());
 }
@@ -608,12 +658,13 @@ void gTextArea::setLine(int vl)
 	gtk_text_iter_set_line(iter, vl);
 	if (gtk_text_iter_get_chars_in_line(iter) <= col)
 		col = gtk_text_iter_get_chars_in_line(iter) - 1;
-	gtk_text_iter_set_line_offset(iter, col);
+	if (col >= 0)
+		gtk_text_iter_set_line_offset(iter, col);
 	gtk_text_buffer_place_cursor(_buffer, iter);
 	ensureVisible();
 }
 
-int gTextArea::column()
+int gTextArea::column() const
 {
 	return gtk_text_iter_get_line_offset(getIterAt());
 }
@@ -624,7 +675,7 @@ void gTextArea::setColumn(int vl)
 
 	if (vl < 0) 
 	{
-		vl = gtk_text_iter_get_chars_in_line(iter)-1;
+		vl = gtk_text_iter_get_chars_in_line(iter) - 1;
 	}
 	else
 	{
@@ -632,12 +683,14 @@ void gTextArea::setColumn(int vl)
 			vl = gtk_text_iter_get_chars_in_line(iter) - 1;
 	}
 	
-	gtk_text_iter_set_line_offset(iter,vl);
+	if (vl >= 0)
+		gtk_text_iter_set_line_offset(iter, vl);
+
 	gtk_text_buffer_place_cursor(_buffer, iter);
 	ensureVisible();
 }
 
-int gTextArea::position()
+int gTextArea::position() const
 {
 	return gtk_text_iter_get_offset(getIterAt());
 }
@@ -651,7 +704,7 @@ void gTextArea::setPosition(int vl)
 	ensureVisible();
 }
 
-int gTextArea::length()
+int gTextArea::length() const
 {
 	GtkTextIter iter;
 	
@@ -659,7 +712,7 @@ int gTextArea::length()
 	return gtk_text_iter_get_offset(&iter);
 }
 
-bool gTextArea::wrap()
+bool gTextArea::wrap() const
 {
 	return (gtk_text_view_get_wrap_mode(GTK_TEXT_VIEW(textview)) != GTK_WRAP_NONE);
 }
@@ -703,7 +756,10 @@ void gTextArea::paste()
 	
 	txt = gClipboard::getText(&len, "text/plain");
 	if (txt)
+	{
 		gtk_text_buffer_insert_at_cursor(_buffer, (const gchar *)txt, len);
+		refresh();
+	}
 }
 
 void gTextArea::insert(const char *txt)
@@ -712,9 +768,10 @@ void gTextArea::insert(const char *txt)
 		return;
 	
 	gtk_text_buffer_insert_at_cursor(_buffer, (const gchar *)txt, -1);
+	refresh();
 }
 
-int gTextArea::toLine(int pos)
+int gTextArea::toLine(int pos) const
 {
 	if (pos < 0)
 		pos=0;
@@ -724,7 +781,7 @@ int gTextArea::toLine(int pos)
 	return gtk_text_iter_get_line(getIterAt(pos));
 }
 
-int gTextArea::toColumn(int pos)
+int gTextArea::toColumn(int pos) const
 {
 	if (pos < 0)
 		pos=0;
@@ -734,7 +791,7 @@ int gTextArea::toColumn(int pos)
 	return gtk_text_iter_get_line_offset(getIterAt(pos));
 }
 
-int gTextArea::toPosition(int line, int col)
+int gTextArea::toPosition(int line, int col) const
 {
 	GtkTextIter iter;
 	int lm, cm;
@@ -768,13 +825,13 @@ gTextArea selection
 
 ***********************************************************************************/
 
-bool gTextArea::isSelected()
+bool gTextArea::isSelected() const
 {
 	return gtk_text_buffer_get_selection_bounds(_buffer, NULL, NULL);
 	//return gtk_text_buffer_get_has_selection(buf); // Only since 2.10
 }
 
-int gTextArea::selStart()
+int gTextArea::selStart() const
 {
 	GtkTextIter start, end;
 	
@@ -782,7 +839,7 @@ int gTextArea::selStart()
 	return gtk_text_iter_get_offset(&start);	
 }
 
-int gTextArea::selEnd()
+int gTextArea::selEnd() const
 {
 	GtkTextIter start, end;
 	
@@ -790,7 +847,7 @@ int gTextArea::selEnd()
 	return gtk_text_iter_get_offset(&end);
 }
 
-char *gTextArea::selText()
+char *gTextArea::selText() const
 {
 	GtkTextIter start, end;
 	char *text;
@@ -811,7 +868,8 @@ void gTextArea::setSelText(const char *vl)
 	if (gtk_text_buffer_get_selection_bounds(_buffer, &start, &end))
 		gtk_text_buffer_delete(_buffer, &start, &end);
 	
-	gtk_text_buffer_insert(_buffer, &start, vl, -1);	
+	gtk_text_buffer_insert(_buffer, &start, vl, -1);
+	refresh();
 }
 
 void gTextArea::selDelete()
@@ -851,14 +909,8 @@ void gTextArea::selSelect(int pos, int length)
 
 void gTextArea::updateCursor(GdkCursor *cursor)
 {
-  GdkWindow *win;
+  GdkWindow *win = TEXT_AREA(textview);
 
-#ifdef GTK3
-	win = gtk_text_view_get_window(GTK_TEXT_VIEW(textview), GTK_TEXT_WINDOW_TEXT);
-#else
-	win = ((PrivateGtkTextWindow *)GTK_TEXT_VIEW(textview)->text_window)->bin_window;
-#endif
-  
   gControl::updateCursor(cursor);
   
   if (!win)
@@ -1040,24 +1092,53 @@ GtkIMContext *gTextArea::getInputMethod()
 #endif
 }
 
+void gTextArea::updateFixSpacing()
+{
+	GtkTextIter start;
+	GtkTextIter end;
+	
+	if (font()->mustFixSpacing())
+	{
+		if (!_fix_spacing_tag)
+			_fix_spacing_tag = gtk_text_buffer_create_tag(_buffer, NULL, "letter-spacing", PANGO_SCALE, NULL);
+	
+		gtk_text_buffer_get_bounds(_buffer, &start, &end);
+		gtk_text_buffer_apply_tag (_buffer, _fix_spacing_tag, &start, &end);
+	}
+	else
+	{
+		if (_fix_spacing_tag)
+		{
+			gtk_text_buffer_get_bounds(_buffer, &start, &end);
+			gtk_text_buffer_remove_tag(_buffer, _fix_spacing_tag, &start, &end);
+			gtk_text_tag_table_remove(gtk_text_buffer_get_tag_table(_buffer), _fix_spacing_tag);
+			_fix_spacing_tag = NULL;
+		}
+	}
+}
+
 #ifdef GTK3
 GtkWidget *gTextArea::getStyleSheetWidget()
 {
 	return textview;
 }
 
-int gTextArea::minimumWidth() const
+const char *gTextArea::getStyleSheetColorNode()
 {
-	return gDesktop::scale() * 4;
+	return "text";
 }
 
-int gTextArea::minimumHeight() const
+void gTextArea::customStyleSheet(GString *)
 {
-	return gDesktop::scale() * 8;
+	gtk_text_view_set_pixels_inside_wrap(GTK_TEXT_VIEW(widget), font()->mustFixSpacing());
+	gtk_text_view_set_pixels_below_lines(GTK_TEXT_VIEW(widget), font()->mustFixSpacing());
+	
+	updateFixSpacing();
 }
+
 #endif
 
-void gTextArea::getCursorPos(int *x, int *y, int pos)
+void gTextArea::getCursorPos(int *x, int *y, int pos) const
 {
 	GdkRectangle rect;
 	int f = getFrameWidth();
@@ -1077,5 +1158,75 @@ void gTextArea::emitCursor()
 		return;
 	
 	_last_pos = pos;
-	emit(SIGNAL(onCursor));
+	CB_textarea_cursor(this);
+}
+
+#ifdef GTK3
+void gTextArea::onEnterEvent()
+{
+	if (_text_area_visible)
+		gdk_window_show(TEXT_AREA(textview));
+}
+
+void gTextArea::onLeaveEvent()
+{
+	_text_area_visible = !hasFocus() && gdk_window_is_visible(TEXT_AREA(textview));
+	if (_text_area_visible)
+		gdk_window_hide(TEXT_AREA(textview));
+}
+#endif
+
+void gTextArea::setMinimumSize()
+{
+	if (scrollBar())
+		_min_h = gApplication::getScrollbarBigSize(); // + font()->height() + (hasBorder() ? 4 : 0);
+	else
+		_min_h = font()->height() + (hasBorder() ? 4 : 0);
+	
+	_min_w = _min_h;
+}
+
+void gTextArea::updateScrollBar()
+{
+	gControl::updateScrollBar();
+	setMinimumSize();
+}
+
+void gTextArea::setFont(gFont *ft)
+{
+	gControl::setFont(ft);
+	setMinimumSize();
+}
+
+void gTextArea::setBorder(bool b)
+{
+	int padding;
+	
+	if (b == _has_border)
+		return;
+	
+	_has_border = b;
+	
+	padding = b ? (gDesktop::scale() / 2) : 0;
+	
+#ifdef GTK3
+	gtk_widget_set_margin_top(frame, padding);
+	gtk_widget_set_margin_bottom(frame, padding);
+#if GTK_CHECK_VERSION(3,12,0)
+	gtk_widget_set_margin_start(frame, padding);
+	gtk_widget_set_margin_end(frame, padding);
+#else
+	gtk_widget_set_margin_left(frame, padding);
+	gtk_widget_set_margin_right(frame, padding);
+#endif
+#else
+	gtk_alignment_set_padding(GTK_ALIGNMENT(border), padding, padding, padding, padding);
+#endif
+	
+	refresh();
+}
+
+gColor gTextArea::defaultBackground() const
+{
+	return gDesktop::getColor(COLOR_TEXT_BACKGROUND, !isEnabled());
 }
