@@ -100,7 +100,7 @@ static void set_color(GtkWidget *wid, gColor color, void (*func)(GtkWidget *, Gt
 	int i;
 	GtkStateType st;
 
-	if (color == COLOR_DEFAULT)
+	if (color == GB_COLOR_DEFAULT)
 	{
 		pcol = NULL;
 	}
@@ -1591,23 +1591,20 @@ void gt_pixbuf_make_gray(GdkPixbuf *pixbuf)
 GdkPixbuf *gt_pixbuf_create_disabled(GdkPixbuf *img)
 {
   gint w, h;
-  guchar *r, *g, *b, *end;
+  guchar *p, *end;
   GdkPixbuf *dimg;
 
   dimg = gdk_pixbuf_copy(img);
   w = gdk_pixbuf_get_width(dimg);
   h = gdk_pixbuf_get_height(dimg);
-  r = gdk_pixbuf_get_pixels(dimg);
-  g = r + 1;
-  b = r + 2;
-  end = r + w * h * gdk_pixbuf_get_n_channels(img);
+  p = gdk_pixbuf_get_pixels(dimg);
+  end = p + w * h * gdk_pixbuf_get_n_channels(img);
   
-	while (r != end) 
+	while (p != end) 
 	{
-		*r = *g = *b = (*r * 11 + *g * 16 + *b * 5) / 32;
-    r += 4;
-    g += 4;
-    b += 4;
+		p[0] = p[1] = p[2] = (p[0] * 11 + p[1] * 16 + p[2] * 5) / 32;
+		p[3] >>= 1;
+		p += 4;
 	}
 	
 	return dimg;
@@ -2114,8 +2111,8 @@ void gt_cairo_draw_pixbuf(cairo_t *cr, GdkPixbuf *pixbuf, float x, float y, floa
 #ifdef GTK3
 static GtkStyleContext *_style[NUM_STYLES] = { NULL };
 #else
-static int _style_loaded = 0;
-static GtkStyle *_style[NUM_STYLES];
+static uint _style_loaded = 0;
+static GtkStyle *_style[NUM_STYLES] = { NULL };
 #endif
 
 static int type_to_index(GType type)
@@ -2163,6 +2160,11 @@ const char *gt_get_style_class(GType type)
 		return _class[index];
 }
 
+static void cb_style_changed(GtkStyleContext *style, gpointer)
+{
+	gDesktop::onStyleChange();
+}
+
 GtkStyleContext *gt_get_style(GType type, const char *node, const char *more_klass)
 {
 	int index = 0;
@@ -2180,7 +2182,7 @@ GtkStyleContext *gt_get_style(GType type, const char *node, const char *more_kla
 	const char *klass = gt_get_style_class(type);
 
 	style = gtk_style_context_new();
-	
+
 	if (klass)
 		gtk_style_context_add_class(style, klass);
 
@@ -2203,6 +2205,7 @@ GtkStyleContext *gt_get_style(GType type, const char *node, const char *more_kla
 	if (!node && !more_klass)
 		_style[index] = style;
 	
+	g_signal_connect(G_OBJECT(style), "changed", G_CALLBACK(cb_style_changed), 0);
 	return style;
 }
 
@@ -2213,6 +2216,7 @@ static GtkStyle *get_style(const char *name, GType type)
 	GtkSettings *set = gtk_settings_get_default();
 	GtkStyle* st = gtk_rc_get_style_by_paths(set, NULL, name, type);
 	if (!st) st = gtk_widget_get_default_style();
+	g_object_ref(G_OBJECT(st));
 	return st;
 }
 
@@ -2221,6 +2225,7 @@ static GtkStyle *get_widget_style(const char *name)
 	GtkSettings *set = gtk_settings_get_default();
 	GtkStyle* st = gtk_rc_get_style_by_paths(set, name, NULL, G_TYPE_NONE);
 	if (!st) st = gtk_widget_get_default_style();
+	g_object_ref(G_OBJECT(st));
 	return st;
 }
 
@@ -2312,6 +2317,61 @@ void gt_draw_border(cairo_t *cr, GtkStyleContext *st, GtkStateFlags state, int b
 			gtk_render_focus(st, cr, x, y, w, h);
 	}
 }
+
+#else
+
+void gt_draw_border(GtkWidget *wid, GdkRectangle *clip, int border, gColor color, bool bg)
+{
+	GdkWindow *win;
+	GtkShadowType shadow;
+	gint x, y, w, h;
+	cairo_t *cr;
+	GtkAllocation a;
+	GtkStyle *st;
+
+	if (border == BORDER_NONE)
+		return;
+
+	gtk_widget_get_allocation(wid, &a);
+	
+	x = a.x;
+	y = a.y;
+	w = a.width;
+	h = a.height;
+	
+	if (w < 2 || h < 2)
+		return;
+
+	if (GTK_IS_LAYOUT(wid))
+		win = gtk_layout_get_bin_window(GTK_LAYOUT(wid));
+	else
+		win = gtk_widget_get_window(wid);
+
+	switch (border)
+	{
+		case BORDER_PLAIN:
+
+			cr = gdk_cairo_create(win);
+			gt_cairo_draw_rect(cr, x, y, w, h, color);
+			cairo_destroy(cr);
+			return;
+
+		case BORDER_SUNKEN: shadow = GTK_SHADOW_IN; break;
+		case BORDER_RAISED: shadow = GTK_SHADOW_OUT; break;
+		case BORDER_ETCHED: shadow = GTK_SHADOW_ETCHED_IN; break;
+
+		default:
+			return;
+	}
+
+	st = gtk_widget_get_style(wid);
+	if (bg)
+		gtk_paint_box(st, win, GTK_STATE_NORMAL, shadow, clip, wid, "entry", x, y, w, h);
+	else
+		gtk_paint_shadow(st, win, GTK_STATE_NORMAL, shadow, clip, wid, border == BORDER_SUNKEN ? "entry" : NULL, x, y, w, h);
+}
+
+
 #endif
 
 bool gt_grab(GtkWidget *widget, bool owner_event, guint32 time)
@@ -2425,6 +2485,9 @@ void gt_on_theme_change()
 			g_object_unref(G_OBJECT(_style[i]));
 		_style[i] = NULL;
 	}
+#ifndef GTK3
+	_style_loaded = 0;
+#endif
 }
 
 #if GTK_CHECK_VERSION(3, 22, 0)
@@ -2465,7 +2528,7 @@ void gt_css_add_color(GString *css, gColor bg, gColor fg)
 {
 	char buffer[32];
 
-	if (bg != COLOR_DEFAULT)
+	if (bg != GB_COLOR_DEFAULT)
 	{
 		gt_to_css_color(buffer, bg);
 		g_string_append(css, "background-color:");
@@ -2473,7 +2536,7 @@ void gt_css_add_color(GString *css, gColor bg, gColor fg)
 		g_string_append(css, ";\nbackground-image:none;\n");
 	}
 
-	if (fg != COLOR_DEFAULT)
+	if (fg != GB_COLOR_DEFAULT)
 	{
 		gt_to_css_color(buffer, fg);
 		g_string_append(css, "color:");
@@ -2550,7 +2613,7 @@ void gt_widget_update_css(GtkWidget *widget, gFont *font, gColor bg, gColor fg)
 	
 	css = g_string_new(NULL);
 	
-	if (font || bg != COLOR_DEFAULT || fg != COLOR_DEFAULT)
+	if (font || bg != GB_COLOR_DEFAULT || fg != GB_COLOR_DEFAULT)
 	{
 		g_string_append_printf(css, "#%s {\ntransition:none;\n", name);
 		gt_css_add_color(css, bg, fg);
