@@ -54,7 +54,7 @@
 #include "CButton.h"
 #include "CTextBox.h"
 #include "CTextArea.h"
-#include "CSlider.h"
+#include "CScrollBar.h"
 #include "CTabStrip.h"
 #include "CTrayIcon.h"
 #include "cprinter.h"
@@ -221,7 +221,6 @@ GB_DESC *GB_CLASSES[] EXPORT =
 	CWindowDesc,
 	CWindowsDesc,
 	CFormDesc,
-	SliderDesc,
 	ScrollBarDesc,
 	CButtonDesc,
 	CToggleButtonDesc,
@@ -482,6 +481,8 @@ static void hook_main(int *argc, char ***argv)
 		gApplication::onKeyEvent = global_key_event_handler;
 	}
 
+	gApplication::updateDarkTheme();
+
 	init = true;
 
 	CALL_HOOK_MAIN(_old_hook_main, argc, argv);
@@ -593,7 +594,7 @@ static void hook_wait(int duration)
 		return;
 	}
 
-	if (duration != -1 && gKey::isValid())
+	if (duration != GB_WAIT_NO_USER_INPUT && gKey::isValid())
 	{
 		if (!_warning)
 		{
@@ -607,22 +608,24 @@ static void hook_wait(int duration)
 	{
 		MAIN_do_iteration(true);
 	}
-	else if (duration == -1)
+	else if (duration == GB_WAIT_NO_USER_INPUT)
 	{
 		bool d = gApplication::disableInputEvents(true);
 		int i;
 		
 		for (i = 0; i < 256; i++)
 		{
-			if (!gApplication::eventsPending())
+			if (!gApplication::eventsPending() && !_post_check)
 				break;
 			MAIN_do_iteration(true);
 		}
 
 		gApplication::disableInputEvents(d);
 	}
-	else if (duration == -2)
+	else if (duration == GB_WAIT_FOR_NEXT_EVENT)
+	{
 		MAIN_do_iteration(false);
+	}
 }
 
 static void hook_watch(int fd, int type, void *callback, intptr_t param)
