@@ -929,6 +929,11 @@ static void parse_args(int argc, char **argv)
 	p3p = "";
 	max_age = -1;
 
+	env = getenv("GB_HTTPD_HOST");
+	if (env && *env)
+		hostname = env;
+
+
 	env = getenv("GB_HTTPD_PORT");
 	if (env && *env)
 	{
