@@ -136,7 +136,10 @@ BEGIN_PROPERTY(MimePart_ContentType)
 	#else
 		char *str = g_mime_content_type_encode(ctype, NULL);
 	#endif
-		GB.ReturnNewZeroString(str);
+		if (*str == ' ') // workaround a gmime bug
+			GB.ReturnNewZeroString(str + 1);
+		else
+			GB.ReturnNewZeroString(str);
 		g_free(str);
 	}
 	else
