@@ -115,6 +115,14 @@ static size_t http_read_curl(void *ptr, size_t size, size_t nmemb, void *_object
 {
 	size *= nmemb;
 	
+	//fprintf(stderr, "http_read_curl: ptr = %p / size = %ld / [%p] / data = %p / len_data = %ld / len_sent = %ld\n", ptr, size, THIS, THIS_HTTP->data, THIS_HTTP->len_data, THIS_HTTP->len_sent);
+	
+	if (!THIS_HTTP->data)
+	{
+		//fprintf(stderr, "**********************\n");
+		return 0;
+	}
+	
 	if (size > (THIS_HTTP->len_data - THIS_HTTP->len_sent))
 		size = THIS_HTTP->len_data - THIS_HTTP->len_sent;
 	
@@ -384,7 +392,6 @@ static void http_send(void *_object, int type, char *sContent, char *sData, int
 		}
 		else
 			THIS_HTTP->data = NULL;
-		
 	}
 	
 	THIS_HTTP->len_sent = 0;
