@@ -2,14 +2,11 @@
 
   GLclipping.h
 
-  The Gambas openGL component
-
   (c) 2005-2007 Laurent Carlier <lordheavy@users.sourceforge.net>
-                Benoît Minisini <gambas@users.sourceforge.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -19,18 +16,16 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
 #ifndef __GLCLIPPING_H
 #define __GLCLIPPING_H
 
-#include "gambas.h"
 #include "main.h"
 
-#include <GL/gl.h>
-
 DECLARE_METHOD(GLCLIPPLANE);
 DECLARE_METHOD(GLGETCLIPPLANE);
 
