@@ -2,14 +2,11 @@
 
   GLfog.c
 
-  The Gambas openGL component
-
   (c) 2005-2007 Laurent Carlier <lordheavy@users.sourceforge.net>
-                Benoît Minisini <gambas@users.sourceforge.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -19,17 +16,14 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
 #define __GLFOG_C
 
-#include "gambas.h"
-#include "gb_common.h"
-#include "main.h"
-
-#include <GL/gl.h>
+#include "GL.h"
 
 BEGIN_METHOD(GLFOGF, GB_INTEGER pname; GB_FLOAT param)
 
@@ -49,10 +43,9 @@ BEGIN_METHOD(GLFOGFV, GB_INTEGER pname; GB_OBJECT params)
 	GB_ARRAY fArray = (GB_ARRAY) VARG(params);
 	uint i, count = GB.Array.Count(fArray);
 	
-	if (count>4)
-		count=4;
+      count = (count > 4 ? 4 : count);
 
-	for (i=0;i<count; i++)
+	for (i=0; i<count; i++)
 		params[i]=*((double *)GB.Array.Get(fArray,i));
 
 	glFogfv(VARG(pname), params);
@@ -65,10 +58,9 @@ BEGIN_METHOD(GLFOGIV, GB_INTEGER pname; GB_OBJECT params)
 	GB_ARRAY iArray = (GB_ARRAY) VARG(params);
 	uint i, count = GB.Array.Count(iArray);
 	
-	if (count>4)
-		count=4;
+      count = (count > 4 ? 4 : count);
 
-	for (i=0;i<count; i++)
+	for (i=0; i<count; i++)
 		params[i]=*((GLint *)GB.Array.Get(iArray,i));
 
 	glFogiv(VARG(pname), params);
