@@ -2,14 +2,11 @@
 
   GLprimitives.c
 
-  The Gambas openGL component
-
   (c) 2005-2007 Laurent Carlier <lordheavy@users.sourceforge.net>
-                Benoît Minisini <gambas@users.sourceforge.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -19,17 +16,16 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
 #define __GLPRIMITIVES_C
 
-#include "gambas.h"
-#include "gb_common.h"
-#include "main.h"
+#include "GL.h"
 
-#include <GL/gl.h>
+#include <stdio.h>
 
 BEGIN_METHOD(GLBEGIN, GB_INTEGER primitive)
 
@@ -61,40 +57,63 @@ BEGIN_METHOD(GLRECTI, GB_INTEGER x1; GB_INTEGER y1; GB_INTEGER x2; GB_INTEGER y2
   
 END_METHOD
 
-BEGIN_METHOD(GLVERTEXF, GB_FLOAT x; GB_FLOAT y; GB_FLOAT z; GB_FLOAT w)
+BEGIN_METHOD(GLVERTEX2F, GB_FLOAT x; GB_FLOAT y)
 
-	if (MISSING(z))
-	{
-		glVertex2d(VARG(x), VARG(y));
-		return;
-	}
-
-	if (MISSING(w))
-	{
-		glVertex3d(VARG(x), VARG(y), VARG(z));
-		return;
-	}
-
-	glVertex4d(VARG(x), VARG(y), VARG(z), VARG(w));
+      glVertex2d(VARG(x), VARG(y));
 
 END_METHOD
 
+BEGIN_METHOD(GLVERTEX3F, GB_FLOAT x; GB_FLOAT y; GB_FLOAT z)
+
+      glVertex3d(VARG(x), VARG(y), VARG(z));
+
+END_METHOD
+
+BEGIN_METHOD(GLVERTEXF, GB_FLOAT x; GB_FLOAT y; GB_FLOAT z; GB_FLOAT w)
+
+      if (MISSING(z))
+      {
+            glVertex2d(VARG(x), VARG(y));
+            return;
+      }
+
+      if (MISSING(w))
+      {
+            glVertex3d(VARG(x), VARG(y), VARG(z));
+            return;
+      }
+
+      glVertex4d(VARG(x), VARG(y), VARG(z), VARG(w));
+
+END_METHOD
+
+BEGIN_METHOD(GLVERTEX2I, GB_INTEGER x; GB_INTEGER y)
+
+      glVertex2i(VARG(x), VARG(y));
+
+END_METHOD
+
+BEGIN_METHOD(GLVERTEX3I, GB_INTEGER x; GB_INTEGER y; GB_INTEGER z)
+
+      glVertex3i(VARG(x), VARG(y), VARG(z));
+
+END_METHOD
 
 BEGIN_METHOD(GLVERTEXI, GB_INTEGER x; GB_INTEGER y; GB_INTEGER z; GB_INTEGER w)
 
-	if (MISSING(z))
-	{
-		glVertex2i(VARG(x), VARG(y));
-		return;
-	}
+      if (MISSING(z))
+      {
+            glVertex2i(VARG(x), VARG(y));
+            return;
+      }
 
-	if (MISSING(w))
-	{
-		glVertex3i(VARG(x), VARG(y), VARG(z));
-		return;
-	}
+      if (MISSING(w))
+      {
+            glVertex3i(VARG(x), VARG(y), VARG(z));
+            return;
+      }
 
-	glVertex4i(VARG(x), VARG(y), VARG(z), VARG(w));
+      glVertex4i(VARG(x), VARG(y), VARG(z), VARG(w));
 
 END_METHOD
 
