@@ -31,6 +31,7 @@
 #include <stdio.h>
 #include <stdint.h>
 #include <math.h>
+#include <memory>
 
 #include <PDFDoc.h>
 #include <Stream.h>
@@ -1027,7 +1028,14 @@ END_PROPERTY
 BEGIN_METHOD(PDFPAGE_select, GB_INTEGER X; GB_INTEGER Y; GB_INTEGER W; GB_INTEGER H)
 
 	TextOutputDev *dev;
+#if POPPLER_VERSION_25_01_0
+	GooString str;
+# else
 	GooString *str;
+#endif
+#if POPPLER_VERSION_24_12_0
+	std::unique_ptr<Gfx> _gfx;
+#endif
 	Gfx *gfx;
 	int32_t x,y,w,h;
 
@@ -1037,7 +1045,10 @@ BEGIN_METHOD(PDFPAGE_select, GB_INTEGER X; GB_INTEGER Y; GB_INTEGER W; GB_INTEGE
 	h = VARGOPT(H, (int32_t)THIS->page->getMediaHeight());
 
 	dev = new TextOutputDev (NULL, true, 0, false, false);
-#if POPPLER_VERSION_24_11_0
+#if POPPLER_VERSION_24_12_0
+	_gfx = THIS->page->createGfx(dev,72.0,72.0,0,false,true,-1, -1, -1, -1, NULL, NULL);
+	gfx = _gfx.get();
+#elif POPPLER_VERSION_24_11_0
 	gfx = THIS->page->createGfx(dev,72.0,72.0,0,false,true,-1, -1, -1, -1, NULL, NULL);
 #else
 	gfx = THIS->page->createGfx(dev,72.0,72.0,0,false,true,-1, -1, -1, -1, false, NULL, NULL);
@@ -1048,9 +1059,14 @@ BEGIN_METHOD(PDFPAGE_select, GB_INTEGER X; GB_INTEGER Y; GB_INTEGER W; GB_INTEGE
 
 	str=dev->getText((double)x,(double)y,(double)(w+x),(double)(h+y));
 
+#if !(POPPLER_VERSION_24_12_0)
 	delete gfx;
+#endif
 	delete dev;
 
+#if POPPLER_VERSION_25_01_0
+	GB.ReturnNewString(str.getCString(),str.getLength());
+#else
 	if (!str)
 	{
 		GB.ReturnNewZeroString("");
@@ -1059,6 +1075,7 @@ BEGIN_METHOD(PDFPAGE_select, GB_INTEGER X; GB_INTEGER Y; GB_INTEGER W; GB_INTEGE
 	
 	GB.ReturnNewString(str->getCString(),str->getLength());	
 	delete str;
+#endif
 
 END_METHOD
 
