@@ -180,7 +180,7 @@ void MyDrawingArea::redraw(QRect &r, bool frame)
 	fw = frameWidth();
 
 	bg = CWIDGET_get_background((CWIDGET *)THIS);
-	if (bg != COLOR_DEFAULT)
+	if (bg != GB_COLOR_DEFAULT)
 	{
 		p->fillRect(fw, fw, width() - fw * 2, height() - fw * 2, TO_QCOLOR(bg));
 	}
@@ -536,11 +536,7 @@ void MyDrawingArea::changeEvent(QEvent *e)
 	}
 }
 
-/***************************************************************************
-
-	DrawingArea
-
-***************************************************************************/
+//-------------------------------------------------------------------------
 
 BEGIN_METHOD(DrawingArea_new, GB_OBJECT parent)
 
@@ -564,7 +560,7 @@ BEGIN_PROPERTY(DrawingArea_Cached)
 		GB_COLOR bg = CWIDGET_get_background((CWIDGET *)THIS);
 		GB_COLOR fg = CWIDGET_get_foreground((CWIDGET *)THIS);
 
-		if (bg == COLOR_DEFAULT)
+		if (bg == GB_COLOR_DEFAULT)
 		{
 			CWIDGET_set_color((CWIDGET *)THIS, WIDGET->palette().color(WIDGET->backgroundRole()).rgb() & 0xFFFFFF, fg);
 			WIDGET->clearBackground();
@@ -704,6 +700,16 @@ BEGIN_PROPERTY(DrawingArea_Tablet)
 
 END_PROPERTY
 
+BEGIN_PROPERTY(DrawingArea_NoMouse)
+
+	if (READ_PROPERTY)
+		GB.ReturnBoolean(WIDGET->testAttribute(Qt::WA_TransparentForMouseEvents));
+	else
+		WIDGET->setAttribute(Qt::WA_TransparentForMouseEvents, VPROP(GB_BOOLEAN));
+
+END_PROPERTY
+
+//-------------------------------------------------------------------------
 
 GB_DESC CDrawingAreaDesc[] =
 {
@@ -723,6 +729,7 @@ GB_DESC CDrawingAreaDesc[] =
 	GB_PROPERTY("Enabled", "b", DrawingArea_Enabled),
 	GB_PROPERTY("Painted", "b", DrawingArea_Painted),
 	GB_PROPERTY("Tablet", "b", DrawingArea_Tablet),
+	GB_PROPERTY("NoMouse", "b", DrawingArea_NoMouse),
 
 	GB_METHOD("Clear", NULL, DrawingArea_Clear, NULL),
 	GB_METHOD("Refresh", NULL, DrawingArea_Refresh, "[(X)i(Y)i(Width)i(Height)i]"),
