@@ -393,7 +393,7 @@ BEGIN_METHOD(Menu_new, GB_OBJECT parent; GB_BOOLEAN hidden)
 
 		if (!menu->menu)
 		{
-			#if QT_VERSION >= QT_VERSION_CHECK(5,0,0) && QT_VERSION < QT_VERSION_CHECK(5,5,0)
+			#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0) && QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 				menu->menu = new MyMenu();
 			#else
 				menu->menu = new QMenu();
@@ -810,7 +810,22 @@ BEGIN_METHOD(Menu_Popup, GB_INTEGER x; GB_INTEGER y; GB_OBJECT ref)
 	if (MISSING(x) || MISSING(y))
 		pos = QCursor::pos();
 	else
+	{
 		pos = QPoint(VARG(x), VARG(y));
+		#if QT5
+		#ifndef QT6
+			if (MAIN_platform_is_wayland)
+			{
+				//CWINDOW *win = (CWINDOW *)CWidget::get(THIS->toplevel);
+				QWindow *window = THIS->toplevel->windowHandle();
+				//QPoint global = THIS->toplevel->mapToGlobal(QPoint(0,0)); 
+				//int h = win->menuBar->sizeHint().height();
+				//if (h == 0) h = win->menuBar->height();
+				pos -= QPoint(window->frameMargins().left() + window->frameMargins().right() - 1, window->frameMargins().top() + window->frameMargins().bottom() - 1);
+			}
+		#endif
+	  #endif	
+	}
 
 	CMENU_popup(THIS, pos);
 
@@ -1230,7 +1245,7 @@ void CMenu::slotDestroyed(void)
 
 //---------------------------------------------------------------------------
 
-#if QT_VERSION >= QT_VERSION_CHECK(5,0,0) && QT_VERSION < QT_VERSION_CHECK(5,5,0)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0) && QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 
 void MyMenu::setVisible(bool visible)
 {
