@@ -78,10 +78,24 @@ void CMOUSE_set_control(void *control)
 void CMOUSE_finish_event(void)
 {
 	if (_control)
+	{
+		CMOUSE_clear(true);
 		GB.Raise(_control, EVENT_MouseUp, 0);
+		CMOUSE_clear(false);
+	}
 }
 
 
+void CMOUSE_update_global_pos(void)
+{
+	if (MOUSE_info.valid)
+	{
+		QPoint pos = QCursor::pos();
+		MOUSE_info.screenX = pos.x();
+		MOUSE_info.screenY = pos.y();
+	}
+}
+
 //int CMOUSE_last_state = 0;
 
 //static CCURSOR PredefinedCursor[LastCursor + 1] = { { { 0, 0 }, NULL, NULL } };
