@@ -1195,12 +1195,14 @@ BEGIN_PROPERTY(Control_ScreenX)
 	int x = WIDGET->mapToGlobal(QPoint(0, 0)).x();
 
 #ifdef QT5
+#ifndef QT6
 	if (MAIN_platform_is_wayland)
 	{
 		QWindow *win = WIDGET->window()->windowHandle();
 		if (win)
 			x += win->frameMargins().left();
 	}
+#endif
 #endif
 
   GB.ReturnInteger(x);
@@ -1223,12 +1225,14 @@ BEGIN_PROPERTY(Control_ScreenY)
 	int y = WIDGET->mapToGlobal(QPoint(0, 0)).y();
 
 #ifdef QT5
+#ifndef QT6
 	if (MAIN_platform_is_wayland)
 	{
 		QWindow *win = WIDGET->window()->windowHandle();
 		if (win)
 			y += win->frameMargins().top();
 	}
+#endif
 #endif
 
   GB.ReturnInteger(y);
@@ -2107,6 +2111,7 @@ void CWIDGET_grab(CWIDGET *_object)
 	WIDGET->releaseKeyboard();
 	THIS->flag.grab = false;
 
+	CMOUSE_update_global_pos();
 }
 
 BEGIN_METHOD_VOID(Control_Grab)
