@@ -50,6 +50,18 @@ typedef
 		char mouse;
 	}
 	CWIDGET_EXT;
+	
+typedef
+	struct {
+		GB_COLOR fg;
+		GB_COLOR bg;
+		void *cursor;
+		char mouse;
+		//unsigned drop : 1;
+		unsigned no_tab_focus : 1;
+		unsigned tracking : 1;
+	}
+	CWIDGET_PROXY;
 
 typedef
 	struct CWIDGET {
@@ -59,41 +71,41 @@ typedef
 		struct {
 			unsigned deleted : 1;
 			unsigned scrollview : 1;           // inherits QScrollView
-			unsigned expand : 1;
-			unsigned ignore : 1;
-			unsigned notified : 1;
-			unsigned visible : 1;
+			unsigned expand : 1;               //
+			unsigned ignore : 1;               //
+			unsigned visible : 1;              //
 			unsigned autoFillBackground : 1;
-			unsigned fillBackground : 1;
+			unsigned fillBackground : 1;       //
+			unsigned noBackground : 1;         //
 
-			unsigned noBackground : 1;
 			unsigned shown : 1;                // for containers
 			unsigned tracking : 1;
 			unsigned old_tracking : 1;
 			unsigned grab : 1;
-			unsigned dragging: 1;
+			unsigned dragging: 1;              //
 			unsigned no_tab_focus : 1;
-			unsigned inside : 1;
+			unsigned inside : 1;               //
 
 			unsigned inside_later : 1;
-			unsigned use_tablet : 1;
-			unsigned no_keyboard : 1;
-			unsigned tablet_pressed : 1;
+			unsigned use_tablet : 1;           //
 			unsigned has_action : 1;
 			unsigned drop : 1;
 			unsigned resized : 1;
 			unsigned wheel : 1;                // eat wheel events
+			unsigned design : 1;               //
+			unsigned design_ignore : 1;        //
 
-			unsigned design : 1;
-			unsigned design_ignore : 1;
 			unsigned no_design : 1;
 			unsigned orientation : 1;          // for scrollbars & similar widgets
 			unsigned inverted : 1;             // if layout has been inverted
 			unsigned direction : 2;            // text direction
 			unsigned user : 1;                 // UserControl or UserContainer
+			unsigned no_animation : 1;         // enable or disable animations explicitly
+			unsigned _reserved : 1;
 			} flag;
 		char *name;
 		void *font;
+		uint key;
 		}
 	CWIDGET; // BEWARE: gb.qt.h MUST be updated accordingly!
 
@@ -195,7 +207,7 @@ DECLARE_PROPERTY(Control_Mouse);
 #define EMBED_OK     1
 #define EMBED_ERROR  2
 
-void CWIDGET_new(QWidget *w, void *_object, bool no_show = false, bool no_filter = false, bool no_tag = false);
+void CWIDGET_new(QWidget *w, void *_object, bool no_show = false);
 void CWIDGET_init_name(CWIDGET *_object);
 void CWIDGET_set_name(CWIDGET *_object, const char *name);
 #define CWIDGET_get_name(_object) (((CWIDGET *)_object)->name)
@@ -205,7 +217,7 @@ QString CWIDGET_Utf8ToQString(GB_STRING *str);
 
 void CWIDGET_destroy(CWIDGET *_object);
 
-void CWIDGET_iconset(QIcon &icon, const QPixmap &p, int size = 0);
+QSize CWIDGET_iconset(QIcon &icon, const QPixmap &p, int size = 0);
 
 void CWIDGET_set_color(CWIDGET *_object, int bg, int fg, bool handle_proxy = false);
 void CWIDGET_reset_color(CWIDGET *_object);
@@ -265,6 +277,9 @@ void *CWIDGET_get_next_focus(void *_object);
 void *CWIDGET_get_previous_focus(void *_object);
 bool CWIDGET_has_no_tab_focus(void *_object);
 
+CWIDGET_PROXY *CWIDGET_save_proxy(void *_object);
+void CWIDGET_apply_proxy(CWIDGET_PROXY *data, void *_object);
+
 #ifndef DO_NOT_DECLARE_EVENTS
 #ifndef __CWIDGET_CPP
 extern
@@ -299,7 +314,7 @@ public:
 
 	static CWidget manager;
 
-	static void add(QObject *, void *, bool no_filter);
+	static void add(QObject *, void *);
 	static CWIDGET *get(QObject *);
 	static CWIDGET *getReal(QObject *o) { return dict[o]; }
 	static CWIDGET *getRealExisting(QObject *);
