@@ -53,16 +53,6 @@
 #include "csvgimage.h"
 #include "cpaint_impl.h"
 
-/*class ClipInfo
-{
-public:
-	QPainterPath *path;
-	GB_RECT *rect;
-
-	ClipInfo() { path = NULL; rect = NULL; }
-	~ClipInfo() { delete path; delete rect; }
-};*/
-
 typedef
 	struct {
 		QPainter *painter;
@@ -84,6 +74,9 @@ typedef
 #define PAINTER(d) EXTRA(d)->painter
 #define PATH(d) EXTRA(d)->path
 //#define CLIP(d) EXTRA(d)->clip
+
+#define DASH_ZERO 0.0009765625
+#define LINE_WIDTH_1 0.9999
 	
 static bool _internal_paint = false;
 
@@ -139,7 +132,7 @@ static bool init_painting(GB_PAINT *d, QPaintDevice *device)
 	pen.setCapStyle(Qt::FlatCap);
 	pen.setJoinStyle(Qt::MiterJoin);
 	pen.setMiterLimit(10.0);
-	pen.setWidthF(1.0);
+	pen.setWidthF(LINE_WIDTH_1);
 	pen.setColor(CCOLOR_make(col));
 	PAINTER(d)->setPen(pen);
 
@@ -518,7 +511,7 @@ static void ResetClip(GB_PAINT *d)
 	PAINTER(d)->setClipping(false);
 }
 
-static void get_path_extents(QPainterPath *path, GB_EXTENTS *ext, const QTransform &transform)
+static void get_path_extents(QPainterPath *path, GB_EXTENTS *ext)
 {
 	if (!path)
 	{
@@ -526,7 +519,8 @@ static void get_path_extents(QPainterPath *path, GB_EXTENTS *ext, const QTransfo
 		return;
 	}
 
-	QRectF rect = transform.inverted().mapRect(path->boundingRect());
+	//QRectF rect = transform.inverted().mapRect(path->boundingRect());
+	QRectF rect = path->boundingRect();
 
 	ext->x1 = (float)rect.left();
 	ext->y1 = (float)rect.top();
@@ -546,7 +540,7 @@ static void ClipExtents(GB_PAINT *d, GB_EXTENTS *ext)
 	}
 	else*/
 	QPainterPath path = PAINTER(d)->clipPath();
-	get_path_extents(&path, ext, QTransform()); //PAINTER(d)->transform());
+	get_path_extents(&path, ext); //, QTransform()); //PAINTER(d)->transform());
 }
 
 static void Fill(GB_PAINT *d, int preserve)
@@ -596,7 +590,7 @@ static void Stroke(GB_PAINT *d, int preserve)
 
 static void PathExtents(GB_PAINT *d, GB_EXTENTS *ext)
 {
-	get_path_extents(PATH(d), ext, PAINTER(d)->transform());
+	get_path_extents(PATH(d), ext); //, PAINTER(d)->transform());
 }
 
 static int PathContains(GB_PAINT *d, float x, float y)
@@ -630,8 +624,6 @@ static void PathOutline(GB_PAINT *d, GB_PAINT_OUTLINE_CB cb)
 	}
 }
 
-#define DASH_ZERO 0.0009765625
-
 static void Dash(GB_PAINT *d, int set, float **dashes, int *count)
 {
 	QPen pen = PAINTER(d)->pen();
@@ -784,11 +776,18 @@ static void LineWidth(GB_PAINT *d, int set, float *value)
 	QPen pen = PAINTER(d)->pen();
 	if (set)
 	{
-		pen.setWidthF((qreal)*value);
+		pen.setWidthF((qreal)(*value == 1 ? LINE_WIDTH_1 : *value));
 		PAINTER(d)->setPen(pen);
 	}
 	else
-		*value = (float)pen.widthF();
+	{
+		qreal width = pen.widthF();
+		
+		if (width == (qreal)LINE_WIDTH_1)
+			width = 1;
+		
+		*value = (float)width;
+	}
 }
 
 static void MiterLimit(GB_PAINT *d, int set, float *value)
@@ -824,7 +823,18 @@ static void Operator(GB_PAINT *d, int set, int *value)
 			case GB_PAINT_OPERATOR_DEST_ATOP: mode = QPainter::CompositionMode_DestinationAtop; break;
 			case GB_PAINT_OPERATOR_XOR: mode = QPainter::CompositionMode_Xor; break;
 			case GB_PAINT_OPERATOR_ADD: mode = QPainter::CompositionMode_Plus; break;
-			case GB_PAINT_OPERATOR_SATURATE: mode = QPainter::CompositionMode_Multiply; break;
+			case GB_PAINT_OPERATOR_SATURATE: mode = QPainter::CompositionMode_SourceOver; break;
+			case GB_PAINT_OPERATOR_MULTIPLY: mode = QPainter::CompositionMode_Multiply; break;
+			case GB_PAINT_OPERATOR_SCREEN: mode = QPainter::CompositionMode_Screen; break;
+			case GB_PAINT_OPERATOR_OVERLAY: mode = QPainter::CompositionMode_Overlay; break;
+			case GB_PAINT_OPERATOR_DARKEN: mode = QPainter::CompositionMode_Darken; break;
+			case GB_PAINT_OPERATOR_LIGHTEN: mode = QPainter::CompositionMode_Lighten; break;
+			case GB_PAINT_OPERATOR_COLOR_DODGE: mode = QPainter::CompositionMode_ColorDodge; break;
+			case GB_PAINT_OPERATOR_COLOR_BURN: mode = QPainter::CompositionMode_ColorBurn; break;
+			case GB_PAINT_OPERATOR_HARD_LIGHT: mode = QPainter::CompositionMode_HardLight; break;
+			case GB_PAINT_OPERATOR_SOFT_LIGHT: mode = QPainter::CompositionMode_SoftLight; break;
+			case GB_PAINT_OPERATOR_DIFFERENCE: mode = QPainter::CompositionMode_Difference; break;
+			case GB_PAINT_OPERATOR_EXCLUSION: mode = QPainter::CompositionMode_Exclusion; break;
 			case GB_PAINT_OPERATOR_OVER: default: mode = QPainter::CompositionMode_SourceOver;
 		}
 		PAINTER(d)->setCompositionMode(mode);
@@ -845,18 +855,38 @@ static void Operator(GB_PAINT *d, int set, int *value)
 			case QPainter::CompositionMode_DestinationAtop: *value = GB_PAINT_OPERATOR_DEST_ATOP; break;
 			case QPainter::CompositionMode_Xor: *value = GB_PAINT_OPERATOR_XOR; break;
 			case QPainter::CompositionMode_Plus: *value = GB_PAINT_OPERATOR_ADD; break;
-			case QPainter::CompositionMode_Multiply: *value = GB_PAINT_OPERATOR_SATURATE; break;
+			case QPainter::CompositionMode_Multiply: *value = GB_PAINT_OPERATOR_MULTIPLY; break;
+			case QPainter::CompositionMode_Screen: *value = GB_PAINT_OPERATOR_SCREEN; break;
+			case QPainter::CompositionMode_Overlay: *value = GB_PAINT_OPERATOR_OVERLAY; break;
+			case QPainter::CompositionMode_Darken: *value = GB_PAINT_OPERATOR_DARKEN; break;
+			case QPainter::CompositionMode_Lighten: *value = GB_PAINT_OPERATOR_LIGHTEN; break;
+			case QPainter::CompositionMode_ColorDodge: *value = GB_PAINT_OPERATOR_COLOR_DODGE; break;
+			case QPainter::CompositionMode_ColorBurn: *value = GB_PAINT_OPERATOR_COLOR_BURN; break;
+			case QPainter::CompositionMode_HardLight: *value = GB_PAINT_OPERATOR_HARD_LIGHT; break;
+			case QPainter::CompositionMode_SoftLight: *value = GB_PAINT_OPERATOR_SOFT_LIGHT; break;
+			case QPainter::CompositionMode_Difference: *value = GB_PAINT_OPERATOR_DIFFERENCE; break;
+			case QPainter::CompositionMode_Exclusion: *value = GB_PAINT_OPERATOR_EXCLUSION; break;
 			case QPainter::CompositionMode_SourceOver: default: *value = GB_PAINT_OPERATOR_OVER;
 		}
 	}
 }
 
 
+static void Opacity(GB_PAINT *d, int set, float *value)
+{
+	if (set)
+		PAINTER(d)->setOpacity(*value);
+	else
+		*value = (float)PAINTER(d)->opacity();
+}
+
+
 static void NewPath(GB_PAINT *d)
 {
 	PRESERVE_PATH(d, FALSE);
 }
 
+
 static void ClosePath(GB_PAINT *d)
 {
 	CHECK_PATH(d);
@@ -1074,7 +1104,7 @@ static void get_text_extents(GB_PAINT *d, bool rich, const char *text, int len,
 
 	p.end();
 
-	get_path_extents(&path, ext, QTransform());
+	get_path_extents(&path, ext); //, QTransform());
 	_draw_path = NULL;
 }
 
@@ -1197,10 +1227,12 @@ static void DrawImage(GB_PAINT *d, GB_IMAGE image, float x, float y, float w, fl
 {
 	QImage *img = CIMAGE_get((CIMAGE *)image);
 	QRectF rect(x, y, w, h);
+	float prev_opacity;
 
 	begin_clipping(d);
 
-	PAINTER(d)->setOpacity(opacity);
+	prev_opacity = (float)PAINTER(d)->opacity();
+	PAINTER(d)->setOpacity(opacity * prev_opacity);
 
 	if (source)
 	{
@@ -1217,7 +1249,7 @@ static void DrawImage(GB_PAINT *d, GB_IMAGE image, float x, float y, float w, fl
 	else
 		PAINTER(d)->drawImage(rect, *img);
 
-	PAINTER(d)->setOpacity(1.0);
+	PAINTER(d)->setOpacity(prev_opacity);
 
 	end_clipping(d);
 }
@@ -1363,11 +1395,21 @@ static void TransformDelete(GB_TRANSFORM *matrix)
 static void TransformInit(GB_TRANSFORM matrix, float xx, float yx, float xy, float yy, float x0, float y0)
 {
 	QTransform *t = (QTransform *)matrix;
-	QMatrix m((qreal)xx, (qreal)yx, (qreal)xy, (qreal)yy, (qreal)x0, (qreal)y0);
-	QTransform t2(m);
+	QTransform t2((qreal)xx, (qreal)yx, (qreal)xy, (qreal)yy, (qreal)x0, (qreal)y0);
 	*t = t2;
 }
 
+static void TransformGet(GB_TRANSFORM matrix, float values[6])
+{
+	QTransform *t = (QTransform *)matrix;
+	values[0] = t->m11();
+	values[1] = t->m12();
+	values[2] = t->m21();
+	values[3] = t->m22();
+	values[4] = t->m31();
+	values[5] = t->m32();
+}
+
 static void TransformTranslate(GB_TRANSFORM matrix, float tx, float ty)
 {
 	QTransform *t = (QTransform *)matrix;
@@ -1380,6 +1422,12 @@ static void TransformScale(GB_TRANSFORM matrix, float sx, float sy)
 	t->scale((qreal)sx, (qreal)sy);
 }
 
+static void TransformShear(GB_TRANSFORM matrix, float sh, float sv)
+{
+	QTransform *t = (QTransform *)matrix;
+	t->shear((qreal)sh, (qreal)sv);
+}
+
 static void TransformRotate(GB_TRANSFORM matrix, float angle)
 {
 	QTransform *t = (QTransform *)matrix;
@@ -1452,6 +1500,7 @@ GB_PAINT_DESC PAINT_Interface =
 	LineWidth,
 	MiterLimit,
 	Operator,
+	Opacity,
 	NewPath,
 	ClosePath,
 	Arc,
@@ -1490,8 +1539,10 @@ GB_PAINT_MATRIX_DESC PAINT_MATRIX_Interface =
 	TransformCopy,
 	TransformDelete,
 	TransformInit,
+	TransformGet,
 	TransformTranslate,
 	TransformScale,
+	TransformShear,
 	TransformRotate,
 	TransformInvert,
 	TransformMultiply,
@@ -1538,7 +1589,11 @@ MyPaintEngine::~MyPaintEngine() {}
 
 void MyPaintEngine::patchFeatures()
 {
+#if QT6
+	if (type() == Pdf)
+#else
 	if (type() == PostScript || type() == Pdf)
+#endif
 	{
 		QPaintEngine::PaintEngineFeatures f = QPaintEngine::AllFeatures;
 		f &= (QPaintEngine::PorterDuff | QPaintEngine::PerspectiveTransform
