@@ -83,7 +83,6 @@
 #include "CDraw.h"
 #include "CWatch.h"
 #include "CDrawingArea.h"
-#include "CSlider.h"
 #include "CScrollBar.h"
 #include "CWatcher.h"
 #include "cprinter.h"
@@ -199,6 +198,8 @@ MyApplication::MyApplication(int &argc, char **argv)
 		}
 	}
 
+	APPLICATION_update_dark_theme();
+
 	QObject::connect(this, SIGNAL(commitDataRequest(QSessionManager &)), SLOT(commitDataRequested(QSessionManager &)));
 }
 
@@ -255,6 +256,7 @@ static bool QT_EventFilter(QEvent *e)
 	return cancel;
 }
 
+#if 0
 static bool QT_Notify(CWIDGET *object, bool value)
 {
 	bool old = object->flag.notified;
@@ -262,6 +264,7 @@ static bool QT_Notify(CWIDGET *object, bool value)
 	object->flag.notified = value;
 	return old;
 }
+#endif
 
 bool MyApplication::eventFilter(QObject *o, QEvent *e)
 {
@@ -687,9 +690,9 @@ static void hook_wait(int duration)
 	
 	if (duration >= 0)
 		qApp->processEvents(QEventLoop::AllEvents, duration);
-	else if (duration == -1)
+	else if (duration == GB_WAIT_NO_USER_INPUT)
 		qApp->processEvents(QEventLoop::ExcludeUserInputEvents, 0);
-	else if (duration == -2)
+	else if (duration == GB_WAIT_FOR_NEXT_EVENT)
 		qApp->processEvents(QEventLoop::AllEvents | QEventLoop::WaitForMoreEvents);
 	
 	MAIN_in_wait--;
@@ -1002,7 +1005,7 @@ GB_DESC *GB_CLASSES[] EXPORT =
 	CPanelDesc, CHBoxDesc, CVBoxDesc, CHPanelDesc, CVPanelDesc,
 	CTabStripContainerChildrenDesc, CTabStripContainerDesc, CTabStripDesc,
 	CDrawingAreaDesc,
-	SliderDesc, ScrollBarDesc,
+	ScrollBarDesc,
 	CWindowMenusDesc, CWindowControlsDesc, CWindowDesc, CWindowsDesc, CFormDesc,
 	CDialogDesc,
 	CEmbedderDesc,
@@ -1037,7 +1040,6 @@ void *GB_QT4_1[] EXPORT =
 	(void *)QT_NewString,
 	(void *)QT_ReturnNewString,
 	(void *)QT_EventFilter,
-	(void *)QT_Notify,
 	(void *)CCONST_alignment,
 	(void *)QT_Link,
 	(void *)QT_GetLink,
