@@ -2,7 +2,7 @@
 
   CConst.cpp
 
-  (c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
+  (c) 2000-2017 Benoît Minisini <benoit.minisini@gambas-basic.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,27 +37,27 @@
 
 static int _alignment[] =
 {
-	ALIGN_NORMAL, Qt::AlignVCenter + Qt::AlignLeft,
-	ALIGN_LEFT, Qt::AlignVCenter + Qt::AlignLeft + Qt::AlignAbsolute,
-	ALIGN_RIGHT, Qt::AlignVCenter + Qt::AlignRight + Qt::AlignAbsolute,
-	ALIGN_CENTER, Qt::AlignVCenter + Qt::AlignHCenter,
-	ALIGN_TOP_NORMAL, Qt::AlignTop + Qt::AlignLeft,
-	ALIGN_TOP_LEFT, Qt::AlignTop + Qt::AlignLeft + Qt::AlignAbsolute,
-	ALIGN_TOP_RIGHT, Qt::AlignTop + Qt::AlignRight + Qt::AlignAbsolute,
-	ALIGN_TOP, Qt::AlignTop + Qt::AlignHCenter,
-	ALIGN_BOTTOM_NORMAL, Qt::AlignBottom + Qt::AlignLeft,
-	ALIGN_BOTTOM_LEFT, Qt::AlignBottom + Qt::AlignLeft + Qt::AlignAbsolute,
-	ALIGN_BOTTOM_RIGHT, Qt::AlignBottom + Qt::AlignRight + Qt::AlignAbsolute,
-	ALIGN_BOTTOM, Qt::AlignBottom + Qt::AlignHCenter,
-	ALIGN_JUSTIFY, Qt::AlignVCenter + Qt::AlignJustify,
+	ALIGN_NORMAL, Qt::AlignVCenter | Qt::AlignLeft,
+	ALIGN_LEFT, Qt::AlignVCenter | Qt::AlignLeft | Qt::AlignAbsolute,
+	ALIGN_RIGHT, Qt::AlignVCenter | Qt::AlignRight | Qt::AlignAbsolute,
+	ALIGN_CENTER, Qt::AlignVCenter | Qt::AlignHCenter,
+	ALIGN_TOP_NORMAL, Qt::AlignTop | Qt::AlignLeft,
+	ALIGN_TOP_LEFT, Qt::AlignTop | Qt::AlignLeft | Qt::AlignAbsolute,
+	ALIGN_TOP_RIGHT, Qt::AlignTop | Qt::AlignRight | Qt::AlignAbsolute,
+	ALIGN_TOP, Qt::AlignTop | Qt::AlignHCenter,
+	ALIGN_BOTTOM_NORMAL, Qt::AlignBottom | Qt::AlignLeft,
+	ALIGN_BOTTOM_LEFT, Qt::AlignBottom | Qt::AlignLeft | Qt::AlignAbsolute,
+	ALIGN_BOTTOM_RIGHT, Qt::AlignBottom | Qt::AlignRight | Qt::AlignAbsolute,
+	ALIGN_BOTTOM, Qt::AlignBottom | Qt::AlignHCenter,
+	ALIGN_JUSTIFY, Qt::AlignVCenter | Qt::AlignJustify,
 	CONST_MAGIC
 };
 
 static int _horizontal_alignment[] =
 {
 	ALIGN_NORMAL, Qt::AlignLeft,
-	ALIGN_LEFT, Qt::AlignLeft + Qt::AlignAbsolute,
-	ALIGN_RIGHT, Qt::AlignRight + Qt::AlignAbsolute,
+	ALIGN_LEFT, Qt::AlignLeft | Qt::AlignAbsolute,
+	ALIGN_RIGHT, Qt::AlignRight | Qt::AlignAbsolute,
 	ALIGN_CENTER, Qt::AlignHCenter,
 	ALIGN_JUSTIFY, Qt::AlignJustify,
 	CONST_MAGIC
@@ -119,6 +119,12 @@ IMPLEMENT_ALIGN(Align_IsLeft, ALIGN_IS_LEFT(a))
 IMPLEMENT_ALIGN(Align_IsRight, ALIGN_IS_RIGHT(a))
 IMPLEMENT_ALIGN(Align_IsCenter, ALIGN_IS_CENTER(a))
 
+BEGIN_METHOD(Align_Make, GB_INTEGER halign; GB_INTEGER valign)
+
+  GB.ReturnInteger(ALIGN_MAKE(VARG(halign), VARG(valign)));
+
+END_METHOD
+
 //-------------------------------------------------------------------------
 
 GB_DESC AlignDesc[] =
@@ -149,6 +155,8 @@ GB_DESC AlignDesc[] =
   GB_STATIC_METHOD("IsCenter", "b", Align_IsCenter, "(Alignment)i"),
   GB_STATIC_METHOD("IsRight", "b", Align_IsRight, "(Alignment)i"),
 
+  GB_STATIC_METHOD("Make", "i", Align_Make, "(Horizontal)i(Vertical)i"),
+
   GB_END_DECLARE
 };
 
