@@ -43,7 +43,6 @@
 #include <QEvent>
 #include <QLayout>
 #include <QEventLoop>
-#include <QDesktopWidget>
 #include <QAction>
 #include <QTimer>
 
@@ -61,6 +60,10 @@
 #include <QWindow>
 #endif
 
+#ifndef QT6
+#include <QDesktopWidget>
+#endif
+
 #include "gambas.h"
 
 #include "CWidget.h"
@@ -68,6 +71,9 @@
 #include "CMenu.h"
 #include "CKey.h"
 #include "CDraw.h"
+#include "CImage.h"
+#include "CColor.h"
+#include "CStyle.h"
 #include "CWindow.h"
 
 #ifndef NO_X_WINDOW
@@ -262,6 +268,8 @@ static void raise_resize_event(void *_object)
 
 static void post_show_event(void *_object)
 {
+	THIS->sx = THIS->x;
+	THIS->sy = THIS->y;
 	GB.Raise(THIS, EVENT_Move, 0);
 	raise_resize_event(THIS);
 	handle_focus(THIS);
@@ -299,7 +307,7 @@ static void reparent_window(CWINDOW *_object, void *parent, bool move, int x = 0
 	if (newParentWidget != WINDOW->parentWidget())
 	{
 		//qDebug("reparent_window: -> %s %p", parent ? ((CWIDGET *)parent)->name : "", parent);
-		WINDOW->doReparent(newParentWidget, p);
+		WINDOW->doReparent(newParentWidget, &p);
 	}
 	else
 		CWIDGET_move(THIS, p.x(), p.y());
@@ -364,7 +372,7 @@ void CWINDOW_move_resize(void *_object, int x, int y, int w, int h)
 	{
 		bool resizable = false;
 	
-		if (WINDOW->isTopLevel() && !WINDOW->isResizable())
+		if (WINDOW->isWindow() && !WINDOW->isResizable())
 		{
 			resizable = true;
 			WINDOW->setResizable(true);
@@ -386,10 +394,55 @@ void CWINDOW_move_resize(void *_object, int x, int y, int w, int h)
 	}
 }
 
+static int get_screen_number(QWidget *widget)
+{
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+	return QApplication::screens().indexOf(widget->screen());
+#else
+	return QApplication::desktop()->screenNumber(widget);
+#endif
+}
+
+void CWINDOW_add_control(CWIDGET *ob)
+{
+	static uint n = 0;
+	CWINDOW *_object;
+	CWIDGET *parent;
+	
+	parent = (CWIDGET *)CWIDGET_get_parent(ob);
+	if (!parent)
+		return;
+	
+	_object = CWidget::getWindow(parent);
+	if (THIS && WINDOW)
+	{
+		n++;
+		ob->key = n;
+		WINDOW->controls.insert(n, ob);
+		//fprintf(stderr, "CWINDOW_add_control : [%d] %s > %s\n", n, THIS->widget.name, ob->name);
+	}
+}
+
+void CWINDOW_remove_control(CWIDGET *ob)
+{
+	CWINDOW *_object;
+	CWIDGET *parent;
+	
+	parent = (CWIDGET *)CWIDGET_get_parent(ob);
+	if (!parent)
+		return;
+	
+	_object = CWidget::getWindow(parent);
+	if (THIS && WINDOW && !WINDOW->isDeleted())
+		WINDOW->controls.remove(ob->key);
+}
+
 //-- Window ---------------------------------------------------------------
 
 BEGIN_METHOD(Window_new, GB_OBJECT parent)
 
+	static bool app_icon = false;
+
 	MyMainWindow *win = 0;
 	MyContainer *container;
 #ifndef NO_X_WINDOW
@@ -531,6 +584,12 @@ BEGIN_METHOD(Window_new, GB_OBJECT parent)
 	#endif
 
 	THIS->showMenuBar = true;
+
+	if (!app_icon)
+	{
+		app_icon = true;
+		CIMAGE_set_default_window_icon();
+	}
 	
 END_METHOD
 
@@ -817,6 +876,25 @@ BEGIN_METHOD(Window_ShowPopup, GB_INTEGER x; GB_INTEGER y)
 END_METHOD
 
 
+#if 0
+BEGIN_METHOD(Window_ShowPopupAt, GB_OBJECT control; GB_INTEGER pos; GB_INTEGER align)
+
+	static GB_FUNCTION func;
+
+	if (!GB_FUNCTION_IS_VALID(&func))
+		GB.GetFunction(&func, (void *)GB.FindClass("_Gui"), "_ShowPopupAt", NULL, NULL);
+
+	GB.Push(4,
+		GB_T_OBJECT, THIS,
+		GB_T_OBJECT, VARG(control),
+		GB_T_INTEGER, VARGOPT(pos, ALIGN_BOTTOM),
+		GB_T_INTEGER, VARGOPT(align, ALIGN_NORMAL));
+
+	GB.Call(&func, 4, FALSE);
+
+END_METHOD
+#endif
+
 BEGIN_PROPERTY(Window_Modal)
 
 	if (THIS->toplevel)
@@ -1143,26 +1221,14 @@ END_PROPERTY
 
 BEGIN_PROPERTY(Window_Controls_Count)
 
-	QList<QWidget *> list = WINDOW->findChildren<QWidget *>();
-	int i;
-	int n = 0;
-	CWIDGET *control;
-
-	for (i = 0; i < list.count(); i++)
-	{
-		control = CWidget::getReal(list.at(i));
-		if (control && !CWIDGET_check(control))
-			n++;
-	}
-
-	GB.ReturnInteger(n);
+	GB.ReturnInteger(WINDOW->controls.count());
 
 END_PROPERTY
 
 
 BEGIN_METHOD_VOID(Window_Controls_next)
 
-	QList<QWidget *> children = WINDOW->findChildren<QWidget *>();
+	QList<uint> keys = WINDOW->controls.keys();
 	CWIDGET *control;
 	int index;
 
@@ -1172,13 +1238,13 @@ BEGIN_METHOD_VOID(Window_Controls_next)
 
 	do
 	{
-		if (index >= children.count())
+		if (index >= keys.count())
 		{
 			GB.StopEnum();
 			return;
 		}
 
-		control = CWidget::getReal(children.at(index));
+		control = WINDOW->controls[keys.at(index)];
 		index++;
 	}
 	while (!control || CWIDGET_check(control));
@@ -1303,7 +1369,7 @@ END_METHOD
 BEGIN_PROPERTY(Window_Opacity)
 
 	if (READ_PROPERTY)
-		GB.ReturnInteger(WIDGET->windowOpacity() * 100);
+		GB.ReturnInteger(WIDGET->windowOpacity() * 100 + 0.5);
 	else
 	{
 		double opacity = VPROP(GB_INTEGER) / 100.0;
@@ -1314,13 +1380,14 @@ BEGIN_PROPERTY(Window_Opacity)
 			opacity = 1.0;
 
 		WIDGET->setWindowOpacity(opacity);
+		WIDGET->update();
 	}
 
 END_PROPERTY
 
 BEGIN_PROPERTY(Window_Screen)
 
-	GB.ReturnInteger(QApplication::desktop()->screenNumber(WIDGET));
+	GB.ReturnInteger(get_screen_number(WIDGET));
 
 END_PROPERTY
 
@@ -1390,6 +1457,29 @@ BEGIN_PROPERTY(Window_MinHeight)
 
 END_PROPERTY
 
+BEGIN_PROPERTY(Window_Geometry)
+
+	GEOM_RECT *rect = GEOM.CreateRect();
+
+	if (THIS->toplevel)
+	{
+		rect->x = THIS->sx;
+		rect->y = THIS->sy;
+		rect->w = THIS->sw;
+		rect->h = THIS->sh;
+	}
+	else
+	{
+		rect->x = THIS->x;
+		rect->y = THIS->y;
+		rect->w = THIS->w;
+		rect->h = THIS->h;
+	}
+
+	GB.ReturnObject(rect);
+
+END_PROPERTY
+
 
 /***************************************************************************/
 
@@ -1461,6 +1551,7 @@ GB_DESC CWindowDesc[] =
 	GB_METHOD("ShowModal", "i", Window_ShowModal, NULL),
 	GB_METHOD("ShowDialog", "i", Window_ShowModal, NULL),
 	GB_METHOD("ShowPopup", "i", Window_ShowPopup, "[(X)i(Y)i]"),
+	//GB_METHOD("ShowPopupAt", "i", Window_ShowPopupAt, "(Control)Control;[(Position)i(Alignment)i]"),
 	GB_METHOD("Center", NULL, Window_Center, NULL),
 	GB_METHOD("Activate", NULL, Window_Activate, NULL),
 
@@ -1504,6 +1595,7 @@ GB_DESC CWindowDesc[] =
 	GB_PROPERTY("Resizable", "b", Window_Resizable),
 
 	GB_PROPERTY_READ("Screen", "i", Window_Screen),
+	GB_PROPERTY_READ("Geometry", "Rect", Window_Geometry),
 
 	GB_PROPERTY_SELF("Menus", ".Window.Menus"),
 	GB_PROPERTY_SELF("Controls", ".Window.Controls"),
@@ -1574,6 +1666,7 @@ MyMainWindow::MyMainWindow(QWidget *parent, const char *name, bool embedded) :
 	_utility = false;
 	_state = windowState();
 	_screen = -1;
+	_ignore_next_close = false;
 
 	//setAttribute(Qt::WA_KeyCompression, true);
 	//setAttribute(Qt::WA_InputMethodEnabled, true);
@@ -1648,17 +1741,24 @@ void MyMainWindow::showEvent(QShowEvent *e)
 }
 
 
-void MyMainWindow::initProperties(int which)
+void MyMainWindow::initProperties(int which, bool force)
 {
 	CWIDGET *_object = CWidget::get(this);
 
 	if (!THIS->toplevel) // || effectiveWinId() == 0)
 		return;
 
+	if (!force && !isVisible())
+		return;
+
 	if (!THIS->title && _border)
 		setWindowTitle(TO_QSTRING(GB.Application.Title()));
 
+	if (effectiveWinId() == 0)
+		createWinId();
+
 	#ifdef QT5
+
 		QT_WINDOW_PROP prop;
 		
 		prop.stacking = THIS->stacking;
@@ -1667,9 +1767,9 @@ void MyMainWindow::initProperties(int which)
 		prop.sticky = THIS->sticky;
 		
 		PLATFORM.Window.SetProperties(this, which, &prop);
+
 	#else
-		if (effectiveWinId() == 0)
-			return;
+
 		X11_flush();
 
 		if (which & (PROP_STACKING | PROP_SKIP_TASKBAR))
@@ -1698,6 +1798,7 @@ void MyMainWindow::initProperties(int which)
 			X11_window_set_desktop(effectiveWinId(), isVisible(), THIS->sticky ? 0xFFFFFFFF : X11_get_current_desktop());
 
 		X11_flush();
+
 	#endif
 }
 
@@ -1750,7 +1851,7 @@ void MyMainWindow::present(QWidget *parent)
 	qDebug("present: %p %s: parent = %p %s", THIS, _object->name, _parent, _parent ? _parent->name : "");*/
 
 	if (parent)
-		_screen = QApplication::desktop()->screenNumber(parent);
+		_screen = get_screen_number(parent);
 	else
 		_screen = -1;
 
@@ -1762,15 +1863,25 @@ void MyMainWindow::present(QWidget *parent)
 
 		setAttribute(Qt::WA_ShowWithoutActivating, THIS->noTakeFocus);
 
-#ifdef QT5
+/*#ifdef QT5
 		if (MAIN_platform_is_wayland)
-			initProperties(PROP_ALL);
+			initProperties(PROP_ALL, true);
 #else
 		if (effectiveWinId() == 0)
 		{
 			createWinId();
 		}
-		initProperties(PROP_ALL);
+		initProperties(PROP_ALL, true);
+#endif*/
+
+#ifdef QT5
+		if (THIS->noTakeFocus)
+			PLATFORM.Window.SetUserTime(this, 0);
+#endif
+		initProperties(PROP_ALL, true);
+#ifdef QT5
+		if (THIS->noTakeFocus)
+			PLATFORM.Window.SetUserTime(this, 0);
 #endif
 
 		if (getState() & Qt::WindowMinimized)
@@ -1782,18 +1893,23 @@ void MyMainWindow::present(QWidget *parent)
 		else
 			show();
 
-#ifdef QT5
+/*#ifdef QT5
 		if (!MAIN_platform_is_wayland)
 		{
 			//qDebug("createWinId: %p", (void *)effectiveWinId());
 			if (THIS->noTakeFocus)
 				PLATFORM.Window.SetUserTime(this, 0);
-			initProperties(PROP_ALL);
+			initProperties(PROP_ALL, true);
 			if (THIS->noTakeFocus)
 				PLATFORM.Window.SetUserTime(this, 0);
 		}
 #else
-		initProperties(PROP_SKIP_TASKBAR);
+		initProperties(PROP_SKIP_TASKBAR, true);
+#endif*/
+
+#ifdef QT5
+#else
+		initProperties(PROP_SKIP_TASKBAR, true);
 #endif
 
 		/*if (isUtility() && _resizable)
@@ -1843,7 +1959,7 @@ void MyMainWindow::showActivate(QWidget *transient)
 		{
 			if (newParentWidget && parentWidget() != newParentWidget)
 			{
-				doReparent(newParentWidget, pos());
+				doReparent(newParentWidget);
 			}
 		}
 	}
@@ -1855,7 +1971,17 @@ void MyMainWindow::showActivate(QWidget *transient)
 	if (isUtility())
 	{
 		if (!newParentWidget && CWINDOW_Main && THIS != CWINDOW_Main)
-			newParentWidget = CWidget::getTopLevel((CWIDGET *)CWINDOW_Main)->widget.widget;
+		{
+			if (CWINDOW_Active)
+				newParentWidget = CWidget::getTopLevel((CWIDGET *)CWINDOW_Active)->widget.widget;
+			else if (CWINDOW_Main)
+				newParentWidget = ((CWIDGET *)CWINDOW_Main)->widget;
+
+			if (newParentWidget && parentWidget() != newParentWidget)
+			{
+				doReparent(newParentWidget);
+			}
+		}
 	}
 
 	present(newParentWidget);
@@ -1890,7 +2016,7 @@ void on_error_show_modal(MODAL_INFO *info)
 	CWIDGET_leave_popup(info->save_popup);
 }
 
-void MyMainWindow::doShowModal(bool popup, const QPoint *pos)
+void MyMainWindow::doShowModal(bool popup, const QPoint *p)
 {
 	CWIDGET *_object = CWidget::get(this);
 	CWINDOW *parent;
@@ -1923,7 +2049,10 @@ void MyMainWindow::doShowModal(bool popup, const QPoint *pos)
 			setParent(CWidget::getTopLevel((CWIDGET *)parent)->widget.widget, Qt::Popup | info.flags);
 
 		move(0, 0);
-		move(*pos);
+		move(*p);
+		THIS->x = p->x();
+		THIS->y = p->y();
+		//fprintf(stderr, "doShowModal: popup: %d %d\n", pos().x(), pos().y());
 		setFocus();
 		show();
 		raise();
@@ -1991,165 +2120,6 @@ void MyMainWindow::doShowModal(bool popup, const QPoint *pos)
 	}
 }
 
-#if 0
-void MyMainWindow::showModal(void)
-{
-	//Qt::WindowFlags flags = windowFlags() & ~Qt::WindowType_Mask;
-	CWIDGET *_object = CWidget::get(this);
-	CWINDOW *parent;
-	bool persistent = CWIDGET_test_flag(THIS, WF_PERSISTENT);
-	//QPoint p = pos();
-	QEventLoop eventLoop;
-	GB_ERROR_HANDLER handler;
-	MODAL_INFO info;
-
-	if (THIS->modal)
-		return;
-
-	CWIDGET_finish_focus();
-
-	info.that = this;
-	info.old = MyApplication::eventLoop;
-	info.save = CWINDOW_Current;
-
-	MyApplication::eventLoop = &eventLoop;
-
-	setWindowModality(Qt::ApplicationModal);
-
-	if (_resizable && _border)
-	{
-		setMinimumSize(THIS->minw, THIS->minh);
-		setSizeGrip(true);
-	}
-
-	_enterLoop = false; // Do not call exitLoop() if we do not entered the loop yet!
-
-	parent = CWINDOW_Current;
-	if (!parent)
-	{
-		parent = CWINDOW_Main;
-		if (!parent)
-			parent = CWINDOW_Active;
-	}
-
-	present(parent ? CWidget::getTopLevel((CWIDGET *)parent)->widget.widget : 0);
-	setEventLoop();
-
-	THIS->loopLevel++;
-	CWINDOW_Current = THIS;
-
-	_enterLoop = true;
-
-	GB.Debug.EnterEventLoop();
-
-	handler.handler = (GB_CALLBACK)on_error_show_modal;
-	handler.arg1 = (intptr_t)&info;
-
-	GB.OnErrorBegin(&handler);
-
-	eventLoop.exec();
-
-	GB.OnErrorEnd(&handler);
-
-	GB.Debug.LeaveEventLoop();
-	
-	//eventLoop.processEvents(QEventLoop::ExcludeUserInputEvents | QEventLoop::DeferredDeletion, 0);
-
-	MyApplication::eventLoop = info.old;
-	CWINDOW_Current = info.save;
-
-	if (persistent)
-	{
-		setSizeGrip(false);
-		setWindowModality(Qt::NonModal);
-	}
-
-	CWINDOW_ensure_active_window();
-}
-
-void MyMainWindow::showPopup(QPoint &pos)
-{
-	Qt::WindowFlags flags = windowFlags() & ~Qt::WindowType_Mask;
-	CWIDGET *_object = CWidget::get(this);
-	bool persistent = CWIDGET_test_flag(THIS, WF_PERSISTENT);
-	CWINDOW *save = CWINDOW_Current;
-	void *save_popup;
-	QEventLoop eventLoop;
-	QEventLoop *old;
-
-	if (THIS->modal)
-		return;
-
-	CWIDGET_finish_focus();
-
-	setWindowFlags(Qt::Popup | flags);
-	setWindowModality(Qt::ApplicationModal);
-	THIS->popup = true;
-
-	/*if (_resizable && _border)
-	{
-		setMinimumSize(THIS->minw, THIS->minh);
-		setSizeGrip(true);
-	}*/
-
-	_enterLoop = false; // Do not call exitLoop() if we do not entered the loop yet!
-
-	move(0, 0);
-	move(pos);
-	setFocus();
-	show();
-	raise();
-	setEventLoop();
-	//QTimer::singleShot(50, this, SLOT(activateLater()));
-
-	THIS->loopLevel++;
-	CWINDOW_Current = THIS;
-
-	//handle_focus(THIS);
-	//activateWindow();
-
-	save_popup = CWIDGET_enter_popup();
-
-	_enterLoop = true;
-
-	old = MyApplication::eventLoop;
-	MyApplication::eventLoop = &eventLoop;
-	GB.Debug.EnterEventLoop();
-	eventLoop.exec();
-	GB.Debug.LeaveEventLoop();
-	MyApplication::eventLoop = old;
-	//eventLoop.exec();
-	//eventLoop.processEvents(QEventLoop::ExcludeUserInputEvents | QEventLoop::DeferredDeletion, 0);
-
-	CWINDOW_Current = save;
-
-	if (persistent)
-	{
-		setWindowModality(Qt::NonModal);
-		setWindowFlags(Qt::Window | flags);
-		THIS->popup = false;
-	}
-
-	CWIDGET_leave_popup(save_popup);
-
-	//CWIDGET_check_hovered();
-}
-#endif
-
-#if 0
-void MyMainWindow::setTool(bool t)
-{
-	WFlags f = getWFlags();
-
-	if (t)
-		f |=  WStyle_Tool | WStyle_Customize;
-	else
-		f &= ~WStyle_Tool;
-
-	doReparent(CWINDOW_Main ? (MyMainWindow *)QWIDGET(CWINDOW_Main) : 0, f, pos());
-}
-#endif
-
 void MyMainWindow::moveSizeGrip()
 {
 	CWINDOW *window;
@@ -2201,26 +2171,28 @@ void MyMainWindow::setBorder(bool b)
 
 #ifdef QT5
 	
-	bool visible = isVisible();
-	void *_object = CWidget::get(this);;
+	/*bool visible = isVisible();
+	void *_object = CWidget::get(this);;*/
 	
-	if (_border)
+	/*if (_border)
 		setWindowFlags(windowFlags() & ~Qt::FramelessWindowHint);
 	else
-		setWindowFlags(windowFlags() | Qt::FramelessWindowHint);
+		setWindowFlags(windowFlags() | Qt::FramelessWindowHint);*/
 	
-	if (visible) 
+	/*if (visible)
 	{
 		show();
 		move(THIS->x, THIS->y);
-	}
+	}*/
+
+	initProperties(PROP_ALL);
 
 #else
 
 	initProperties(PROP_BORDER);
 	if (effectiveWinId())
 		X11_window_remap(effectiveWinId());
-	doReparent(parentWidget(), pos());
+	doReparent(parentWidget());
 	
 #endif
 }
@@ -2233,7 +2205,7 @@ void MyMainWindow::setResizable(bool b)
 	_resizable = b;
 	if (!isWindow())
 		return;
-	doReparent(parentWidget(), pos());
+	doReparent(parentWidget());
 }
 
 void MyMainWindow::setUtility(bool b)
@@ -2242,8 +2214,10 @@ void MyMainWindow::setUtility(bool b)
 		return;
 
 	_utility = b;
+	if (!isWindow())
+		return;
 
-	doReparent(parentWidget(), pos());
+	doReparent(parentWidget());
 }
 
 #if 0
@@ -2296,6 +2270,11 @@ void MyMainWindow::moveEvent(QMoveEvent *e)
 		{
 			THIS->x = x();
 			THIS->y = y();
+			if ((_state & (Qt::WindowMinimized | Qt::WindowMaximized | Qt::WindowFullScreen)) == 0)
+			{
+				THIS->sx = THIS->x;
+				THIS->sy = THIS->y;
+			}
 			//qDebug("moveEvent: x= %d y = %d", x(), y());
 		}
 	}
@@ -2335,8 +2314,15 @@ void MyMainWindow::resizeEvent(QResizeEvent *e)
 	{
 		THIS->w = THIS->container->width();
 		THIS->h = THIS->container->height();
-		if (isTopLevel())
+		if (isWindow())
+		{
+			if ((_state & (Qt::WindowMinimized | Qt::WindowMaximized | Qt::WindowFullScreen)) == 0)
+			{
+				THIS->sw = THIS->w;
+				THIS->sh = THIS->h;
+			}
 			CCONTAINER_arrange(THIS);
+		}
 	}
 
 #ifndef NO_X_WINDOW
@@ -2349,7 +2335,7 @@ void MyMainWindow::resizeEvent(QResizeEvent *e)
   	//qDebug("resizeEvent %ld %ld isHidden:%s shown:%s ", THIS->w, THIS->h, isHidden() ? "1" : "0", shown ? "1" : "0");
 	//qDebug("THIS->h = %ld  THIS->container->height() = %ld  height() = %ld", THIS->h, THIS->container->height(), height());
 
-	if (THIS->opened && (e->spontaneous() || parentWidget()))
+	if (THIS->opened) // && (e->spontaneous() || parentWidget()))
 		raise_resize_event(THIS);
 }
 
@@ -2489,6 +2475,12 @@ void MyMainWindow::closeEvent(QCloseEvent *e)
 	//fprintf(stderr, "closeEvent(): THIS = %p loopLevel = %d CWINDOW_Current = %p\n", THIS, THIS->loopLevel, CWINDOW_Current);
 	
 	e->ignore();
+	
+	if (_ignore_next_close)
+	{
+		_ignore_next_close = false;
+		return;
+	}
 
 	#if DEBUG_WINDOW
 		qDebug("closeEvent: CWINDOW_Current = %p / %d <-> %p / %d", CWINDOW_Current, CWINDOW_Current ? CWINDOW_Current->loopLevel : -1, THIS, THIS->loopLevel);
@@ -2581,7 +2573,7 @@ void MyMainWindow::setPersistent(bool pers)
 	setAttribute(Qt::WA_DeleteOnClose, !pers);
 }
 
-void MyMainWindow::doReparent(QWidget *parent, const QPoint &pos)
+void MyMainWindow::doReparent(QWidget *parent, const QPoint *p)
 {
 	CWINDOW *_object = (CWINDOW *)CWidget::get(this);
 	QIcon icon;
@@ -2603,7 +2595,9 @@ void MyMainWindow::doReparent(QWidget *parent, const QPoint &pos)
 
 	if (THIS->toplevel)
 	{
-		if (_utility)
+		if (THIS->popup)
+			f |= Qt::Popup;
+		else if (_utility)
 			f |= Qt::Dialog;
 		else
 			f |= Qt::Window;
@@ -2631,12 +2625,16 @@ void MyMainWindow::doReparent(QWidget *parent, const QPoint &pos)
 	if (parent != parentWidget() || f != windowFlags())
 	{
 		reparented = true;
+		CWINDOW_remove_control((CWIDGET *)THIS);
 		setParent(parent, f);
 		//qDebug("setParent %d", f != windowFlags());
+		CWINDOW_add_control((CWIDGET *)THIS);
 	}
 
-	move(pos);
-	//qDebug("doReparent: (%s %p) (%d %d) -> (%d %d)", GB.GetClassName(THIS), THIS, pos.x(), pos.y(), WIDGET->x(), WIDGET->y());
+	if (p)
+		move(*p);
+	else
+		move(THIS->x, THIS->y);
 
 	if (!THIS->embedded)
 	{
@@ -2683,9 +2681,9 @@ int MyMainWindow::currentScreen() const
 		return _screen;
 
 	if (CWINDOW_Active)
-		return QApplication::desktop()->screenNumber(CWINDOW_Active->widget.widget);
+		return get_screen_number(CWINDOW_Active->widget.widget);
 	else if (CWINDOW_Main)
-		return QApplication::desktop()->screenNumber(CWINDOW_Main->widget.widget);
+		return get_screen_number(CWINDOW_Main->widget.widget);
 	else
 #ifndef QT5
 		return QApplication::desktop()->primaryScreen();
@@ -2713,15 +2711,33 @@ void MyMainWindow::center()
 	CWIDGET_move(THIS, r.x() + (r.width() - width()) / 2, r.y() + (r.height() - height()) / 2);
 }
 
+#if 0
+void MyMainWindow::paintEvent(QPaintEvent *e)
+{
+	if (CSTYLE_fix_breeze && isWindow())
+	{
+		QPainter p(this);
+		p.fillRect(0, 0, width(), 1, CCOLOR_light_foreground());
+	}
+}
+#endif
+
 void MyMainWindow::configure()
 {
 	CWINDOW *_object = (CWINDOW *)CWidget::get(this);
 	QMenuBar *menuBar = THIS->menuBar;
 	bool arrange = false;
 	QRect geom;
+	int d;
 
 	//qDebug("THIS->menuBar = %p  menuBar() = %p", THIS->menuBar, menuBar());
 
+	// sometimes configure() seems to be called when the window is being deleted
+	if (CWIDGET_check(THIS))
+		return;
+
+	d = 0; //CSTYLE_fix_breeze && isWindow() ? 1 : 0;
+
 	if (menuBar && THIS->showMenuBar && !THIS->hideMenuBar)
 	{
 		int h = menuBar->sizeHint().height();
@@ -2730,14 +2746,14 @@ void MyMainWindow::configure()
 			h = menuBar->height();
 
 		menuBar->show();
-		geom = QRect(0, h, this->width(), this->height() - h);
+		geom = QRect(0, h + d, this->width(), this->height() - h - d);
 
 		if (THIS->container->geometry() != geom)
 		{
 			arrange = true;
 			THIS->container->setGeometry(geom);
 		}
-		menuBar->setGeometry(0, 0, this->width(), h);
+		menuBar->setGeometry(0, d, this->width(), h);
 	}
 	else
 	{
@@ -2747,7 +2763,7 @@ void MyMainWindow::configure()
 			menuBar->lower();
 		}
 
-		geom = QRect(0, 0, this->width(), this->height());
+		geom = QRect(0, d, this->width(), this->height() - d);
 
 		if (THIS->container->geometry() != geom)
 		{
@@ -2819,21 +2835,21 @@ void MyMainWindow::changeEvent(QEvent *e)
 	}
 	else if (e->type() == QEvent::WindowStateChange)
 	{
+		_state = windowState();
 		GB.Raise(CWidget::get(this), EVENT_State, 0);
 	}
 }
 
 Qt::WindowStates MyMainWindow::getState() const
 {
-	return isVisible() ? windowState() : _state;
+	return _state;
 }
 
 void MyMainWindow::setState(Qt::WindowStates state)
 {
+	_state = state;
 	if (isVisible())
 		setWindowState(state);
-	else
-		_state = state;
 }
 
 void MyMainWindow::setVisible(bool visible)
