@@ -53,6 +53,7 @@
 #include <QPaintDevice>
 #include <QLibraryInfo>
 #include <QThreadPool>
+#include <QScreen>
 
 #include "gb.image.h"
 #include "gb.form.font.h"
@@ -83,7 +84,6 @@
 #include "CDraw.h"
 #include "CWatch.h"
 #include "CDrawingArea.h"
-#include "CSlider.h"
 #include "CScrollBar.h"
 #include "CWatcher.h"
 #include "cprinter.h"
@@ -142,7 +142,6 @@ static int _prevent_quit = 0;
 
 static QHash<void *, void *> _link_map;
 
-
 static QByteArray _utf8_buffer[UTF8_NBUF];
 static int _utf8_count = 0;
 static int _utf8_length = 0;
@@ -359,6 +358,7 @@ MyApplication::MyApplication(int &argc, char **argv)
 	}
 
 	QObject::connect(this, SIGNAL(commitDataRequest(QSessionManager &)), SLOT(commitDataRequested(QSessionManager &)));
+	QObject::connect(this, SIGNAL(paletteChanged(const QPalette &)), SLOT(paletteHasChanged(const QPalette &)));
 }
 
 void MyApplication::initClipboard()
@@ -371,6 +371,16 @@ void MyApplication::clipboardHasChanged(QClipboard::Mode m)
 	CLIPBOARD_has_changed(m);
 }
 
+void MyApplication::paletteHasChanged(const QPalette &)
+{
+	if (COLOR_update_palette())
+	{
+		//fprintf(stderr, "updatePalette\n");
+		APPLICATION_update_dark_theme();
+		APPLICATION_send_change_event(CHANGE_COLOR);
+	}
+}
+
 static bool QT_EventFilter(QEvent *e)
 {
 	bool cancel;
@@ -414,6 +424,7 @@ static bool QT_EventFilter(QEvent *e)
 	return cancel;
 }
 
+#if 0
 static bool QT_Notify(CWIDGET *object, bool value)
 {
 	bool old = object->flag.notified;
@@ -421,6 +432,7 @@ static bool QT_Notify(CWIDGET *object, bool value)
 	object->flag.notified = value;
 	return old;
 }
+#endif
 
 bool MyApplication::eventFilter(QObject *o, QEvent *e)
 {
@@ -615,7 +627,7 @@ void MAIN_check_quit(void)
 
 void MAIN_update_scale(const QFont &font)
 {
-	MAIN_scale = GET_DESKTOP_SCALE(font.pointSize(), PLATFORM.Desktop.GetResolutionY());
+	MAIN_scale = GET_DESKTOP_SCALE(font.pointSize(), QGuiApplication::primaryScreen()->logicalDotsPerInch());
 }
 
 static void QT_InitEventLoop(void)
@@ -819,9 +831,9 @@ static void hook_wait(int duration)
 	
 	if (duration >= 0)
 		qApp->processEvents(QEventLoop::AllEvents, duration);
-	else if (duration == -1)
+	else if (duration == GB_WAIT_NO_USER_INPUT)
 		qApp->processEvents(QEventLoop::ExcludeUserInputEvents, 0);
-	else if (duration == -2)
+	else if (duration == GB_WAIT_FOR_NEXT_EVENT)
 		qApp->processEvents(QEventLoop::AllEvents | QEventLoop::WaitForMoreEvents);
 	
 	MAIN_in_wait--;
@@ -925,8 +937,8 @@ static void QT_Init(void)
 
 	char *appid = GB.ToZeroString((GB_STRING *)CALL_GUI("_InitApp", NULL, "s", 0, FALSE));
 
-	//fprintf(stderr, "appid = %s\n", appid);
-	qApp->setDesktopFileName(TO_QSTRING(appid));
+	if (*appid)
+		qApp->setDesktopFileName(TO_QSTRING(appid));
 
 	#endif
 	
@@ -978,6 +990,9 @@ static void QT_Init(void)
 	if (env && atoi(env) != 0)
 		MAIN_key_debug = TRUE;
 	
+	COLOR_update_palette();
+	APPLICATION_update_dark_theme();
+
 	GB.Hook(GB_HOOK_WAIT, (void *)hook_wait);
 	GB.Hook(GB_HOOK_TIMER, (void *)hook_timer);
 	GB.Hook(GB_HOOK_WATCH, (void *)hook_watch);
@@ -1132,7 +1147,7 @@ GB_DESC *GB_CLASSES[] EXPORT =
 	CPanelDesc, CHBoxDesc, CVBoxDesc, CHPanelDesc, CVPanelDesc,
 	CTabStripContainerChildrenDesc, CTabStripContainerDesc, CTabStripDesc,
 	CDrawingAreaDesc,
-	SliderDesc, ScrollBarDesc,
+	ScrollBarDesc,
 	CWindowMenusDesc, CWindowControlsDesc, CWindowDesc, CWindowsDesc, CFormDesc,
 	CDialogDesc,
 	CWatcherDesc,
@@ -1165,7 +1180,6 @@ void *GB_QT5_1[] EXPORT =
 	(void *)QT_NewString,
 	(void *)QT_ReturnNewString,
 	(void *)QT_EventFilter,
-	(void *)QT_Notify,
 	(void *)CCONST_alignment,
 	(void *)QT_Link,
 	(void *)QT_GetLink,
