@@ -2,14 +2,11 @@
 
   Cfont.h
 
-  Gambas extension using SDL
-
   (c) 2007 Laurent Carlier <lordheavy@users.sourceforge.net>
-           Benoît Minisini <gambas@users.sourceforge.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -19,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -28,23 +26,22 @@
 
 #include "SDLfont.h"
 
-#include "gambas.h"
+#include "main.h"
 
 #ifndef __CFONT_CPP
-//extern GB_DESC CFont[];
-extern GB_DESC CFonts[];
-
+extern GB_DESC CFont[];
+//extern GB_DESC CFonts[];
 #else
 
-//#define THIS OBJECT(CFONT)
-
-#endif
+#define THIS ((CFONT *)_object)
+#define FONT ((CFONT *)_object)->font
+#endif /* __CFONT_CPP */
 
 typedef
 	struct {
 		GB_BASE ob;
-		// QString *family;
+		SDLfont *font;
 	}
-	CFONTINFO;
+	CFONT;
 
-#endif
+#endif /* __CFONT_H */
