@@ -2,14 +2,11 @@
 
   Cmouse.h
 
-  Gambas extension using SDL
-
   (c) 2006 Laurent Carlier <lordheavy@users.sourceforge.net>
-           Benoît Minisini <gambas@users.sourceforge.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -19,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -40,12 +38,13 @@ typedef
     int relx;
     int rely;
     int state;
+    SDLMod keymod;
     }
   CMOUSE_INFO;
 
 #ifndef __CMOUSE_CPP
 extern GB_DESC CMouse[];
-extern GB_DESC CCursor[];
+//extern GB_DESC CCursor[];
 extern CMOUSE_INFO CMOUSE_info;
 #else
 
