@@ -2,14 +2,11 @@
 
   SDLapp.cpp
 
-  Gambas extension using SDL
-
   (c) 2006 Laurent Carlier <lordheavy@users.sourceforge.net>
-           Benoît Minisini <gambas@users.sourceforge.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -19,16 +16,16 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
 #include "SDLapp.h"
 
 #include "SDLcore.h"
-
-#include "SDL.h"
-#include "SDL_syswm.h"
+#include "SDLwindow.h"
+#include "SDL_ttf.h"
 
 #include <iostream>
 #include <string>
@@ -47,13 +44,13 @@ SDLapplication::SDLapplication(int &argc, char **argv)
 		return;
 	}
 
-	std::string sMsg = "Failed to init : ";
+	std::string sMsg = "Failed to init: ";
 	Uint32 sysInit = SDL_WasInit(SDL_INIT_EVERYTHING);
 
 	// if audio is defined, sdl was init by gb.sdl.sound component !
 	if (sysInit & SDL_INIT_AUDIO)
 	{
-		if (SDL_InitSubSystem(SDL_INIT_VIDEO)<0)
+		if (SDL_InitSubSystem(SDL_INIT_VIDEO | SDL_INIT_JOYSTICK)<0)
 		{
 			sMsg =+ SDL_GetError();
 			goto _error;
@@ -61,23 +58,31 @@ SDLapplication::SDLapplication(int &argc, char **argv)
 	}
 	else
 	{
- 		if (SDL_Init(SDL_INIT_VIDEO | SDL_INIT_TIMER | SDL_INIT_NOPARACHUTE)<0)
+ 		if (SDL_Init(SDL_INIT_VIDEO | SDL_INIT_TIMER | SDL_INIT_NOPARACHUTE | SDL_INIT_JOYSTICK)<0)
 		{
 			sMsg =+ SDL_GetError();
 			goto _error;
 		}
 	}
 
-	SDLcore::Init();
-	SDLcore::RegisterApplication(this);
+	if (TTF_Init()<0)
+	{
+		sMsg =+ TTF_GetError();
+		goto _error;
+	}
+
 	SDLapp = this;
+	
+	SDL_EnableUNICODE(1);
+	
+	SDLcore::Init();
+	SDLdebug::Init();
 
 	return;
 
 _error:
 	std::cout << sMsg << std::endl;
 	exit (-1);
-
 }
 
 SDLapplication::~SDLapplication()
@@ -89,20 +94,38 @@ SDLapplication::~SDLapplication()
 		return;
 	}
 
+	TTF_Quit();
 	Uint32 sysInit = SDL_WasInit(SDL_INIT_EVERYTHING);
 
 	// if audio is defined, gb.sdl.audio component still not closed !
 	if (sysInit & SDL_INIT_AUDIO)
-		SDL_QuitSubSystem(SDL_INIT_VIDEO);
+		SDL_QuitSubSystem(SDL_INIT_VIDEO | SDL_INIT_JOYSTICK);
 	else
-		SDL_Quit();	
+		SDL_Quit();
 }
 
-void SDLapplication::ManageEvents()
+static int poll_event(SDL_Event *event, bool no_input)
+{
+	uint mask;
+	
+	SDL_PumpEvents();
+
+	mask = SDL_ALLEVENTS;
+	if (no_input)
+		mask ^= SDL_KEYEVENTMASK | SDL_MOUSEEVENTMASK | SDL_JOYEVENTMASK | SDL_QUITMASK;
+	
+	/* We can't return -1, just return 0 (no event) on error */
+	if ( SDL_PeepEvents(event, 1, SDL_GETEVENT, mask) <= 0 )
+		return 0;
+	return 1;
+}
+
+
+void SDLapplication::ManageEvents(bool no_input)
 {
 	SDL_Event event;
 
-	while (SDL_PollEvent(&event))
+	while (poll_event(&event, no_input))
 	{
 		if (!this->HaveWindows())
 			break;
@@ -134,9 +157,18 @@ void SDLapplication::ManageEvents()
 				SDLcore::GetWindow()->Resize();
 
 				 // take care if window is closed during resize
-				if (this->HaveWindows() && !SDLcore::GetWindow()->IsOpenGL())
+				if (this->HaveWindows())
 					SDLcore::GetWindow()->Show();
 				break;
+			case SDL_JOYAXISMOTION:
+			case SDL_JOYHATMOTION:
+			case SDL_JOYBALLMOTION:
+			case SDL_JOYBUTTONDOWN:
+			case SDL_JOYBUTTONUP:
+				// Only raise joysticks events if window has input keyboard focus
+				if (SDL_GetAppState() & SDL_APPINPUTFOCUS)
+					SDLcore::GetWindow()->JoyEvent(event);
+				break;
 			case SDL_KEYDOWN:
 			case SDL_KEYUP:
 				SDLcore::GetWindow()->KeyEvent(&event.key, event.type);
@@ -207,62 +239,7 @@ Display *SDLapplication::X11appDisplay()
 
 	return (display);
 }
-#if 0
-long SDLapplication::GetExtents()
-{
-	long RetData = 0;
 
-	XEvent xevent;
-	XEvent notifyXevent;
-	Window windowId;
-	Atom type_ret;
-	int format_ret;
-	unsigned long nitems_ret, unused;
-	unsigned char *data_ret;
-
-	LockX11();
-	Atom AtomReqExtents = XInternAtom(SDLapp->X11appDisplay(), "_NET_REQUEST_FRAME_EXTENTS", false);
-	Atom AtomFraExtents = XInternAtom(SDLapp->X11appDisplay(), "_NET_FRAME_EXTENTS", false);
-
-	if ((AtomReqExtents == None) || (AtomFraExtents == None))
-		std::cout << "Frame extents : something goes wrong" << std::endl;
-
-	windowId = X11appRootWin();
-	xevent.xclient.type = ClientMessage;
-	xevent.xclient.message_type = AtomReqExtents;
-	xevent.xclient.display = X11appDisplay();
-	xevent.xclient.window = windowId;
-	xevent.xclient.format = 32;
-	xevent.xclient.data.l[0] = 0;
-	xevent.xclient.data.l[1] = 0;
-	xevent.xclient.data.l[2] = 0;
-	xevent.xclient.data.l[3] = 0;
-	xevent.xclient.data.l[4] = 0;
-
-	XSendEvent (X11appDisplay(), X11appRootWin(), False,
-		(SubstructureRedirectMask | SubstructureNotifyMask),
-		&xevent);
-
-	XIfEvent(X11appDisplay(), &notifyXevent,
-		property_notify_predicate, (XPointer) &windowId);
-
-	if (XGetWindowProperty(X11appDisplay(), CurrentWin(), AtomFraExtents, 0l,
-		sizeof (unsigned long) * 4, False, XA_CARDINAL, &type_ret,
-		&format_ret, &nitems_ret, &unused, &data_ret) == Success)
-	{
-		RetData = data_ret[1];
-		XFree(data_ret);
-	}
-	else
-		std::cout << "Unable to get FrameExtents !" << std::endl;	
-
-	UnlockX11();
-
-	std::cout << RetData << std::endl;
-
-	return RetData;
-}
-#endif
 void SDLapplication::LockX11()
 {
 	SDLapplication::LockX11Count++;
@@ -287,44 +264,3 @@ void SDLapplication::UnlockX11()
 	info.info.x11.unlock_func();
 }
 
-void SDLapplication::process_cmdline( int* argcptr, char ** argv )
-{
-#if 0
-	int argc = *argcptr;
-	int i, j;
-
-	j = 1;
-	for ( i=1; i<argc; i++ )
-	{
-		if ( argv[i] && *argv[i] != '-' )
-		{
-			argv[j++] = argv[i];
-			continue;
-		}
-
-		std::string arg = argv[i];
-		std::string s;
-
-	if ( arg == "-qdevel" || arg == "-qdebug") {
-	    // obsolete argument
-	} else if ( arg.find( "-style=", 0, FALSE ) != -1 ) {
-	    s = arg.right( arg.length() - 7 );
-	} else if ( qstrcmp(arg,"-style") == 0 && i < argc-1 ) {
-	    s = argv[++i];
-	    s = s.lower();
-	} else if ( qstrcmp(arg, "-reverse") == 0 ) {
-	    setReverseLayout( TRUE );
-	} else if ( qstrcmp(arg, "-widgetcount") == 0 ) {
-	    widgetCount = TRUE;;
-	} else {
-	    argv[j++] = argv[i];
-	}
-
-	}
-
-		argv[j] = 0;
-		*argcptr = j;
-	}
-#endif
-}
-
