@@ -2,14 +2,11 @@
 
   SDLcursor.h
 
-  Gambas extension using SDL
-
   (c) 2006 Laurent Carlier <lordheavy@users.sourceforge.net>
-           Benoît Minisini <gambas@users.sourceforge.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -19,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -29,7 +27,7 @@
 #include "SDL_h.h"
 #include "SDLsurface.h"
 
-#include <X11/Xlib.h> // needed with xorg 7.0, already included with xorg 7.1 in Xcursor.h
+#include <X11/Xlib.h>
 #include <X11/Xcursor/Xcursor.h>
 
 class SDLcursor
@@ -39,11 +37,11 @@ public:
 	SDLcursor(const SDLcursor& cursor);
 	~SDLcursor();
 
-	void Show(void );
+	void Show(Window );
 	void SetShape(int );
 	void SetCursor(SDLsurface* image, int xhot = -1, int yhot = -1);
 
-	int GetShape(void );
+	int GetShape(void ) { return hShape; }
 
 private:
 	Cursor hCursor;
