@@ -2,20 +2,11 @@
 
   main.h
 
-  Webcam capture component
-
   (C) 2005-2008 Daniel Campos Fernández <dcamposf@gmail.com>
-  
-  Based on the GPL code from "video-capture":
-  
-      (#) video-capture.c - modified from vidcat.c
-      Copyright (C) 1998 Rasca, Berlin
-      EMail: thron@gmx.de
-      Modifications (C) 2001, Nick Andrew <nick@nick-andrew.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -25,22 +16,21 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
 #ifndef __MAIN_H
 #define __MAIN_H
 
-
-
-
 #include "gambas.h"
-
-
+#include "gb_common.h"
+#include "gb.image.h"
 
 #ifndef __MAIN_C
 extern GB_INTERFACE GB;
+extern IMAGE_INTERFACE IMAGE;
 #endif
 
 #endif
