@@ -1,14 +1,10 @@
 /***************************************************************************
 
-  main.h
-
-  libxml++ wrapper
-
-  (c) 2004 Daniel Campos Fernández <danielcampos@netcourrier.com> 
+  (c) 2012 Adrien Prokopowicz <prokopy@users.sourceforge.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -18,19 +14,19 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
-#ifndef __MAIN_H
-#define __MAIN_H
+#ifndef MAIN_H
+#define MAIN_H
 
+#include "gb.xml.h"
+#include "html/gb.xml.html.h"
 
-#include "gambas.h"
+extern "C" XML_HTML_INTERFACE HTML;
 
+bool CheckHtmlInterface();
 
-#ifndef __MAIN_C
-extern GB_INTERFACE GB;
-#endif
-
-#endif
+#endif // MAIN_H
