@@ -1,14 +1,12 @@
 /***************************************************************************
 
-  file.c
+  gb_file.c
 
-  The file management routines
-
-  (c) 2000-2005 Benot Minisini <gambas@users.sourceforge.net>
+  (c) 2000-2017 Benoît Minisini <benoit.minisini@gambas-basic.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -18,8 +16,14 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
+#include "gb_common.h"
+#include "gb_error.h"
+#include "gb_alloc.h"
+#include "gb_str.h"
+
 #include "gb_file_temp.h"
