@@ -84,7 +84,8 @@ char *STR_copy_len(const char *str, int len)
   char *cpy;
 
   ALLOC(&cpy, len  + 1);
-  memcpy(cpy, str, len + 1);
+  memcpy(cpy, str, len);
+	cpy[len] = 0;
   return cpy;
 }
 
