@@ -42,19 +42,20 @@
 #include "gb_file.h"
 #include "gb_array.h"
 #include "gb_common_buffer.h"
-
+#include "gbc_project.h"
 #include "gbc_archive.h"
 
 #if HAVE_GETOPT_LONG
 static struct option Long_options[] =
 {
-	{ "version", 0, NULL, 'V' },
-	{ "help", 0, NULL, 'h' },
-	{ "swap", 0, NULL, 's' },
-	{ "verbose", 0, NULL, 'v' },
-	{ "output", 1, NULL, 'o' },
 	{ "extract", 1, NULL, 'x' },
-	{ "ignore-public", 0, NULL, 'p'},
+	{ "help", 0, NULL, 'h' },
+	{ "ignore-public", 0, NULL, 'p' },
+	{ "list", 1, NULL, 'l' },
+	{ "output", 1, NULL, 'o' },
+	{ "verbose", 0, NULL, 'v' },
+	{ "version", 0, NULL, 'V' },
+	{ "swap", 0, NULL, 's' },
 	{ 0 }
 };
 #endif
@@ -76,6 +77,8 @@ static char *_archive;
 
 static bool _ignore_public = FALSE;
 
+static char **_ignore_paths = NULL;
+
 static void print_version()
 {
 	#ifdef TRUNK_VERSION
@@ -91,6 +94,98 @@ static void print_title()
 	print_version();
 }
 
+static void add_ignore_path_len(const char *path, int len)
+{
+	//fprintf(stderr, "add_ignore_path_len: %.*s\n", len, path);
+	if (!_ignore_paths)
+		ARRAY_create(&_ignore_paths);
+	*((char **)ARRAY_add(&_ignore_paths)) = STR_copy_len(path, len);
+}
+
+static void add_ignore_path_recursive(const char *path, int len)
+{
+	int nfile;
+	struct dirent **filelist = NULL;
+	char *dir;
+	int i;
+	char *name;
+	
+	if (len <= 5 || strncmp(path, ".src/", 5))
+	{
+		add_ignore_path_len(path, len);
+		return;
+	}
+	
+	dir = STR_copy_len(path, len);
+	
+	nfile = scandir(dir, &filelist, NULL, alphasort);
+	
+	if (nfile < 0)
+	{
+		ERROR_warning("cannot scan directory: %.*s", len, path);
+	}
+	else
+	{
+		for (i = 0; i < nfile; i++)
+		{
+			name = filelist[i]->d_name;
+			
+			if (strcmp(name, ".") == 0 || strcmp(name, "..") == 0)
+				continue;
+			
+			path = FILE_cat(dir, name, NULL);
+			
+			if (FILE_is_dir(path))
+			{
+				add_ignore_path_recursive(path, strlen(path));
+			}
+			else
+			{
+				if (strcmp(FILE_get_ext(path), "class") == 0)
+				{
+					name = STR_upper(FILE_get_basename(path));
+					path = FILE_cat(".gambas", name, NULL);
+					
+					add_ignore_path_len(path, strlen(path));
+					
+					STR_free(name);
+				}
+			}
+		}
+		
+		for (i = 0; i < nfile; i++)
+			free(filelist[i]);
+		free(filelist);
+	}
+	
+	STR_free(dir);
+}
+
+static bool add_ignore_paths_from_project(const char *key, int len_key, const char *value, int len_value)
+{
+	if (!PROJECT_is_key(key, len_key, "IgnoreFiles"))
+		return FALSE;
+	
+	PROJECT_browse_string_list(value, len_value, add_ignore_path_recursive);
+	return TRUE;
+}
+
+static bool must_ignore_path(const char *path)
+{
+	int i;
+
+	if (!_ignore_paths || !path || !*path)
+		return FALSE;
+
+	for (i = 0; i < ARRAY_count(_ignore_paths); i++)
+	{
+		if (!strcmp(_ignore_paths[i], path))
+			return TRUE;
+	}
+
+	return FALSE;
+}
+
 static void get_arguments(int argc, char **argv)
 {
 	int opt;
@@ -101,9 +196,9 @@ static void get_arguments(int argc, char **argv)
 	for(;;)
 	{
 		#if HAVE_GETOPT_LONG
-			opt = getopt_long(argc, argv, "vVLhso:x:l:p", Long_options, &index);
+			opt = getopt_long(argc, argv, "vVLhso:x:l:pi:", Long_options, &index);
 		#else
-			opt = getopt(argc, argv, "vVLhso:x:l:p");
+			opt = getopt(argc, argv, "vVLhso:x:l:pi:");
 		#endif
 
 		if (opt < 0) break;
@@ -139,13 +234,13 @@ static void get_arguments(int argc, char **argv)
 			case 'p':
 				_ignore_public = TRUE;
 				break;
-				
+
 			case 'L':
 				print_version();
 				printf(COPYRIGHT);
 				exit(0);
 
-			case 'h': case '?':
+			case 'h': case '?': case ':':
 				print_title();
 				printf(
 					"\nCreate a standalone one-file executable from a Gambas project.\n"
@@ -158,30 +253,30 @@ static void get_arguments(int argc, char **argv)
 					#if HAVE_GETOPT_LONG
 					"\n\n"
 					"  -h  --help                 display this help\n"
+					"  -l  --list=ARCHIVE         list archive files\n"
 					"  -L  --license              display license\n"
 					"  -o  --output=ARCHIVE       archive path [<project directory>/<project name>.gambas]\n"
+					"  -p  --ignore-public        exclude the '.public' directory\n"
 					"  -s  --swap                 swap endianness\n"
 					"  -v  --verbose              verbose output\n"
 					"  -V  --version              display version\n"
 					"  -x  --extract=ARCHIVE      extract a specific file from the archive\n"
-					"  -l  --list=ARCHIVE         list archive files\n"
-					"  -p  --ignore-public        ignore '.public' directory\n"
 					#else
 					" (no long options on this system)\n\n"
 					"  -h                     display this help\n"
+					"  -l=ARCHIVE             list archive files\n"
 					"  -L                     display license\n"
 					"  -o=ARCHIVE             archive path [<project directory>/<project name>.gambas]\n"
+					"  -p                     exclude the '.public' directory\n"
 					"  -s                     swap endianness\n"
 					"  -v                     verbose output\n"
 					"  -V                     display version\n"
 					"  -x=ARCHIVE             extract a specific file from the archive\n"
-					"  -l=ARCHIVE             list archie files\n"
-					"  -p                     ignore '.public' directory\n"
 					#endif
 					"\n"
 					);
 
-				exit(0);
+				exit(opt != 'h');
 
 			default:
 				exit(1);
@@ -191,7 +286,7 @@ static void get_arguments(int argc, char **argv)
 
 	if (optind < (argc - 1))
 	{
-		fprintf(stderr, "gba: too many arguments.\n");
+		ERROR_warning("too many arguments");
 		exit(1);
 	}
 
@@ -199,7 +294,7 @@ static void get_arguments(int argc, char **argv)
 	{
 		if (optind == argc)
 		{
-			fprintf(stderr, "gba: not enough arguments.\n");
+			ERROR_warning("not enough arguments");
 			exit(1);
 		}
 		_extract_file = argv[optind];
@@ -217,7 +312,7 @@ static void get_arguments(int argc, char **argv)
 
 		if (!FILE_exist(ARCH_project))
 		{
-			fprintf(stderr, "gba: project file not found: %s\n", ARCH_project);
+			ERROR_warning("project file not found: %s", ARCH_project);
 			exit(1);
 		}
 	}
@@ -298,6 +393,19 @@ static int path_count(void)
 }
 
 
+static void ignore_exit(void)
+{
+	int i;
+
+	if (!_ignore_paths)
+		return;
+
+	for (i = 0; i < ARRAY_count(_ignore_paths); i++)
+		STR_free(_ignore_paths[i]);
+
+	ARRAY_delete(&_ignore_paths);
+}
+
 int main(int argc, char **argv)
 {
 	const char *path;
@@ -316,7 +424,10 @@ int main(int argc, char **argv)
 	ARCH_FIND find;
 	int i;
 
+	ERROR_init("gba" GAMBAS_VERSION_STRING ": ");
+
 	get_arguments(argc, argv);
+
 	COMMON_init();
 
 	TRY
@@ -326,7 +437,7 @@ int main(int argc, char **argv)
 			arch = ARCH_open(_archive);
 			
 			if (ARCH_find(arch, _extract_file, 0, &find))
-				fprintf(stderr, "gba: file not found in archive\n");
+				ERROR_warning("file not found in archive");
 			else
 				fwrite(&arch->addr[find.pos], sizeof(char), find.len, stdout);
 			
@@ -355,7 +466,12 @@ int main(int argc, char **argv)
 			if (FILE_exist(path)) ARCH_add_file(path);
 
 			path = FILE_cat(FILE_get_dir(ARCH_project), ".project", NULL);
-			if (FILE_exist(path)) ARCH_add_file(path);
+			if (FILE_exist(path)) 
+			{
+				ARCH_add_file(path);
+				PROJECT_load(path);
+				PROJECT_browse(add_ignore_paths_from_project);
+			}
 
 			path = FILE_cat(FILE_get_dir(ARCH_project), ".environment", NULL);
 			if (FILE_exist(path)) ARCH_add_file(path);
@@ -369,7 +485,7 @@ int main(int argc, char **argv)
 				
 				if (chdir(path) != 0)
 				{
-					fprintf(stderr, "gba: warning: cannot change to directory: %s\n", path);
+					ERROR_warning("warning: cannot change to directory: %s", path);
 					goto _NEXT_PATH;
 				}
 
@@ -378,7 +494,7 @@ int main(int argc, char **argv)
 
 				if (nfile < 0)
 				{
-					fprintf(stderr, "gba: warning: cannot scan directory: %s\n", path);
+					ERROR_warning("warning: cannot scan directory: %s", path);
 					goto _NEXT_PATH;
 				}
 				
@@ -391,6 +507,9 @@ int main(int argc, char **argv)
 
 					file = FILE_cat(path, file_name, NULL);
 
+					if (must_ignore_path(&file[len_prefix + 1]))
+						continue;
+
 					if (*file_name == '.')
 					{
 						// hidden files are allowed only on the root of the project
@@ -434,7 +553,7 @@ int main(int argc, char **argv)
 
 					if (stat(file_name, &info))
 					{
-						fprintf(stderr, "gba: warning: cannot stat file: %s\n", file);
+						ERROR_warning("warning: cannot stat file: %s", file);
 						continue;
 					}
 
@@ -476,27 +595,31 @@ int main(int argc, char **argv)
 
 						ARCH_add_file(file);
 					}
-					
-					free(dirent);
 				}
 
 	_NEXT_PATH:
+	
 				if (filelist != NULL) 
+				{
+					for (i = 0; i < nfile; i++)
+						free(filelist[i]);
 					free(filelist);
+				}
 					
 				FREE((char **)&path);
 			}
 
 			path_exit();
-
+			ignore_exit();
 			ARCH_exit();
+			PROJECT_exit();
 			/*MEM_check();*/
 		}
 	}
 	CATCH
 	{
 		fflush(NULL);
-		fprintf(stderr, "gba: ERROR: ");
+		fprintf(stderr, "gba" GAMBAS_VERSION_STRING ": error: ");
 		ERROR_print();
 		exit(1);
 	}
