@@ -71,6 +71,9 @@ static bool main_compile_all = FALSE;
 static bool main_trans = FALSE;
 static bool main_warnings = FALSE;
 static bool main_swap = FALSE;
+static bool main_quiet = FALSE;
+
+static bool _opt_output_desc = FALSE;
 
 static bool _opt_no_old_read_syntax = FALSE;
 static bool _opt_check_prefix = FALSE;
@@ -92,6 +95,8 @@ static struct option _long_options[] =
 	{ "all", 0, NULL, 'a' },
 	{ "translate-errors", 0, NULL, 'e' },
 	{ "warnings", 0, NULL, 'w' },
+	{ "quiet", 0, NULL, 'q' },
+	{ "output-desc", 0, NULL, 'd'},
 	
 	{ "jobs", 1, NULL, 'j' },
 	{ "root", 1, NULL, 'r' },
@@ -99,10 +104,7 @@ static struct option _long_options[] =
 	{ "default-namespace", 1, NULL, 'n' },
 	{ "form", 1, NULL, 'F' },
 
-	//{ "no-old-read-write-syntax", 0, &_opt_no_old_read_syntax, 1 },
-	//{ "check-prefix", 0, &_opt_check_prefix, 1},
-	
-	{ 0 }
+	{ NULL }
 };
 #endif
 
@@ -150,9 +152,9 @@ static void get_arguments(int argc, char **argv)
 	for(;;)
 	{
 		#if HAVE_GETOPT_LONG
-			opt = getopt_long(argc, argv, "gxvaVhj:Lwtser:f:n:F:b:", _long_options, &index);
+			opt = getopt_long(argc, argv, "gxvaVhj:Lwtser:f:n:F:b:qd", _long_options, &index);
 		#else
-			opt = getopt(argc, argv, "gxvaVhj:Lwtser:f:n:F:b:");
+			opt = getopt(argc, argv, "gxvaVhj:Lwtser:f:n:F:b:qd");
 		#endif
 		if (opt < 0) break;
 
@@ -192,6 +194,11 @@ static void get_arguments(int argc, char **argv)
 				
 				main_warnings = TRUE;
 				break;
+				
+			case 'q':
+				
+				main_quiet = TRUE;
+				break;
 
 			case 's':
 				
@@ -206,6 +213,7 @@ static void get_arguments(int argc, char **argv)
 				break;
 
 			case 'b':
+				
 				if (COMP_bytecode)
 					ERROR_fail("option '-b' already specified.");
 				if (strcmp(optarg, "3.8") && strcmp(optarg, "3.15") && strcmp(optarg, "3.18") && strcmp(optarg, "3.19") && strcmp(optarg,"last"))
@@ -224,7 +232,12 @@ static void get_arguments(int argc, char **argv)
 				printf(COPYRIGHT);
 				exit(0);
 
-			case 'h': case '?':
+			case 'd':
+				
+				_opt_output_desc = TRUE;
+				break;
+
+			case 'h': case '?': case ':':
 				
 				print_title();
 				
@@ -238,6 +251,7 @@ static void get_arguments(int argc, char **argv)
 					"\n\n"
 					"  -a --all                              compile all files\n"
 					"  -b --bytecode-version                 force a specific bytecode version\n"
+					"  -d --output-desc                      output class description files for the IDE\n"
 					"  -e --translate-errors                 display translatable error messages\n"
 					"  -F --form <form file>                 convert a form file into code and print it\n"
 					"  -g --debug                            add debugging information\n"
@@ -245,6 +259,7 @@ static void get_arguments(int argc, char **argv)
 					"  -j --jobs <count>                     number of background jobs (default: %d)\n"
 					"  -L --license                          display license\n"
 					"  -n --default-namespace <namespace>    default namespace for exported classes\n"
+					"  -q --quiet                            do not print anything if compilation succeeds\n"
 					"  -r --root <directory>                 gives the gambas installation directory\n"
 					"  -s --swap                             swap endianness\n"
 					"  -t --translate                        output translation files and compile them if needed\n"
@@ -260,6 +275,7 @@ static void get_arguments(int argc, char **argv)
 					" (no long options on this system)\n\n"
 					"  -a                   compile all files\n"
 					"  -b                   force a specific bytecode version\n"
+					"  -d                   output class description files for the IDE\n"
 					"  -e                   display translatable error messages\n"
 					"  -F <form file>       convert a form file into code and print it\n"
 					"  -g                   add debugging information\n"
@@ -267,6 +283,7 @@ static void get_arguments(int argc, char **argv)
 					"  -j <count>           number of background jobs (default: %d)\n"
 					"  -L                   display license\n"
 					"  -n <namespace>       default namespace for exported classes\n"
+					"  -q                   do not print anything if compilation succeeds\n"
 					"  -r <directory>       gives the gambas installation directory\n"
 					"  -s                   swap endianness\n"
 					"  -t                   output translation files and compile them if needed\n"
@@ -282,7 +299,7 @@ static void get_arguments(int argc, char **argv)
 					"\n",
 					SYSTEM_get_cpu_count());
 
-				exit(0);
+				exit(opt != 'h');
 				
 			case 'j':
 				
@@ -319,7 +336,7 @@ static void get_arguments(int argc, char **argv)
 					ERROR_fail("option '-F' already specified.");
 				_convert_form = STR_copy(optarg);
 				break;
-
+				
 			default:
 				exit(1);
 
@@ -385,6 +402,7 @@ static void compile_file(const char *file)
 	JOB->swap = main_swap;
 	JOB->public_module = _opt_public_module;
 	JOB->no_old_read_syntax = _opt_no_old_read_syntax;
+	JOB->output_desc = _opt_output_desc;
 	//JOB->class_file = main_class_file;
 
 	if (COMP_verbose)
@@ -446,6 +464,9 @@ static void compile_file(const char *file)
 	JOB->step = JOB_STEP_OUTPUT;
 	OUTPUT_do(main_swap);
 	
+	if (_opt_output_desc)
+		OUTPUT_desc();
+	
 	lock = COMPILE_lock_file(".gbc.lock");
 	CLASS_export();
 	COMPILE_unlock_file(lock);
@@ -800,6 +821,7 @@ int main(int argc, char **argv)
 {
 	int i;
 
+	ERROR_init("gbc" GAMBAS_VERSION_STRING ": ");
 	MEMORY_init();
 	COMMON_init();
 
@@ -855,7 +877,8 @@ int main(int argc, char **argv)
 			COMPILE_exit(_ntask_max == 1);
 			FILE_exit();
 
-			puts("OK");
+			if (!main_quiet)
+				puts("OK");
 		}
 	}
 	CATCH
