@@ -57,6 +57,7 @@ void CLASS_create(CLASS **result)
 	ARRAY_create(&class->array);
 	ARRAY_create(&class->structure);
 	ARRAY_create(&class->names);
+	ARRAY_create_inc(&class->calls, 256);
 
 	TABLE_create_inc(&class->table, sizeof(CLASS_SYMBOL), TF_IGNORE_CASE, 1024);
 	TABLE_create_inc(&class->string, sizeof(SYMBOL), TF_NORMAL, 1024);
@@ -159,6 +160,7 @@ void CLASS_delete(CLASS **class)
 	ARRAY_delete(&((*class)->array));
 	ARRAY_delete(&((*class)->structure));
 	ARRAY_delete(&((*class)->names));
+	ARRAY_delete(&((*class)->calls));
 
 	if ((*class)->name) STR_free((*class)->name);
 	if ((*class)->export_name) STR_free((*class)->export_name);
@@ -188,11 +190,11 @@ CLASS_SYMBOL *CLASS_declare(CLASS *class, int index, int type, bool global)
 		name = SYMBOL_get_name(&sym->symbol);
 		if (global)
 			COMPILE_print(MSG_WARNING, -1, "class name hidden by global declaration: &1", name);
-		else
+		else if (!JOB->func->no_code)
 			COMPILE_print(MSG_WARNING, -1, "class name hidden by local declaration: &1", name);
 	}
 
-	if (!global && !TYPE_is_null(sym->global.type))
+	if (!global && !TYPE_is_null(sym->global.type) && !JOB->func->no_code)
 	{
 		name = SYMBOL_get_name(&sym->symbol);
 
@@ -270,6 +272,7 @@ int CLASS_add_function(CLASS *class, TRANS_FUNC *decl)
 	CLASS_SYMBOL *sym;
 	PARAM *param;
 	int count;
+	int save_line;
 
 	count = ARRAY_count(class->function);
 	if (count >= MAX_CLASS_FUNCTION)
@@ -325,6 +328,9 @@ int CLASS_add_function(CLASS *class, TRANS_FUNC *decl)
 	func->fast = decl->fast;
 	func->unsafe = decl->unsafe;
 	
+	save_line = JOB->line;
+	JOB->line = func->line;
+	
 	// Function startup
 
 	CODE_begin_function(func);
@@ -353,6 +359,8 @@ int CLASS_add_function(CLASS *class, TRANS_FUNC *decl)
 	if (func->npmin < 0)
 		func->npmin = func->nparam;
 	
+	JOB->line = save_line;
+	
 	return count;
 }
 
@@ -1075,3 +1083,16 @@ char *CLASS_get_export_name(CLASS *class)
 	
 	return class->name;
 }
+
+
+void CLASS_add_call_real(CLASS *class, TYPE type, int index)
+{
+	CLASS_CALL *call;
+	
+	call = ARRAY_add_void(&class->calls);
+	
+	call->type = type;
+	call->index = index;
+	call->line = JOB->line;
+	call->func = JOB->func;
+}
