@@ -2,7 +2,7 @@
 
   gbc_form.c
 
-  (c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
+  (c) 2000-2017 Benoît Minisini <benoit.minisini@gambas-basic.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -107,12 +107,12 @@ static void print_var(const char *before, const char *word, int len, const char
 {
 	FORM_print(before);
 	if (!word)
-		FORM_print("Me");
+		FORM_print_len("Me", 2);
 	else
 	{
-		FORM_print("{");
+		FORM_print_char('{');
 		FORM_print_len(word, len);
-		FORM_print("}");
+		FORM_print_char('}');
 	}
 	FORM_print(after);
 }
@@ -523,7 +523,10 @@ void FORM_do(char *source, bool convert, bool ctrl_public)
 			/*get_current(&word, &len_word);*/
 			/*FORM_print("  %.*s", len_word, word);*/
 			FORM_print_indent();
-			FORM_print("\t.");
+			FORM_print_len("\t.", 2);
+			// Fix incorrect use of unsigned color constants by the IDE form editor
+			if (line[len - 1] == '&')
+				len--;
 			FORM_print_len(line, len);
 			FORM_print("\n");
 		}
