@@ -399,7 +399,7 @@ static void output_class(void)
 
 static void output_desc(void)
 {
-	int i, n, nn = 0;
+	int i, n;
 	CLASS_SYMBOL *csym;
 	TYPE type;
 	short out_type;
@@ -417,7 +417,6 @@ static void output_desc(void)
 
 		if (TYPE_is_public(type))
 		{
-			nn++;
 			/* name */
 			write_int(get_string(csym->symbol.name, csym->symbol.len));
 			/* datatype */
@@ -1202,60 +1201,37 @@ static void output_string(void)
 }
 
 
+static char *get_file(const char *dir, char *name, const char *ext)
+{
+	char *path;
+	
+	if (mkdir(dir, 0777) == 0)
+		FILE_set_owner(dir, COMP_project);
+	
+	path = STR_copy(FILE_set_ext(FILE_cat(dir, name, NULL), ext));
+	STR_free(name);
+	return path;
+}
+
+
 char *OUTPUT_get_file(const char *file)
 {
-	char *output;
-	char *p;
-	char *name;
-
-	name = STR_copy(FILE_get_name(file));
-
-	for (p = name; *p; p++)
-	{
-		if (*p == '.')
-		{
-			*p = 0;
-			break;
-		}
-
-		*p = toupper(*p);
-	}
-
-	output = ".gambas";
-	if (mkdir(output, 0777) == 0)
-		FILE_set_owner(output, COMP_project);
-
-	output = STR_copy(FILE_cat(output, name, NULL));
-
-	//STR_free(dir);
-	STR_free(name);
-
-	return output;
+	return get_file(".gambas", STR_upper(FILE_set_ext(FILE_get_name(file), NULL)), NULL);
 }
 
 
 char *OUTPUT_get_trans_file(const char *file)
 {
-	char *output;
-	//char *dir;
-	char *name;
-
-	//dir = STR_copy(FILE_get_dir(file));
-	name = STR_copy(FILE_get_name(file));
-
-	output = ".lang"; //(char *)FILE_cat(dir, ".lang", NULL);
-	if (mkdir(output, 0777) == 0)
-		FILE_set_owner(output, COMP_project);
-
-	output = (char *)FILE_cat(".lang", name, NULL);
-	output = STR_copy(FILE_set_ext(output, "pot"));
-
-	//STR_free(dir);
-	STR_free(name);
-
-	return output;
+	return get_file(".lang", STR_copy(FILE_get_name(file)), "pot");
 }
 
+
+char *OUTPUT_get_calls_file(const char *file)
+{
+	return get_file(".desc", STR_upper(FILE_set_ext(FILE_get_name(file), NULL)), "calls");
+}
+
+
 static void output_translation(void)
 {
 	FILE *file;
@@ -1433,3 +1409,68 @@ void OUTPUT_do(bool swap)
 	// Translations
 	output_translation();
 }
+
+void OUTPUT_desc()
+{
+	CLASS *class = JOB->class;
+	CLASS_CALL *call;
+	FILE *file;
+	int i;
+	const char *name;
+	int len;
+	int value;
+	char *path;
+	
+	path = OUTPUT_get_calls_file(JOB->name);
+	
+	file = fopen(path, "w");
+	if (!file)
+		THROW("Cannot create file: &1", path);
+	
+	for (i = 0; i < ARRAY_count(class->calls); i++)
+	{
+		call = &class->calls[i];
+		
+		fputc('[', file);
+		
+		value = TYPE_get_value(call->type);
+		switch(value)
+		{
+			case TV_NONE:
+				fputc('?', file);
+				break;
+			case TV_ME:
+				fputs(JOB->class->name, file);
+				break;
+			case TV_SUPER:
+				fprintf(file, "SUPER");
+				break;
+			default:
+				name = get_symbol_name(class->table, class->class[value].index, &len);
+				fprintf(file, "%.*s", len, name);
+		}
+		
+		if (call->index == CC_NEW)
+			fprintf(file, "._new]");
+		else if (call->index == CC_GET)
+			fprintf(file, "._get]");
+		else
+		{
+			name = get_symbol_name(class->table, call->index, &len);
+			fprintf(file, ".%.*s]", len, name);
+		}
+
+		fprintf(file, ":%d:", call->line);
+		if (call->func)
+		{
+			name = get_symbol_name(class->table, call->func->name, &len);
+			fprintf(file, "%.*s", len, name);
+		}
+		
+		fputc('\n', file);
+	}
+		
+	fclose(file);
+	
+	STR_free(path);
+}
