@@ -97,7 +97,10 @@ static void check_local(CLASS_SYMBOL *sym)
 	if (!sym->local_used)
 	{
 		if (sym->local.value < 0)
-			COMPILE_print(MSG_WARNING, sym->local.line, "unused argument: &1", SYMBOL_get_name(&sym->symbol));
+		{
+			if (!_func->no_code)
+				COMPILE_print(MSG_WARNING, sym->local.line, "unused argument: &1", SYMBOL_get_name(&sym->symbol));
+		}
 		else
 			COMPILE_print(MSG_WARNING, sym->local.line, "unused variable: &1", SYMBOL_get_name(&sym->symbol));
 	}
@@ -391,6 +394,27 @@ void TRANS_statement(void)
 }
 
 
+static bool is_void_body()
+{
+	bool is_proc = (TYPE_get_id(_func->type) == T_VOID);
+	PATTERN *look = JOB->current;
+	bool is_void = TRUE;
+	
+	for(look = JOB->current;; look++)
+	{
+		if (PATTERN_is(look[0], RS_END) && TRANS_is_end_function(is_proc, &look[1]))
+			break;
+		
+		if (PATTERN_is_newline(*look))
+			continue;
+			
+		is_void = FALSE;
+		break;
+	}
+	
+	return is_void;
+}
+
 static void translate_body()
 {
 	PATTERN *look, *save;
@@ -666,10 +690,14 @@ void TRANS_code(void)
 			continue;
 		}
 		
+		_func->no_code = is_void_body();
+		
 		create_local_from_param();
 
 		translate_body();
 
+		remove_local();
+		
 		CODE_return(2); // Return from function, ignore Gosub stack
 
 		CODE_end_function(_func);
@@ -685,7 +713,6 @@ void TRANS_code(void)
 			printf("\n");
 		}
 
-		remove_local();
 	}
 
 	CLASS_check_properties(JOB->class);
