@@ -68,7 +68,7 @@ static void _drop_type(int n)
 		ERROR_panic("Incorrect type analyze");
 }
 
-#define push_type(_type) fprintf(stderr, "push_type: %d in %s.%d\n", (_type).t.id, __func__, __LINE__), _push_type(_type)
+#define push_type(_type) fprintf(stderr, "push_type: %d (%d) in %s.%d\n", (_type).t.id, (_type).t.value, __func__, __LINE__), _push_type(_type)
 #define push_type_id(_id) fprintf(stderr, "push_type_id: %d in %s.%d\n", (_id), __func__, __LINE__), _push_type(TYPE_make_simple(_id))
 #define pop_type() (fprintf(stderr, "pop_type: in %s.%d\n", __func__, __LINE__),(_type[--_type_level]))
 #define drop_type(_n) fprintf(stderr, "drop_type: %d in %s.%d\n", (_n), __func__, __LINE__),_drop_type(_n)
@@ -101,6 +101,10 @@ static void drop_type(int n)
 
 #endif
 
+#define push_type_object(_value) push_type(TYPE_make(T_OBJECT, _value, 0))
+#define push_type_class(_value) push_type(TYPE_make(T_CLASS, _value, 0))
+
+
 static short get_nparam(PATTERN *tree, int count, int *pindex)
 {
 	PATTERN pattern;
@@ -259,8 +263,9 @@ bool TRANS_string(PATTERN pattern)
 
 static void trans_class(int index)
 {
-	CODE_push_class(TRANS_get_class(index));
-	push_type_id(T_OBJECT);
+	index = TRANS_get_class(index);
+	CODE_push_class(index);
+	push_type_class(index);
 }
 
 static void trans_identifier(int index, bool point, PATTERN next)
@@ -285,7 +290,7 @@ static void trans_identifier(int index, bool point, PATTERN next)
 		{
 			TRANS_LABEL *info = TRANS_get_label_info(sym->local.value);
 			if (info->ctrl_id)
-				THROW("Label is not top-level");
+				THROW("Label must be top-level");
 
 			CODE_push_number(sym->local.value + 1);
 			push_type_id(T_INTEGER);
@@ -384,11 +389,14 @@ static void trans_identifier(int index, bool point, PATTERN next)
 			else
 				push_type(JOB->class->dyn[sym->global.value].type);
 		}
+		
+		CLASS_add_call(JOB->class, TYPE_make(T_OBJECT, TV_ME, 0), index);
 	}
 	else
 	{
 		if (point)
 		{
+			CLASS_add_call(JOB->class, get_type(0, 1), index);
 			CODE_push_unknown(CLASS_add_unknown(JOB->class, index));
 			push_type_id(T_VOID);
 		}
@@ -578,8 +586,7 @@ static void trans_operation(short op, short nparam, PATTERN previous)
 		case OP_PT:
 			if (nparam == 0)
 			{
-				TRANS_use_with();
-				type = T_OBJECT;
+				ftype = TRANS_use_with();
 			}
 			else if (!PATTERN_is_identifier(previous))
 				THROW(E_SYNTAX);
@@ -588,6 +595,7 @@ static void trans_operation(short op, short nparam, PATTERN previous)
 				switch(get_type_id(0, nparam))
 				{
 					case T_OBJECT:
+					case T_CLASS:
 					case T_VARIANT:
 					case T_STRUCT:
 					case T_STRING:
@@ -608,6 +616,7 @@ static void trans_operation(short op, short nparam, PATTERN previous)
 
 		case OP_LSQR:
 			CODE_push_array(nparam);
+			CLASS_add_call(JOB->class, get_type(0, nparam), CC_GET);
 			break;
 
 		case OP_RSQR:
@@ -759,7 +768,7 @@ static void trans_expr_from_tree(TRANS_TREE *tree, int count)
 		else if (PATTERN_is(pattern, RS_NULL))
 		{
 			CODE_push_null();
-			push_type_id(T_OBJECT);
+			push_type_id(T_NULL);
 		}
 		else if (PATTERN_is(pattern, RS_ME))
 		{
@@ -767,7 +776,7 @@ static void trans_expr_from_tree(TRANS_TREE *tree, int count)
 				THROW("ME cannot be used in a static function");*/
 
 			CODE_push_me(FALSE);
-			push_type_id(T_OBJECT);
+			push_type_object(TV_ME);
 		}
 		else if (PATTERN_is(pattern, RS_SUPER))
 		{
@@ -775,7 +784,7 @@ static void trans_expr_from_tree(TRANS_TREE *tree, int count)
 				THROW("ME cannot be used in a static function");*/
 
 			CODE_push_super(FALSE);
-			push_type_id(T_OBJECT);
+			push_type_object(TV_SUPER);
 		}
 		else if (PATTERN_is(pattern, RS_LAST))
 		{
@@ -862,6 +871,8 @@ void TRANS_new(void)
 
 		CODE_push_class(index);
 		nparam = 1;
+		
+		CLASS_add_call(JOB->class, TYPE_make(T_OBJECT, index, 0), CC_NEW);
 	}
 	else if (PATTERN_is_type(*JOB->current))
 	{
@@ -869,8 +880,11 @@ void TRANS_new(void)
 			THROW("Cannot instantiate native types");
 
 		//CODE_push_number(RES_get_type(PATTERN_index(*JOB->current)));
-		CODE_push_class(CLASS_get_array_class(JOB->class, RES_get_type(PATTERN_index(*JOB->current)), -1));
+		index = CLASS_get_array_class(JOB->class, RES_get_type(PATTERN_index(*JOB->current)), -1);
+		CODE_push_class(index);
 		nparam = 1;
+
+		CLASS_add_call(JOB->class, TYPE_make(T_OBJECT, index, 0), CC_NEW);
 	}
 	else if (PATTERN_is(*JOB->current, RS_LBRA))
 	{
