@@ -335,7 +335,7 @@ const void *const GAMBAS_DebugApi[] =
 	(void *)DEBUG_enum_keys,
 	(void *)CLASS_get_next_sorted_symbol,
 	(void *)DEBUG_get_object_access_type,
-	(void *)DEBUG_find_class,
+	(void *)DEBUG_look_class,
 	(void *)CARRAY_get_array_bounds,
 	(void *)GB_DebugBreakOnError,
 	(void *)DEBUG_enter_eval,
