@@ -68,6 +68,7 @@ typedef
 #ifndef __ARCHIVE_C
 EXTERN ARCHIVE *ARCHIVE_main;
 EXTERN char *ARCHIVE_path;
+EXTERN ARCHIVE *ARCHIVE_list;
 #endif
 
 void ARCHIVE_init(void);
@@ -100,4 +101,6 @@ bool ARCHIVE_check_addr(const char *addr);
 
 void ARCHIVE_browse(ARCHIVE *arch, void (*found)(const char *path, int64_t size));
 
+void ARCHIVE_before_fork(ARCHIVE *arch);
+
 #endif
