@@ -83,6 +83,8 @@ CLASS *CARRAY_get_array_class(CLASS *class, CTYPE ctype);
 int *CARRAY_get_array_bounds(CARRAY *_object);
 void CARRAY_resize(CARRAY *_object, int size);
 
+bool CARRAY_equals(CARRAY *a, CARRAY *b);
+
 CARRAY *CARRAY_create_static(CLASS *class, void *ref, CLASS_ARRAY *desc, void *data);
 int CARRAY_get_static_count(CLASS_ARRAY *desc);
 size_t CARRAY_get_static_size(CLASS *class, CLASS_ARRAY *desc);
@@ -122,13 +124,13 @@ void CARRAY_release_static(CLASS *class, CLASS_ARRAY *desc, void *data);
 ({ \
 	CARRAY *__object = (CARRAY *)(_object); \
 	if (__object->read_only) \
-		THROW(E_SARRAY); \
+		THROW(E_READONLY); \
 })
 
 
 #endif  // #ifndef __GBX_CLASS_INFO_C 
 
-#define ARRAY_TEMPLATE_NDESC 28
+#define ARRAY_TEMPLATE_NDESC 29
 #define ARRAY_OF_STRUCT_TEMPLATE_NDESC 15
 
 #endif
