@@ -64,14 +64,18 @@ static bool check_null(const void *object)
 
 BEGIN_METHOD(Components_get, GB_STRING name)
 
-	const char *name = GB_ToZeroString(ARG(name));
-	COMPONENT *comp;
-
-	comp = COMPONENT_find(name);
+	COMPONENT *comp = COMPONENT_find(GB_ToZeroString(ARG(name)));
 	GB_ReturnObject(comp);
 
 END_METHOD
 
+BEGIN_METHOD(Components_Exist, GB_STRING name)
+
+	COMPONENT *comp = COMPONENT_find(GB_ToZeroString(ARG(name)));
+	GB_ReturnBoolean(comp != NULL);
+
+END_METHOD
+
 BEGIN_PROPERTY(Components_Count)
 
 	GB_ReturnInt(COMPONENT_count);
@@ -939,6 +943,7 @@ GB_DESC NATIVE_Components[] =
 
 	GB_STATIC_METHOD("_next", "Component", Components_next, NULL),
 	GB_STATIC_METHOD("_get", "Component", Components_get, "(Name)s"),
+	GB_STATIC_METHOD("Exist", "b", Components_Exist, "(Name)s"),
 	GB_STATIC_PROPERTY_READ("Count", "i", Components_Count),
 
 	GB_END_DECLARE
@@ -953,6 +958,7 @@ GB_DESC NATIVE_Component[] =
 	GB_STATIC_METHOD("Load", "Component", Component_Load, "(Name)s"),
 	GB_STATIC_METHOD("IsLoaded", "b", Component_IsLoaded, "(Name)s"),
 	GB_STATIC_METHOD("FindFromPath", "s", Component_FindFromPath, "(Path)s"),
+	
 	GB_STATIC_PROPERTY_READ("Path", "s", Component_Path),
 
 	GB_PROPERTY_READ("Name", "s", Component_Name),
