@@ -31,13 +31,16 @@
 #include "gb_error.h"
 
 #include "gbx_variant.h"
+#include "gbx_exec.h"
 #include "gambas.h"
 #include "gbx_api.h"
 #include "gbx_class.h"
 #include "gbx_object.h"
-
+#include "gbx_compare.h"
+#include "gbx_c_array.h"
 #include "gbx_c_collection.h"
 
+#define check_not_read_only(_object) ((((CCOLLECTION *)_object)->read_only) ? CARRAY_static_array(), TRUE : FALSE)
 
 static void clear(CCOLLECTION *col)
 {
@@ -63,7 +66,19 @@ static void clear(CCOLLECTION *col)
 
 #define get_key(_col, _key, _len, _set_last) HASH_TABLE_lookup((_col)->hash_table, (_key), (_len), _set_last)
 
-#define add_key(_col, _key, _len) ((_len) == 0 ? (GB_Error((char *)E_VKEY), NULL) : HASH_TABLE_insert(((CCOLLECTION *)(_col))->hash_table, (_key), (_len)))
+static inline void *add_key(CCOLLECTION *col, const char *key, int len)
+{
+	if (len == 0)
+	{
+		GB_Error((char *)E_VKEY);
+		return NULL;
+	}
+	
+	if (check_not_read_only(col))
+		return NULL;
+	
+	return HASH_TABLE_insert(col->hash_table, key, len);
+}
 
 static void remove_key(CCOLLECTION *col, const char *key, int len)
 {
@@ -77,6 +92,9 @@ static void remove_key(CCOLLECTION *col, const char *key, int len)
 		GB_Error((char *)E_VKEY);
 		return;
 	}
+	
+	if (check_not_read_only(col))
+		return;
 
 	save = col->hash_table->last;
 	
@@ -109,6 +127,44 @@ static void remove_key(CCOLLECTION *col, const char *key, int len)
 }
 
 
+bool CCOLLECTION_equals(CCOLLECTION *a, CCOLLECTION *b)
+{
+	HASH_ENUM iter;
+	char *key;
+	int len;
+	VARIANT *value;
+	VARIANT *other_value;
+	
+	if (CCOLLECTION_get_count(a) != CCOLLECTION_get_count(b))
+		return FALSE;
+	
+	if (!COMPARE_equals_variant((VARIANT *)&a->default_value, (VARIANT *)&b->default_value))
+		return FALSE;
+	
+	CLEAR(&iter);
+
+	for(;;)
+	{
+		value = HASH_TABLE_next(a->hash_table, &iter, TRUE);
+		if (!value)
+			break;
+
+		HASH_TABLE_get_last_key(a->hash_table, &key, &len);
+		
+		other_value = HASH_TABLE_lookup(b->hash_table, key, len, FALSE);
+		if (!other_value)
+			return FALSE;
+		
+		if (!COMPARE_equals_variant(value, other_value))
+			return FALSE;
+	}
+	
+	return TRUE;
+}
+
+
+//-------------------------------------------------------------------------
+
 BEGIN_METHOD(Collection_new, GB_INTEGER mode)
 
 	int mode = MISSING(mode) ? 0 : VARG(mode);
@@ -191,6 +247,9 @@ BEGIN_METHOD_VOID(Collection_Clear)
 
 	int mode = THIS->hash_table->mode;
 
+	if (check_not_read_only(THIS))
+		return;
+
 	/* Stops all iterators */
 	GB_StopAllEnum(THIS);
 
@@ -303,12 +362,15 @@ BEGIN_PROPERTY(Collection_Default)
 		GB_ReturnVariant(&THIS->default_value);
 	else
 	{
+		if (check_not_read_only(THIS))
+			return;
 		GB_StoreVariant(PROP(GB_VARIANT), POINTER(&THIS->default_value));
 		THIS->has_default = THIS->default_value.type != GB_T_NULL;
 	}
 
 END_PROPERTY
 
+
 static void return_node_key(HASH_TABLE *hash_table, HASH_NODE *node)
 {
 	char *key;
@@ -328,12 +390,69 @@ BEGIN_PROPERTY(Collection_First)
 
 END_PROPERTY
 
+
 BEGIN_PROPERTY(Collection_Last)
 
 	return_node_key(THIS->hash_table, THIS->hash_table->slast);
 
 END_PROPERTY
 
+
+BEGIN_PROPERTY(Collection_ReadOnly)
+
+	if (READ_PROPERTY)
+		GB_ReturnBoolean(THIS->read_only);
+	else
+	{
+		bool read_only = VPROP(GB_BOOLEAN);
+		if (THIS->read_only == !!read_only)
+			return;
+		
+		if (THIS->read_only)
+			CARRAY_static_array();
+		else
+			THIS->read_only = TRUE;
+	}
+
+END_PROPERTY
+
+
+BEGIN_METHOD(Collection_Equals, GB_OBJECT collection)
+
+	CCOLLECTION *other = (CCOLLECTION *)VARG(collection);
+	
+	if (GB_CheckObject(other))
+		return;
+	
+	GB_ReturnBoolean(CCOLLECTION_equals(THIS, other));
+	
+END_METHOD
+
+static CCOLLECTION *_insert_col;
+
+static void insert_one(const char *key, int len, GB_VALUE *value)
+{
+	void *data;
+
+	data = add_key(_insert_col, key, len);
+	if (!data)
+		return;
+
+	GB_StoreVariant(&value->_variant, data);
+}
+
+BEGIN_METHOD(Collection_Insert, GB_OBJECT collection)
+
+	GB_COLLECTION other = (GB_COLLECTION)VARG(collection);
+	
+	if (GB_CheckObject(other))
+		return;
+	
+	_insert_col = THIS;
+	GB_CollectionBrowse(other, insert_one);
+
+END_METHOD
+
 #endif
 
 
@@ -352,6 +471,7 @@ GB_DESC NATIVE_Collection[] =
 	GB_PROPERTY("Key", "s", Collection_Key),
 	GB_PROPERTY("Default", "v", Collection_Default),
 	GB_PROPERTY_READ("Keys", "String[]", Collection_Keys),
+	GB_PROPERTY("ReadOnly", "b", Collection_ReadOnly),
 
 	GB_METHOD("Add", NULL, Collection_Add, "(Value)v(Key)s"),
 	GB_METHOD("Exist", "b", Collection_Exist, "(Key)s"),
@@ -362,6 +482,8 @@ GB_DESC NATIVE_Collection[] =
 	GB_METHOD("_get", "v", Collection_get, "(Key)s"),
 	GB_METHOD("_put", NULL, Collection_put, "(Value)v(Key)s"),
 	GB_METHOD("Copy", "Collection", Collection_Copy, NULL),
+	GB_METHOD("Equals", "b", Collection_Equals, "(Collection)Collection;"),
+	GB_METHOD("Insert", NULL, Collection_Insert, "(Collection)Collection;"),
 
 	GB_END_DECLARE
 };
@@ -456,4 +578,23 @@ bool GB_CollectionEnum(GB_COLLECTION col, GB_COLLECTION_ITER *iter, GB_VARIANT *
 	return FALSE;
 }
 
+void GB_CollectionBrowse(GB_COLLECTION col, GB_COLLECTION_BROWSE_CALLBACK func)
+{
+	GB_COLLECTION_ITER iter;
+	GB_VALUE value;
+	char *key;
+	int len;
+	
+	GB_CollectionEnum(col, &iter, NULL, NULL, NULL);
+	for(;;)
+	{
+		if (GB_CollectionEnum(col, &iter, (GB_VARIANT *)&value, &key, &len))
+			break;
+		
+		BORROW((VALUE *)&value);
+		(*func)(key, len, &value);
+		RELEASE((VALUE *)&value);
+	}
+}
+
 #endif
