@@ -773,20 +773,47 @@ BEGIN_METHOD(File_IsHidden, GB_STRING path)
 
 END_METHOD
 
-BEGIN_METHOD(File_RealPath, GB_STRING path)
+BEGIN_METHOD(File_RealPath, GB_STRING path; GB_BOOLEAN parent)
 
 	char *path = STRING_conv_file_name(STRING(path), LENGTH(path));
-	char *rpath = NULL;
 	
-	if (!FILE_is_relative(path))
+	if (FILE_is_absolute(path))
 	{
-		rpath = realpath(path, NULL);
-		path = rpath;
+		char *rpath = realpath(path, NULL);
+		GB_ReturnNewZeroString(rpath);
+		free(rpath);
 	}
+	else if (VARGOPT(parent, FALSE))
+	{
+		if (path[0] == '.' && path[1] == '/')
+		{
+			if (path[2] == 'g' && path[3] == 'b' && path[4] == '.')
+			{
+				GB_ReturnNewZeroString(path);
+			}
+			else
+			{
+				int lpath = strlen(path);
+				char *rpath = STRING_new(NULL, lpath + 1);
+				rpath[0] = '.';
+				memcpy(&rpath[1], path, lpath);
+				GB_ReturnNewString(rpath, lpath + 1);
+				STRING_free(&rpath);
+			}
+		}
+		else if (path[0])
+		{
+			const char *rpath = FILE_cat("..", path, NULL);
+			GB_ReturnNewString(rpath, FILE_buffer_length());
+		}
+		else
+		{
+			GB_ReturnVoidString();
+		}
+	}
+	else
+		GB_ReturnNewZeroString(path);
 	
-	GB_ReturnNewZeroString(path);
-	if (rpath) free(rpath);
-
 END_METHOD
 
 BEGIN_PROPERTY(File_DefaultDirAuth)
@@ -815,7 +842,7 @@ END_PROPERTY
 
 BEGIN_PROPERTY(Stream_ByteOrder)
 
-	bool endian = EXEC_big_endian;
+	bool endian = FLAG.big_endian;
 
 	if (READ_PROPERTY)
 	{
@@ -1213,7 +1240,7 @@ GB_DESC FileDesc[] =
 	GB_STATIC_METHOD("Load", "s", File_Load, "(FileName)s"),
 	GB_STATIC_METHOD("Save", NULL, File_Save, "(FileName)s(Data)s"),
 
-	GB_STATIC_METHOD("RealPath", "s", File_RealPath, "(Path)s"),
+	GB_STATIC_METHOD("RealPath", "s", File_RealPath, "(Path)s[(Parent)b]"),
 
 	GB_STATIC_PROPERTY("DefaultDirAuth", "s", File_DefaultDirAuth),
 
