@@ -118,8 +118,7 @@ typedef
 		unsigned _reserved : 2;
 		uchar n_local;
 		uchar n_ctrl;
-		uchar n_label; // Number of label for indirect jumps
-		uchar _reserved2;
+		short n_label; // Number of label for indirect jumps
 		short stack_usage;
 		short error;
 		unsigned short *code;
@@ -330,6 +329,7 @@ typedef
 
 		unsigned new_method : 1;          //          if there is a special method to call when creating a new instance
 		unsigned ready_method : 1;        //          if there is a ready method to call
+		unsigned is_collection : 1;       //          if the class inherits Collection
 		unsigned _reserved2 : 30;         //  80 128
 
 		short special[16];                // 112 160  special functions index (_new, _free, ...)
@@ -444,6 +444,7 @@ EXTERN CLASS *CLASS_PointerArray;
 #define CLASS_is_struct(_class) ((_class)->is_struct)
 #define CLASS_is_array(_class) ((_class)->is_array)
 #define CLASS_is_array_of_struct(_class) ((_class)->is_array_of_struct)
+#define CLASS_is_collection(_class) ((_class)->is_collection)
 
 #define FUNCTION_is_static(func) ((func)->type & TF_STATIC)
 //#define FUNCTION_is_native(_desc) (((uintptr_t)(_desc)->exec >> 16) != 0)
