@@ -259,8 +259,8 @@ static GB_DESC NATIVE_GambasLanguage[] =
 
 	GB_METHOD("Access", "b", NULL, "(Path)s[(Mode)i]"),
 
-	GB_METHOD("Dir", "String[]", NULL, "(Path)s[(Pattern)s(Filter)i]"),
-	GB_METHOD("RDir", "String[]", NULL, "(Path)s[(Pattern)s(Filter)i(FollowLink)b]"),
+	GB_METHOD("Dir", "String[]", NULL, "(Path)s[(Pattern)s(Options)i]"),
+	GB_METHOD("RDir", "String[]", NULL, "(Path)s[(Pattern)s(Options)i(FollowLink)b]"),
 	
 	GB_METHOD("DFree", "l", NULL, "(Path)s"),
 
