@@ -289,29 +289,16 @@ static int get_current_year(void)
 
 void DATE_from_time(time_t time, int usec, VALUE *val)
 {
-	static struct tm tm;
-	static time_t last_time = (time_t)-1;
-
-	DATE_SERIAL date;
-
-	if (time != last_time)
-	{
-		localtime_r(&time, &tm);
-		last_time = time;
-	}
-
-	date.year = tm.tm_year + 1900;
-	date.month = tm.tm_mon + 1;
-	date.day = tm.tm_mday;
-	date.hour = tm.tm_hour;
-	date.min = tm.tm_min;
-	date.sec = tm.tm_sec;
-	date.msec = usec / 1000;
-
-	if (DATE_make(&date, val))
-		VALUE_default(val, T_DATE);
+	val->type = T_DATE;
+	val->_date.date = time / 86400 + DATE_UNIX_EPOCH;
+	val->_date.time = (time % 86400) * 1000 + usec / 1000;
 }
 
+void DATE_to_time(VALUE *val, time_t *time, int *usec)
+{
+	*time = (val->_date.date - DATE_UNIX_EPOCH) * 86400 + val->_date.time / 1000;
+	*usec = (val->_date.time % 1000) * 1000;
+}
 
 void DATE_now(VALUE *val)
 {
@@ -773,31 +760,31 @@ void DATE_add(VALUE *date, int period, int val)
 
 	switch(period)
 	{
-		case DP_MILLISECOND:
+		case GB_DP_MILLISECOND:
 			add_date = val / 86400000;
 			add_time = val % 86400000 ;
 			goto __ADD_DATE_TIME;
 
-		case DP_SECOND:
+		case GB_DP_SECOND:
 			add_date = val / 86400;
 			add_time = (val % 86400) * 1000;
 			goto __ADD_DATE_TIME;
 
-		case DP_MINUTE:
+		case GB_DP_MINUTE:
 			add_date = val / 1440;
 			add_time = (val % 1440) * 60000;
 			goto __ADD_DATE_TIME;
 
-		case DP_HOUR:
+		case GB_DP_HOUR:
 			add_date = val / 24;
 			add_time = (val % 24) * 3600000;
 			goto __ADD_DATE_TIME;
 
-		case DP_DAY:
+		case GB_DP_DAY:
 			add_date = val;
 			goto __ADD_DATE_TIME;
 
-		case DP_WEEK:
+		case GB_DP_WEEK:
 			add_date = val * 7;
 			goto __ADD_DATE_TIME;
 
@@ -809,7 +796,7 @@ void DATE_add(VALUE *date, int period, int val)
 
 	switch(period)
 	{
-		case DP_WEEKDAY:
+		case GB_DP_WEEKDAY:
 			add_date = (val / 5) * 7;
 			ds.weekday += val % 5;
 			if (ds.weekday > 5)
@@ -819,11 +806,11 @@ void DATE_add(VALUE *date, int period, int val)
 			add_date += val % 5;
 			goto __ADD_DATE_TIME;
 
-		case DP_QUARTER:
+		case GB_DP_QUARTER:
 			val *= 3;
 			/* continue; */
 
-		case DP_MONTH:
+		case GB_DP_MONTH:
 			y = ((ds.year * 12) + (ds.month - 1) + val) / 12;
 			m = ((ds.month - 1) + val) % 12;
 			if (m < 0) m += 12;
@@ -835,7 +822,7 @@ void DATE_add(VALUE *date, int period, int val)
 			ds.year = y;
 			goto __MAKE_DATE;
 
-		case DP_YEAR:
+		case GB_DP_YEAR:
 			ds.year += val;
 			if (ds.month == 2 && ds.day == 29)
 			{
@@ -892,8 +879,8 @@ int DATE_diff(VALUE *date1, VALUE *date2, int period)
 
 	switch (period)
 	{
-		case DP_DAY:
-		case DP_WEEK:
+		case GB_DP_DAY:
+		case GB_DP_WEEK:
 			diff = date1->_date.date - date2->_date.date;
 			if (diff)
 			{
@@ -903,22 +890,22 @@ int DATE_diff(VALUE *date1, VALUE *date2, int period)
 			}
 			break;
 
-		case DP_MILLISECOND:
-		case DP_SECOND:
-		case DP_MINUTE:
-		case DP_HOUR:
+		case GB_DP_MILLISECOND:
+		case GB_DP_SECOND:
+		case GB_DP_MINUTE:
+		case GB_DP_HOUR:
 			diff = date1->_date.date - date2->_date.date;
 			diff = diff * 86400000 + (date1->_date.time - date2->_date.time);
 			break;
 
-		case DP_MONTH:
-		case DP_QUARTER:
-		case DP_YEAR:
+		case GB_DP_MONTH:
+		case GB_DP_QUARTER:
+		case GB_DP_YEAR:
 			ds1 = *DATE_split(date1);
 			ds2 = *DATE_split(date2);
 			break;
 
-		case DP_WEEKDAY:
+		case GB_DP_WEEKDAY:
 			diff = date1->_date.date - date2->_date.date;
 			if (diff)
 			{
@@ -936,26 +923,26 @@ int DATE_diff(VALUE *date1, VALUE *date2, int period)
 
 	switch (period)
 	{
-		case DP_DAY:
+		case GB_DP_DAY:
 			break;
 
-		case DP_WEEK:
+		case GB_DP_WEEK:
 			diff /= 7;
 			break;
 
-		case DP_SECOND:
+		case GB_DP_SECOND:
 			diff /= 1000;
 			break;
 
-		case DP_MINUTE:
+		case GB_DP_MINUTE:
 			diff /= 60000;
 			break;
 
-		case DP_HOUR:
+		case GB_DP_HOUR:
 			diff /= 3600000;
 			break;
 
-		case DP_WEEKDAY:
+		case GB_DP_WEEKDAY:
 
 			neg = (diff < 0);
 			if (neg)
@@ -984,19 +971,19 @@ int DATE_diff(VALUE *date1, VALUE *date2, int period)
 
 			break;
 
-		case DP_MONTH:
+		case GB_DP_MONTH:
 			diff = (ds1.year - ds2.year) * 12 + ds1.month - ds2.month;
 			break;
 
-		case DP_QUARTER:
+		case GB_DP_QUARTER:
 			diff = (ds1.year - ds2.year) * 4 + (ds1.month - ds2.month) / 3;
 			break;
 
-		case DP_YEAR:
+		case GB_DP_YEAR:
 			diff = ds1.year - ds2.year;
 			break;
 
-		case DP_MILLISECOND:
+		case GB_DP_MILLISECOND:
 			break;
 	}
 
