@@ -55,19 +55,6 @@ typedef
 
 #endif
 
-enum {
-	DP_MILLISECOND = 1,
-  DP_SECOND = 2,
-  DP_MINUTE = 3,
-  DP_HOUR = 4,
-  DP_DAY = 5,
-  DP_WEEK = 6,
-  DP_WEEKDAY = 7,
-  DP_MONTH = 8,
-  DP_QUARTER = 9,
-  DP_YEAR = 10,
-  };
-
 #ifndef GBX_INFO
 
 #define DATE_YEAR_MIN  -4801
@@ -75,11 +62,13 @@ enum {
 
 #define DATE_NDAY_BC 1753350
 
+#define DATE_UNIX_EPOCH 2472692
+
 #define DATE_SERIAL_has_no_date(_date) ((_date)->year == 0)
 #define DATE_SERIAL_has_no_time(_date) ((_date)->hour == 0 && (_date)->min == 0 && (_date)->sec == 0 && (_date)->msec == 0)
 
 #define DATE_void_value(_value) ((_value)->type = T_DATE, (_value)->_date.time = (_value)->_date.date = 0)
-
+	
 void DATE_init(void);
 void DATE_init_local(void);
 int DATE_get_timezone(void);
@@ -91,6 +80,7 @@ bool DATE_make_local(DATE_SERIAL *date, VALUE *val, bool local);
 #define DATE_make(_date, _value) DATE_make_local(_date, _value, TRUE)
 
 void DATE_from_time(time_t time, int usec, VALUE *val);
+void DATE_to_time(VALUE *val, time_t *time, int *usec);
 void DATE_now(VALUE *val);
 
 int DATE_to_string(char *buffer, VALUE *value);
