@@ -606,7 +606,7 @@ GB_ARRAY DEBUG_get_string_array_from_backtrace(STACK_BACKTRACE *bt)
 	return array;
 }
 
-GB_CLASS DEBUG_find_class(const char *comp_name, const char *class_name)
+GB_CLASS DEBUG_look_class(const char *comp_name, const char *class_name)
 {
 	CLASS *class;
 	COMPONENT *save_comp;
@@ -627,7 +627,7 @@ GB_CLASS DEBUG_find_class(const char *comp_name, const char *class_name)
 	if (PROJECT_class && !strcmp(name, PROJECT_class->name))
 		return (GB_CLASS)PROJECT_class;*/
 
-	class = CLASS_find(class_name);
+	class = CLASS_look(class_name, strlen(class_name));
 
 	if (comp_name)
 		COMPONENT_current = save_comp;
