@@ -179,7 +179,7 @@ void EVENT_exit()
 }
 
 
-static void post(void (*func)(), int nparam, intptr_t param, intptr_t param2)
+static void post(EVENT_FUNC func, int nparam, intptr_t param, intptr_t param2)
 {
 	EVENT_POST *ep;
 
@@ -199,18 +199,21 @@ static void post(void (*func)(), int nparam, intptr_t param, intptr_t param2)
 }
 
 
-void EVENT_post(void (*func)(), intptr_t param)
+void EVENT_post(void *func, intptr_t param)
 {
-	post(func, 1, param, 0);
+	post((EVENT_FUNC)(EVENT_FUNC_1)func, 1, param, 0);
 }
 
-void EVENT_post2(void (*func)(), intptr_t param, intptr_t param2)
+void EVENT_post2(void *func, intptr_t param, intptr_t param2)
 {
-	post(func, 2, param, param2);
+	post((EVENT_FUNC)(EVENT_FUNC_2)func, 2, param, param2);
 }
 
-static void post_event(void *object, int event)
+static void post_event(intptr_t arg1, intptr_t arg2)
 {
+	void *object = (void *)arg1;
+	int event = (int)arg2;
+	
 	GB_Raise(object, event, 0);
 	OBJECT_UNREF(object);
 }
@@ -218,7 +221,7 @@ static void post_event(void *object, int event)
 void EVENT_post_event(void *object, int event)
 {
 	OBJECT_REF(object);
-	post((void (*)())post_event, 2, (intptr_t)object, (intptr_t)event);
+	post((EVENT_FUNC)post_event, 2, (intptr_t)object, (intptr_t)event);
 }
 
 
@@ -244,9 +247,9 @@ bool EVENT_check_post(void)
 		FREE(&ep);
 
 		if (save.nparam == 1)
-			(*save.func)(save.param);
+			(*save.func.args_1)(save.param);
 		else
-			(*save.func)(save.param, save.param2);
+			(*save.func.args_2)(save.param, save.param2);
 	}
 
 	/*norec = FALSE;*/
