@@ -38,8 +38,6 @@
 
 #include "gbx_c_enum.h"
 
-enum { GB_LITTLE_ENDIAN, GB_BIG_ENDIAN };
-
 typedef
 	void (*EXEC_FUNC)();
 
@@ -52,13 +50,14 @@ typedef
 typedef
 	struct {
 		unsigned debug : 1;            // running in debugging mode
-		unsigned got_error : 1;        // if a native function has returned an error
+		unsigned debug_wait : 1;       // if we initialize debugging mode at first breakpoint
+		unsigned trace : 1;            // tracing mode
 		unsigned debug_inside : 1;     // debug inside components
 		unsigned debug_hold : 1;       // hold execution at program end
+		unsigned got_error : 1;        // if a native function has returned an error
 		unsigned task : 1;             // I am a background task
 		unsigned profile : 1;          // profiling mode
 		unsigned profile_instr : 1;    // profiling mode at instruction level
-		unsigned trace : 1;            // tracing mode
 		unsigned arch : 1;             // executing an archive
 		unsigned fifo : 1;             // debugging through a fifo
 		unsigned keep_library : 1;     // do not unload libraries
@@ -124,28 +123,6 @@ extern VALUE RET;
 
 extern VALUE *EXEC_super;
 
-/*
-extern bool EXEC_debug;
-extern bool EXEC_got_error;
-extern bool EXEC_debug_inside;
-extern bool EXEC_debug_hold;
-extern bool EXEC_task;
-extern bool EXEC_profile;
-extern bool EXEC_trace;
-extern bool EXEC_profile_instr;
-extern bool EXEC_arch;
-extern bool EXEC_fifo;
-extern bool EXEC_keep_library;
-extern bool EXEC_break_on_error;
-extern bool EXEC_in_event_loop;
-#if DO_NOT_CHECK_OVERFLOW
-#else
-extern bool EXEC_check_overflow;
-#endif
-extern bool EXEC_big_endian;
-extern bool EXEC_main_hook_done;
-*/
-
 extern const char *EXEC_fifo_name;
 extern const char *EXEC_profile_path;
 
@@ -166,23 +143,6 @@ extern const void *EXEC_subr_table[];
 
 #endif
 
-#define EXEC_debug FLAG.debug
-#define EXEC_got_error FLAG.got_error
-#define EXEC_debug_inside FLAG.debug_inside
-#define EXEC_profile FLAG.profile
-#define EXEC_fifo FLAG.fifo
-#define EXEC_arch FLAG.arch
-#define EXEC_profile_instr FLAG.profile_instr
-#define EXEC_trace FLAG.trace
-#define EXEC_big_endian FLAG.big_endian
-#define EXEC_break_on_error FLAG.break_on_error
-#define EXEC_debug_hold FLAG.debug_hold
-#define EXEC_task FLAG.task
-#define EXEC_keep_library FLAG.keep_library
-#define EXEC_main_hook_done FLAG.main_hook_done
-#define EXEC_check_overflow FLAG.check_overflow
-
-
 // Local variables base pointer
 #define BP EXEC_current.bp
 // Arguments base pointer
