@@ -2034,7 +2034,7 @@ _ADD_QUICK:
 
 	__AQ_LONG:
 
-		if (__builtin_saddl_overflow(val->_long.value, (int64_t)ind, &val->_long.value))
+		if (__builtin_sadd64_overflow(val->_long.value, (int64_t)ind, &val->_long.value))
 			THROW_OVERFLOW();
 		goto *jump_end;
 
@@ -2353,7 +2353,7 @@ _END_TRY:
 	#endif
 
 	// If EP was reset to null, then an error occurred
-	EXEC_got_error = (EP == NULL);
+	FLAG.got_error = (EP == NULL);
 	EP = NULL;
 	EC = ET;
 	ET = NULL;
@@ -2384,7 +2384,7 @@ _CATCH:
 
 _BREAK:
 
-	if (!EXEC_trace && !EXEC_debug)
+	if (!FLAG.trace && !FLAG.debug && !FLAG.debug_wait)
 	{
 		/*static int n = 0;
 		fprintf(stderr, "[%d], break: %p / %p\n", n++, pc, EXEC_current.pc);*/
@@ -3414,7 +3414,7 @@ __LONG:
 
 __LONG_NC:
 
-	if (__builtin_saddl_overflow(P1->_long.value, P2->_long.value, &P1->_long.value))
+	if (__builtin_sadd64_overflow(P1->_long.value, P2->_long.value, &P1->_long.value))
 		THROW_OVERFLOW();
 	SP--;
 	return;
@@ -3574,7 +3574,7 @@ __LONG:
 
 __LONG_NC:
 
-	if (__builtin_ssubl_overflow(P1->_long.value, P2->_long.value, &P1->_long.value))
+	if (__builtin_ssub64_overflow(P1->_long.value, P2->_long.value, &P1->_long.value))
 		THROW_OVERFLOW();
 	SP--;
 	return;
@@ -3733,7 +3733,7 @@ __LONG:
 
 __LONG_NC:
 
-	if (__builtin_smull_overflow(P1->_long.value, P2->_long.value, &P1->_long.value))
+	if (__builtin_smul64_overflow(P1->_long.value, P2->_long.value, &P1->_long.value))
 		THROW_OVERFLOW();
 	SP--;
 	return;
@@ -4757,7 +4757,9 @@ void EXEC_quit(ushort code)
 			break;
 
 		case 1: // STOP
-			if (EXEC_debug && CP) // && CP->component == COMPONENT_main)
+			if (FLAG.debug_wait)
+				DEBUG_breakpoint(1); // initialize debugging
+			if (FLAG.debug && CP) // && CP->component == COMPONENT_main)
 				DEBUG.Breakpoint(0);
 			break;
 
