@@ -194,7 +194,7 @@ _PUSH_GENERIC:
 			{
 				if (defined)
 				{
-					if (!CP->not_3_18 && TYPE_is_pure_object(val->type) && !VALUE_is_super(val) && class->is_simple && !FP->fast)
+					if (!CP->less_than_3_18 && TYPE_is_pure_object(val->type) && !VALUE_is_super(val) && class->is_simple && !FP->fast)
 						*PC = C_PUSH_VARIABLE;
 					else
 						*PC |= 2;
