@@ -469,7 +469,6 @@ static void fill_local_info(void)
 	char last;
 	uchar last_elt;
 	char *codeset;
-	const char *lang;
 	int len;
 	int last_long_date;
 
@@ -917,11 +916,13 @@ static void fill_local_info(void)
 		stradd_sep(long_time, "ss", ':');
 	}*/
 
-	// Fix the french date separator
+	#if 0
+	// Do not fix the french date separator anymore
 
 	lang = LOCAL_get_lang();
 	if (strcmp(lang, "fr") == 0 || strncmp(lang, "fr_", 3) == 0)
 		LOCAL_local.date_sep[LO_DAY] = LOCAL_local.date_sep[LO_MONTH] = '/';
+	#endif
 
 	/*stradd_sep(general_date, LOCAL_local.long_time, ' ');
 	am_pm = nl_langinfo(AM_STR);
@@ -1009,18 +1010,21 @@ void LOCAL_set_lang(const char *lang)
 	char **l;
 	int rtl;
 	char *var;
+	bool set_lang = FALSE;
 
 	if (lang && (strlen(lang) > MAX_LANG))
 		THROW_ARG();
 	
 	#ifdef DEBUG_LANG
-	fprintf(stderr, "******** LOCAL_set_lang: %s\n", lang ? lang : "(null)");
+	fprintf(stderr, "******** LOCAL_set_lang: %s / LC_ALL = %s\n", lang ? lang : "(null)", getenv("LC_ALL"));
 	#endif
 
 	if (lang && *lang)
 	{
-		my_setenv("LANG", lang, env_LANG);
 		my_setenv("LC_ALL", lang, env_LC_ALL);
+		my_setenv("LANG", lang, env_LANG);
+		my_setenv("LANGUAGE", lang, env_LANGUAGE);
+		set_lang = TRUE;
 	}
 	
 	STRING_free(&_lang);
@@ -1030,12 +1034,6 @@ void LOCAL_set_lang(const char *lang)
 	fprintf(stderr, "lang = %s\n", lang);
 	#endif
 
-	my_setenv("LANG", lang, env_LANG);
-	my_setenv("LC_ALL", lang, env_LC_ALL);
-
-	if (getenv("LANGUAGE"))
-		my_setenv("LANGUAGE", lang, env_LANGUAGE);
-	
 	if (setlocale(LC_ALL, ""))
 	{
 		_translation_loaded = FALSE;
@@ -1052,6 +1050,10 @@ void LOCAL_set_lang(const char *lang)
 	DATE_init_local();
 	fill_local_info();
 
+	if (set_lang) my_setenv("LC_ALL", lang, env_LC_ALL);
+	my_setenv("LANG", lang, env_LANG);
+	my_setenv("LANGUAGE", lang, env_LANGUAGE);
+	
 	/* If language is right to left written */
 
 	rtl = FALSE;
@@ -1123,20 +1125,20 @@ const char *LOCAL_get_format(LOCAL_INFO *info, int type)
 {
 	switch(type)
 	{
-		case LF_GENERAL_NUMBER: return "0.###############E@#";
-		case LF_SHORT_NUMBER: return "0.#######E@#";
-		case LF_FIXED: return "0.00";
-		case LF_PERCENT: return "###%";
-		case LF_SCIENTIFIC: return "0.################E+0";
-		case LF_CURRENCY: return info->general_currency;
-		case LF_INTERNATIONAL: return info->intl_currency;
-		case LF_GENERAL_DATE: return info->general_date;
-		case LF_LONG_DATE: return info->long_date;
-		case LF_MEDIUM_DATE: return info->medium_date;
-		case LF_SHORT_DATE: return info->short_date;
-		case LF_LONG_TIME: return info->long_time;
-		case LF_MEDIUM_TIME: return info->medium_time;
-		case LF_SHORT_TIME: return info->short_time;
+		case GB_LF_GENERAL_NUMBER: return "0.###############E@#";
+		case GB_LF_SHORT_NUMBER: return "0.#######E@#";
+		case GB_LF_FIXED: return "0.00";
+		case GB_LF_PERCENT: return "###%";
+		case GB_LF_SCIENTIFIC: return "0.################E+0";
+		case GB_LF_CURRENCY: return info->general_currency;
+		case GB_LF_INTERNATIONAL: return info->intl_currency;
+		case GB_LF_GENERAL_DATE: return info->general_date;
+		case GB_LF_LONG_DATE: return info->long_date;
+		case GB_LF_MEDIUM_DATE: return info->medium_date;
+		case GB_LF_SHORT_DATE: return info->short_date;
+		case GB_LF_LONG_TIME: return info->long_time;
+		case GB_LF_MEDIUM_TIME: return info->medium_time;
+		case GB_LF_SHORT_TIME: return info->short_time;
 		default: return NULL;
 	}
 }
@@ -1178,11 +1180,11 @@ bool LOCAL_format_number(double number, int fmt_type, const char *fmt, int len_f
 
 	switch(fmt_type)
 	{
-		case LF_USER:
+		case GB_LF_USER:
 			break;
 			
-		case LF_STANDARD:
-			fmt_type = LF_GENERAL_NUMBER;
+		case GB_LF_STANDARD:
+			fmt_type = GB_LF_GENERAL_NUMBER;
 			// continue
 
 		default:
@@ -1847,14 +1849,14 @@ bool LOCAL_format_date(const DATE_SERIAL *date, int fmt_type, const char *fmt, i
 
 	switch(fmt_type)
 	{
-		case LF_USER:
+		case GB_LF_USER:
 			break;
 
-		case LF_STANDARD:
+		case GB_LF_STANDARD:
 			fmt = local_current->standard_date;
 			break;
 			
-		case LF_GENERAL_DATE:
+		case GB_LF_GENERAL_DATE:
 			if (date->year == 0)
 			{
 				if (date->hour == 0 && date->min == 0 && date->sec == 0)
