@@ -75,7 +75,8 @@ typedef
 		unsigned no_read_ahead : 1;
 		unsigned null_terminated : 1;
 		unsigned check_read : 1;
-		unsigned _reserved : 2;
+		unsigned no_share : 1;
+		unsigned _reserved : 1;
 		#if __WORDSIZE == 64
 		unsigned _reserved2 : 32;
 		#endif
@@ -122,7 +123,7 @@ typedef
 typedef
 	struct {
 		STREAM_COMMON common;
-		void *addr;
+		char *addr;
 		intptr_t pos;
 		}
 	STREAM_MEMORY;
@@ -176,31 +177,12 @@ typedef
 		}
 	STREAM;
 
-/*enum {
-	STO_READ        = (1 << 0),
-	STO_WRITE       = (1 << 1),
-	STO_READ_WRITE  = STO_READ + STO_WRITE,
-	STO_MODE        = 0x3,
-	STO_APPEND      = (1 << 2),
-	STO_CREATE      = (1 << 3),
-	STO_ACCESS      = 0xF,
-	STO_DIRECT      = (1 << 4),
-	STO_LOCK        = (1 << 5),
-	STO_WATCH       = (1 << 6),
-	STO_PIPE        = (1 << 7),
-	STO_MEMORY      = (1 << 8),
-	STO_STRING      = (1 << 9),
-	STO_NULL        = (1 << 10)
-	};*/
-
 enum {
 	ST_EOL_UNIX = 0,
 	ST_EOL_WINDOWS = 1,
 	ST_EOL_MAC = 2
 	};
 
-//EXTERN int STREAM_eff_read;
-
 #ifndef __STREAM_IMPL_C
 
 EXTERN STREAM_CLASS STREAM_direct;
