@@ -714,7 +714,6 @@ char *STRING_subst(const char *str, int len, SUBST_FUNC get_param)
 	if (len <= 0)
 		len = strlen(str);
 
-	// Comment to force a commit because svn unexpectedly lost my log
 	if (len == 0)
 		return NULL;
 
@@ -1001,14 +1000,14 @@ static iconv_t my_iconv_open(const char *dst, const char *src)
 	odst = dst;
 
 	if (dst == SC_UNICODE)
-		dst = EXEC_big_endian ? "UCS-4BE" : "UCS-4LE";
+		dst = FLAG.big_endian ? "UCS-4BE" : "UCS-4LE";
 	else if (dst == SC_UTF8)
 		dst = "UTF-8";
 	else if (!dst || *dst == 0)
 		dst = "ASCII";
 
 	if (src == SC_UNICODE)
-		src = EXEC_big_endian ? "UCS-4BE" : "UCS-4LE";
+		src = FLAG.big_endian ? "UCS-4BE" : "UCS-4LE";
 	else if (src == SC_UTF8)
 		src = "UTF-8";
 	else if (!src || *src == 0)
@@ -1247,7 +1246,7 @@ int STRING_search(const char *ps, int ls, const char *pp, int lp, int is, bool r
 	{
 		char cp = *pp;
 
-		if (nocase && cp != tolower(cp))
+		if (nocase)
 		{
 			cp = tolower(cp);
 
@@ -1300,7 +1299,7 @@ int STRING_search(const char *ps, int ls, const char *pp, int lp, int is, bool r
 	pos = 0;
 	apos = 0;
 
-	if (!nocase) // || pp[0] == tolower(pp[0]))
+	if (!nocase)
 	{
 		p = memchr(right ? ps : ps + is, (uchar)pp[0], right ? ls : ls - is);
 		if (!p)
