@@ -33,50 +33,54 @@
 
 void SUBR_alloc(ushort code)
 {
-  int size;
-  int count;
-  void *ptr;
-  char *copy;
+	size_t size;
+	int count;
+	void *ptr;
+	char *copy;
 
-  SUBR_ENTER();
+	SUBR_ENTER();
 
-  if (NPARAM == 2)
-    count = SUBR_get_integer(&PARAM[1]);
-  else
-    count = 1;
-  
-  if (TYPE_is_null(PARAM->type))
-  {
-    size = 1;
-    copy = NULL;
-  }
-  if (TYPE_is_string(PARAM->type))
-  {
-    size = PARAM->_string.len + 1;
-    copy = PARAM->_string.addr + PARAM->_string.start;
-  }
-  else
-  {
-    size = SUBR_get_integer(PARAM);
-    copy = NULL;
-  }
-  
-  if (count <= 0 || size <= 0)
-    THROW(E_ARG);
-  
-  ALLOC(&ptr, size * count);
-  
-  if (copy)
-  {
-    size--;
-    memcpy(ptr, copy, size);
-    ((char *)ptr)[size] = 0;
-  }
-  
-  RETURN->type = T_POINTER;
-  RETURN->_pointer.value = ptr;
-  
-  SUBR_LEAVE();
+	if (NPARAM == 2)
+		count = SUBR_get_integer(&PARAM[1]);
+	else
+		count = 1;
+
+	if (TYPE_is_null(PARAM->type))
+	{
+	  size = 1;
+	  copy = NULL;
+	}
+	if (TYPE_is_string(PARAM->type))
+	{
+	  size = PARAM->_string.len + 1;
+	  copy = PARAM->_string.addr + PARAM->_string.start;
+	}
+	else
+	{
+	  size = SUBR_get_integer(PARAM);
+	  copy = NULL;
+	}
+
+	if (count <= 0 || size <= 0)
+	  THROW_ARG();
+
+	size *= count;
+
+	ALLOC(&ptr, size);
+	if (NPARAM == 2)
+		memset(ptr, 0, size);
+
+	if (copy)
+	{
+	  size--;
+	  memcpy(ptr, copy, size);
+	  ((char *)ptr)[size] = 0;
+	}
+
+	RETURN->type = T_POINTER;
+	RETURN->_pointer.value = ptr;
+
+	SUBR_LEAVE();
 }
 
 
@@ -87,9 +91,9 @@ void SUBR_free(void)
   SUBR_ENTER_PARAM(1);
 
   ptr = SUBR_get_pointer(PARAM);
-  
+
   IFREE(ptr);
-  
+
   SUBR_LEAVE_VOID();
 }
 
@@ -106,19 +110,19 @@ void SUBR_realloc(ushort code)
     size = SUBR_get_integer(&PARAM[2]);
   else
     size = 1;
-  
+
   count = SUBR_get_integer(&PARAM[1]);
-  
+
   if (size <= 0 || count <= 0)
-    THROW(E_ARG);
-  
+    THROW_ARG();
+
   ptr = SUBR_get_pointer(&PARAM[0]);
-  
+
   REALLOC(&ptr, size * count);
-  
+
   RETURN->type = T_POINTER;
   RETURN->_pointer.value = ptr;
-  
+
   SUBR_LEAVE();
 }
 
@@ -128,11 +132,11 @@ void SUBR_strptr(ushort code)
   char *ptr;
   ssize_t len = 0;
 	bool err;
-  
+
   SUBR_ENTER();
-  
+
   ptr = (char *)SUBR_get_pointer(PARAM);
-	
+
 	if (NPARAM == 1)
 	{
 		err = CHECK_strlen(ptr, &len);
@@ -142,19 +146,19 @@ void SUBR_strptr(ushort code)
 		len = SUBR_get_integer(&PARAM[1]);
 		err = CHECK_address(ptr, len);
 	}
-    
+
 	if (err)
 	{
 		VALUE_null(RETURN);
 	}
 	else
-	{ 
+	{
 		RETURN->type = T_CSTRING;
 		RETURN->_string.addr = ptr;
 		RETURN->_string.start = 0;
 		RETURN->_string.len = (int)len;
 	}
-	
+
   SUBR_LEAVE();
 }
 
@@ -164,11 +168,11 @@ void SUBR_varptr(ushort code)
 	void *ptr;
 	VALUE *val;
   CLASS_VAR *var;
-	
+
 	SUBR_ENTER_PARAM(1);
-	
+
 	op = (ushort)SUBR_get_integer(PARAM);
-	
+
 	if ((code & 0xFF) == 1)
 	{
 		uint64_t optargs = BP[FP->n_local + FP->n_ctrl - 1]._long.value;
@@ -214,7 +218,7 @@ void SUBR_varptr(ushort code)
 				case T_POINTER:
 					ptr = &val->_pointer.value;
 					break;
-					
+
 				case T_VARIANT:
 					ptr = &val->_variant.value.data;
 					break;
@@ -247,7 +251,7 @@ void SUBR_varptr(ushort code)
 		RETURN->type = T_POINTER;
 		RETURN->_pointer.value = ptr;
 	}
-	
+
 	SUBR_LEAVE();
 }
 
@@ -266,7 +270,7 @@ void SUBR_peek(ushort code)
 	CHECK_leave();
 
 	if (CHECK_got_error())
-		THROW(E_ARG);
+		THROW_ARG();
 
 	SUBR_LEAVE();
 }
@@ -274,19 +278,19 @@ void SUBR_peek(ushort code)
 
 void SUBR_poke(ushort code)
 {
-  void *ptr;
+	void *ptr;
 
 	SUBR_ENTER_PARAM(2);
 
-  ptr = SUBR_get_pointer_or_string(PARAM);
+	ptr = SUBR_get_pointer_or_string(PARAM);
 
 	CHECK_enter();
-  if (sigsetjmp(CHECK_jump, TRUE) == 0)
+	if (sigsetjmp(CHECK_jump, TRUE) == 0)
 		VALUE_write(&PARAM[1], ptr, code & 0xF);
 	CHECK_leave();
 
 	if (CHECK_got_error())
-		THROW(E_ARG);
+		THROW_ARG();
 
 	SUBR_LEAVE_VOID();
 }
@@ -294,20 +298,20 @@ void SUBR_poke(ushort code)
 
 void SUBR_make(ushort code)
 {
-  static void *jump[] = {
-    &&__ERROR, &&__BOOLEAN, &&__BYTE, &&__SHORT, &&__INTEGER, &&__LONG, &&__SINGLE, &&__FLOAT, 
+	static void *jump[] = {
+		&&__ERROR, &&__BOOLEAN, &&__BYTE, &&__SHORT, &&__INTEGER, &&__LONG, &&__SINGLE, &&__FLOAT,
 		&&__DATE, &&__ERROR, &&__ERROR, &&__POINTER, &&__ERROR, &&__ERROR, &&__ERROR, &&__ERROR
-    };
-		
+		};
+
 	TYPE type;
-	
+
 	SUBR_ENTER_PARAM(1);
-	
+
 	type = code & 0x3F;
 	VALUE_conv(PARAM, type);
 	STRING_new_temp_value(RETURN, NULL, TYPE_sizeof_memory(type));
 	goto *jump[type];
-	
+
 __BOOLEAN:
 
 	*(RETURN->_string.addr) = PARAM->_boolean.value != 0;
@@ -347,12 +351,12 @@ __DATE:
 
 	memcpy(RETURN->_string.addr, &PARAM->_date.date, sizeof(int) * 2);
 	goto __END;
-	
+
 __POINTER:
 
 	memcpy(RETURN->_string.addr, &PARAM->_pointer.value, sizeof(void *));
 	goto __END;
-	
+
 __ERROR:
 
 	THROW_ILLEGAL();
