@@ -55,6 +55,7 @@ static void **_default_list[3] = { &_default_in, &_default_out, &_default_err };
 static GB_ARRAY _result;
 static char *_pattern;
 static int _len_pattern;
+static bool _full_path;
 static int _ignore;
 
 static STREAM *_stream;
@@ -200,6 +201,26 @@ static char *get_path(VALUE *param)
 	return STRING_conv_file_name(name, len);
 }
 
+static void get_path_strip(VALUE *param, char **path, int *lpath)
+{
+	char *name;
+	int len;
+
+	SUBR_get_string_len(param, &name, &len);
+
+	while (len > 0 && name[len - 1] == '/')
+		len--;
+
+	*path = STRING_conv_file_name(name, len);
+	if (**path)
+	{
+		*lpath = STRING_length(*path);
+		STRING_ref(*path);
+	}
+	else
+		*lpath = 0;
+}
+
 void SUBR_open(ushort code)
 {
 	CFILE *file;
@@ -792,50 +813,83 @@ void SUBR_exist(ushort code)
 }
 
 
+static void error_subr_dir(char *path)
+{
+	if (*path) STRING_unref(&path);
+}
+
 void SUBR_dir(ushort code)
 {
 	GB_ARRAY array;
-	const char *path;
-	char *pattern;
+	char *path;
+	char *pattern = NULL;
 	int len_pattern;
 	char *str;
 	int attr = 0;
-
+	bool fullpath = FALSE;
+	int lpath;
+				
 	SUBR_ENTER();
 
-	path = get_path(PARAM);
-
 	if (NPARAM >= 2)
 	{
 		pattern = SUBR_get_string(&PARAM[1]);
 		if (NPARAM == 3)
 			attr = SUBR_get_integer(&PARAM[2]);
 	}
-	else
-		pattern = NULL;
 
-	FILE_dir_first(path, pattern, attr);
-
-	GB_ArrayNew(&array, T_STRING, 0);
-
-	while (!FILE_dir_next(&pattern, &len_pattern))
+	if (attr & GB_STAT_FULL_PATH)
 	{
-		if (!LOCAL_is_UTF8)
-		{
-			if (STRING_conv(&str, pattern, len_pattern, LOCAL_encoding, SC_UTF8, FALSE))
-				str = STRING_new(pattern, len_pattern);
-			else
-				STRING_ref(str);
-		}
-		else
-			str = STRING_new(pattern, len_pattern);
-
-		*((char **)GB_ArrayAdd(array)) = str;
+		fullpath = TRUE;
+		attr &= ~GB_STAT_FULL_PATH;
 	}
+		
+	get_path_strip(PARAM, &path, &lpath);
+	
+	ON_ERROR_1(error_subr_dir, path)
+	{
+		FILE_dir_first(path, pattern, attr);
 
-	RETURN->_object.class = OBJECT_class(array);
-	RETURN->_object.object = array;
+		GB_ArrayNew(&array, T_STRING, 0);
 
+		while (!FILE_dir_next(&pattern, &len_pattern))
+		{
+			if (!LOCAL_is_UTF8)
+			{
+				if (STRING_conv(&str, pattern, len_pattern, LOCAL_encoding, SC_UTF8, FALSE))
+					str = STRING_new(pattern, len_pattern);
+				else
+					STRING_ref(str);
+			}
+			else
+				str = STRING_new(pattern, len_pattern);
+
+			if (fullpath)
+			{
+				char *file = str;
+				int lfile = STRING_length(file);
+				
+				str = STRING_new(path, lpath);
+				
+				if (lfile && file[0] != '/')
+					str = STRING_add_char(str, '/');
+				
+				str = STRING_add(str, file, lfile);
+				
+				STRING_unref(&file);
+			}
+			
+			*((char **)GB_ArrayAdd(array)) = str;
+		}
+		
+		RETURN->_object.class = OBJECT_class(array);
+		RETURN->_object.object = array;
+	}
+	END_ERROR
+
+	if (lpath)
+		STRING_unref(&path);
+	
 	SUBR_LEAVE();
 }
 
@@ -850,6 +904,12 @@ static void found_file(const char *path)
 
 	if (_pattern && !REGEXP_match(_pattern, _len_pattern, path, len))
 		return;
+	
+	if (_full_path)
+	{
+		path -= _ignore;
+		len += _ignore;
+	}
 
 	if (!LOCAL_is_UTF8)
 	{
@@ -869,14 +929,13 @@ static void found_file(const char *path)
 
 void SUBR_rdir(ushort code)
 {
-	const char *path;
+	char *path;
+	int lpath;
 	int attr = 0;
 	bool follow = FALSE;
 
 	SUBR_ENTER();
 
-	path = get_path(PARAM);
-
 	if (NPARAM >= 2)
 	{
 		SUBR_get_string_len(&PARAM[1], &_pattern, &_len_pattern);
@@ -890,6 +949,16 @@ void SUBR_rdir(ushort code)
 	else
 		_pattern = NULL;
 
+	if (attr & GB_STAT_FULL_PATH)
+	{
+		_full_path = TRUE;
+		attr &= ~GB_STAT_FULL_PATH;
+	}
+	else
+		_full_path = FALSE;
+		
+	get_path_strip(PARAM, &path, &lpath);
+
 	_result = NULL;
 
 	if (!path || *path == 0)
@@ -898,13 +967,20 @@ void SUBR_rdir(ushort code)
 	if (_ignore > 0 && path[_ignore - 1] != '/')
 		_ignore++;
 
-	FILE_recursive_dir(path, found_file, NULL, attr, follow);
+	ON_ERROR_1(error_subr_dir, path)
+	{
+		FILE_recursive_dir(path, found_file, NULL, attr, follow);
 
-	if (!_result)
-		GB_ArrayNew(&_result, T_STRING, 0);
+		if (!_result)
+			GB_ArrayNew(&_result, T_STRING, 0);
 
-	RETURN->_object.class = OBJECT_class(_result);
-	RETURN->_object.object = _result;
+		RETURN->_object.class = OBJECT_class(_result);
+		RETURN->_object.object = _result;
+	}
+	END_ERROR
+
+	if (lpath)
+		STRING_unref(&path);
 
 	SUBR_LEAVE();
 }
