@@ -103,13 +103,19 @@ void SUBR_round(ushort code)
 	if (NPARAM == 2)
 		val = SUBR_get_integer(&PARAM[1]);
 
-	power = pow(10, val);
-
 	VALUE_conv_float(&PARAM[0]);
-
 	RETURN->type = T_FLOAT;
-	/*RETURN->_float.value = rint(PARAM->_float.value / power) * power;*/
-	RETURN->_float.value = floor(PARAM->_float.value / power + 0.5) * power;
+	
+	if (val >= 0)
+	{
+		power = pow10(val);
+		RETURN->_float.value = floor(PARAM->_float.value / power + 0.5) * power;
+	}
+	else if (val < 0)
+	{
+		power = pow10(-val);
+		RETURN->_float.value = floor(PARAM->_float.value * power + 0.5) / power;
+	}
 
 	SUBR_LEAVE();
 }
