@@ -2168,7 +2168,7 @@ __2v:
 	/* VALUE_put ne fonctionne pas avec T_STRING ! */
 	if (value->type != T_NULL)
 	{
-		value->_variant.value.data = 0; //TODO: Optimize that?
+		//value->_variant.value.data = 0; //TODO: Optimize that?
 		VALUE_put(value, &value->_variant.value, value->type);
 	}
 
