@@ -494,6 +494,12 @@ static void raise_callback()
 				(*(wcb.callback_write))(wcb.fd, GB_WATCH_WRITE, wcb.param_write);
 			}
 		}
+		
+		if (_callback[i].fd < 0)
+			continue;
+		
+		if (_poll[i].revents & (POLLHUP | POLLERR))
+			watch_delete_callback(i);
 	}
 
 	_do_not_really_delete_callback--;
