@@ -28,6 +28,7 @@
 #include "c_clipper.h"
 
 #define SCALE 1048576.0
+#define DEFAULT_CLEAN_DIST 1.414213562373095
 
 static IntPoint to_point_xy(double x, double y)
 {
@@ -44,6 +45,11 @@ static GEOM_POINTF *from_point(IntPoint p)
 	return GEOM.CreatePointF((double)p.X / SCALE, (double)p.Y / SCALE);
 }
 
+static inline int64_t int64_abs(int64_t v)
+{
+	return v >= 0 ? v : -v;
+}
+
 static bool is_polygon_closed(Path &p)
 {
 	int n = p.size() - 1;
@@ -54,6 +60,16 @@ static bool is_polygon_closed(Path &p)
 	return p[0].X == p[n].X && p[0].Y == p[n].Y;
 }
 
+static bool is_polygon_almost_closed(Path &p)
+{
+	int n = p.size() - 1;
+
+	if (n <= 1)
+		return false;
+
+	return int64_abs(p[0].X - p[n].X) <= 1 && int64_abs(p[0].Y - p[n].Y) <= 1;
+}
+
 static void set_polygon_closed(Path &p, bool closed)
 {
 	if (is_polygon_closed(p) == closed)
@@ -266,7 +282,24 @@ BEGIN_METHOD(Polygon_Clean, GB_FLOAT distance)
 
 	closed = is_polygon_closed(*POLY);
 
-	CleanPolygon(*POLY, *(result->poly), VARGOPT(distance, 1.415));
+	CleanPolygon(*POLY, *(result->poly), VARGOPT(distance, DEFAULT_CLEAN_DIST));
+
+	set_polygon_closed(*(result->poly), closed);
+
+	GB.ReturnObject(result);
+
+END_METHOD
+
+BEGIN_METHOD_VOID(Polygon_Trim)
+
+	bool closed;
+	CPOLYGON *result = (CPOLYGON *)GB.New(GB.FindClass("Polygon"), NULL, 0);
+
+	result->poly->resize(POLY->size());
+
+	closed = is_polygon_closed(*POLY);
+
+	CleanPolygon(*POLY, *(result->poly), DEFAULT_CLEAN_DIST);
 
 	set_polygon_closed(*(result->poly), closed);
 
@@ -330,6 +363,7 @@ BEGIN_METHOD(Clipper_Offset, GB_OBJECT polygons; GB_FLOAT delta; GB_INTEGER join
 
 	Paths polygons;
 	Paths result;
+	ClipperOffset co;
 
 	if (to_polygons(polygons, VARG(polygons)))
 		return;
@@ -337,7 +371,6 @@ BEGIN_METHOD(Clipper_Offset, GB_OBJECT polygons; GB_FLOAT delta; GB_INTEGER join
 	SimplifyPolygons(polygons, result, pftNonZero);
 	polygons = result;
 
-	ClipperOffset co;
 	co.AddPaths(polygons, (JoinType)VARGOPT(join, jtSquare), etClosedPolygon);
 	co.MiterLimit = VARGOPT(limit, 0.0);
 	co.Execute(result, VARG(delta) * SCALE);
@@ -349,6 +382,67 @@ BEGIN_METHOD(Clipper_Offset, GB_OBJECT polygons; GB_FLOAT delta; GB_INTEGER join
 END_METHOD
 
 
+BEGIN_METHOD(Clipper_Inflate, GB_OBJECT polygons; GB_FLOAT delta; GB_INTEGER join; GB_INTEGER cap; GB_FLOAT limit; GB_BOOLEAN outline)
+
+	Paths polygons;
+	Paths result;
+	Paths polygons_opened;
+	Paths polygons_closed;
+	uint i;
+	JoinType join;
+	EndType cap;
+	double delta;
+	double limit;
+
+	if (to_polygons(polygons, VARG(polygons)))
+		return;
+
+	/*SimplifyPolygons(polygons, result, pftNonZero);
+	polygons = result;
+	result.clear();*/
+
+	join = (JoinType)VARGOPT(join, jtSquare);
+	cap = (EndType)VARGOPT(cap, etOpenSquare);
+	delta = VARG(delta) * SCALE;
+	limit = VARGOPT(limit, 0.0);
+
+	for (i = 0; i < polygons.size(); i++)
+	{
+		if (is_polygon_almost_closed(polygons[i]))
+			polygons_closed.push_back(polygons[i]);
+		else
+			polygons_opened.push_back(polygons[i]);
+	}
+
+	if (polygons_closed.size())
+	{
+		ClipperOffset co;
+		Paths inflated;
+
+		co.AddPaths(polygons_closed, join, VARGOPT(outline, TRUE) ? cap : etClosedPolygon);
+		co.MiterLimit = limit;
+		co.Execute(inflated, delta);
+
+		result.insert(result.end(), inflated.begin(), inflated.end());
+	}
+
+	if (polygons_opened.size())
+	{
+		ClipperOffset co;
+		Paths inflated;
+
+		co.AddPaths(polygons_opened, join, cap);
+		co.MiterLimit = limit;
+		co.Execute(inflated, delta);
+
+		result.insert(result.end(), inflated.begin(), inflated.end());
+	}
+
+	GB.ReturnObject(from_polygons(result, true));
+
+END_METHOD
+
+
 BEGIN_METHOD(Clipper_Simplify, GB_OBJECT polygons; GB_INTEGER fill)
 
 	Paths polygons;
@@ -373,7 +467,23 @@ BEGIN_METHOD(Clipper_Clean, GB_OBJECT polygons; GB_FLOAT distance)
 
 	result.resize(polygons.size());
 
-	CleanPolygons(polygons, result, VARGOPT(distance, 1.415));
+	CleanPolygons(polygons, result, VARGOPT(distance, DEFAULT_CLEAN_DIST));
+
+	GB.ReturnObject(from_polygons(result, true));
+
+END_METHOD
+
+BEGIN_METHOD(Clipper_Trim, GB_OBJECT polygons)
+
+	Paths polygons;
+	Paths result;
+
+	if (to_polygons(polygons, VARG(polygons)))
+		return;
+
+	result.resize(polygons.size());
+
+	CleanPolygons(polygons, result, DEFAULT_CLEAN_DIST);
 
 	GB.ReturnObject(from_polygons(result, true));
 
@@ -446,6 +556,7 @@ GB_DESC PolygonDesc[] =
 	GB_METHOD("Reverse", NULL, Polygon_Reverse, NULL),
 	GB_METHOD("Simplify", "Polygon[]", Polygon_Simplify, "[(Fill)i]"),
 	GB_METHOD("Clean", "Polygon", Polygon_Clean, "[(Distance)f]"),
+	GB_METHOD("Trim", "Polygon", Polygon_Trim, NULL),
 
 	GB_METHOD("Add", NULL, Polygon_Add, "(X)f(Y)f"),
 	GB_METHOD("AddPoint", NULL, Polygon_AddPoint, "(Point)PointF;"),
@@ -462,6 +573,7 @@ GB_DESC ClipperDesc[] =
 
 	GB_CONSTANT("JoinMiter", "i", jtMiter),
 	GB_CONSTANT("JoinSquare", "i", jtSquare),
+	GB_CONSTANT("JoinBevel", "i", jtSquare),
 	GB_CONSTANT("JoinRound", "i", jtRound),
 
 	GB_CONSTANT("FillEvenOdd", "i", pftEvenOdd),
@@ -470,9 +582,17 @@ GB_DESC ClipperDesc[] =
 	GB_CONSTANT("FillPositive", "i", pftPositive),
 	GB_CONSTANT("FillNegative", "i", pftNegative),
 
+	GB_CONSTANT("CapSquare", "i", etOpenSquare),
+	GB_CONSTANT("CapRound", "i", etOpenRound),
+	GB_CONSTANT("CapButt", "i", etOpenButt),
+	GB_CONSTANT("CapPolygon", "i", etClosedPolygon),
+	GB_CONSTANT("CapJoined", "i", etClosedLine),
+
 	GB_STATIC_METHOD("Offset", "Polygon[]", Clipper_Offset, "(Polygons)Polygon[];(Delta)f[(Join)i(Limit)f(DoNotFix)b]"),
 	GB_STATIC_METHOD("Simplify", "Polygon[]", Clipper_Simplify, "(Polygons)Polygon[];[(Fill)i]"),
 	GB_STATIC_METHOD("Clean", "Polygon[]", Clipper_Clean, "(Polygons)Polygon[];[(Distance)f]"),
+	GB_STATIC_METHOD("Trim", "Polygon[]", Clipper_Trim, "(Polygons)Polygon[]"),
+	GB_STATIC_METHOD("Inflate", "Polygon[]", Clipper_Inflate, "(Polygons)Polygon[];(Delta)f[(Join)i(Cap)i(Limit)f(Outline)b]"),
 
 	GB_STATIC_METHOD("Union", "Polygon[]", Clipper_Union, "(Polygons)Polygon[];[(Clip)Polygon[];(Fill)i]"),
 	GB_STATIC_METHOD("Intersection", "Polygon[]", Clipper_Intersection, "(Polygons)Polygon[];[(Clip)Polygon[];(Fill)i]"),
