@@ -59,6 +59,8 @@ typedef
 		ushort line;
 		VALUE *bp;
 		FUNCTION *fp;
+		char *comp;
+		char *name;
 		}
 	DEBUG_BREAK;
 
@@ -111,6 +113,9 @@ static bool _debug = FALSE;
 #define INFO(_msg, ...) _out && fprintf(_out, "I\t" _msg "\n", ##__VA_ARGS__)
 #endif
 
+static void unset_all_breakpoints();
+
+
 static void init_eval_interface()
 {
 	static bool init = FALSE;
@@ -233,7 +238,7 @@ DEBUG_INFO *DEBUG_init(GB_DEBUG_INTERFACE *debug)
 {
 	DEBUG_interface = debug;
 
-	GB.NewArray(&_breakpoints, sizeof(DEBUG_BREAK), 16);
+	GB.NewArray(&_breakpoints, sizeof(DEBUG_BREAK), 0);
 	GB.NewArray(&_watches, sizeof(DEBUG_WATCH), 0);
 	
 	return &DEBUG_info;
@@ -295,6 +300,7 @@ void DEBUG_exit(void)
 {
 	int i;
 	
+	unset_all_breakpoints();
 	GB.FreeArray(&_breakpoints);
 	
 	if (_watches)
@@ -343,10 +349,14 @@ static bool init_breakpoint(DEBUG_BREAK *brk)
 
 	//fprintf(stderr, "init_breakpoint: id = %d\n", brk->id);
 
-	if (brk->addr || !CLASS_is_loaded(brk->class))
+	if (!brk->class)
 	{
-		WARNING("breakpoint is pending");
-		return TRUE;
+		brk->class = (CLASS *)GB_DEBUG.LookClass(brk->comp, brk->name);
+		if (!brk->class)
+		{
+			WARNING("breakpoint is pending");
+			return TRUE;
+		}
 	}
 
 	if (CLASS_is_native(brk->class) || !brk->class->debug)
@@ -391,11 +401,15 @@ static bool init_breakpoint(DEBUG_BREAK *brk)
 }
 
 
-static bool set_breakpoint(CLASS *class, ushort line)
+static bool set_breakpoint(const char *comp, const char *name, ushort line)
 {
 	DEBUG_BREAK *brk;
 	int id;
 
+	#ifdef DEBUG_ME
+	fprintf(stderr, "set_breakpoint: [%s]%s.%d\n", comp ? comp : "", name, line);
+	#endif
+
 	if (GB.Count(_breakpoints) >= MAX_BREAKPOINT)
 	{
 		WARNING("Too many breakpoints");
@@ -413,40 +427,61 @@ static bool set_breakpoint(CLASS *class, ushort line)
 
 	brk->id = id;
 	brk->addr = NULL;
-	brk->class = class;
 	brk->line = line;
-
-	#ifdef DEBUG_ME
-	fprintf(stderr, "set_breakpoint: %s.%d\n", class->name, line);
-	#endif
+	if (comp)
+		brk->comp = GB.NewZeroString(comp);
+	brk->name = GB.NewZeroString(name);
 
 	init_breakpoint(brk);
 
 	return FALSE;
 }
 
+static void free_breakpoint(DEBUG_BREAK *brk)
+{
+	if (brk->addr)
+		*(brk->addr) = PCODE_BREAKPOINT(0);
+	GB.FreeString(&brk->comp);
+	GB.FreeString(&brk->name);
+}
 
-static bool unset_breakpoint(CLASS *class, ushort line)
+static bool same_component(const char *comp1, const char *comp2)
+{
+	if (comp1 && comp2)
+		return strcmp(comp1, comp2) == 0;
+	else if (comp1 || comp2)
+		return FALSE;
+	else
+		return TRUE;
+}
+
+static bool unset_breakpoint(const char *comp, const char *name, ushort line)
 {
 	int i;
 	DEBUG_BREAK *brk;
+	
+	#ifdef DEBUG_ME
+	fprintf(stderr, "unset_breakpoint: [%s]%s.%d\n", comp ? comp : "", name, line);
+	#endif
 
 	for (i = 0; i < GB.Count(_breakpoints); i++)
 	{
 		brk = &_breakpoints[i];
-		if (brk->class == class && brk->line == line)
-		{
-			if (brk->addr)
-				*(brk->addr) = PCODE_BREAKPOINT(0);
-			GB.Remove(&_breakpoints, i, 1);
 
-			#ifdef DEBUG_ME
-			fprintf(stderr, "unset_breakpoint: %s.%d\n", class->name, line);
-			#endif
+		if (brk->line != line)
+			continue;
+		
+		if (!same_component(comp, brk->comp))
+			continue;
+		
+		if (strcmp(name, brk->name))
+			continue;
+		
+		free_breakpoint(brk);
+		GB.Remove(&_breakpoints, i, 1);
 
-			INFO("breakpoint removed");
-			return FALSE;
-		}
+		INFO("breakpoint removed");
+		return FALSE;
 	}
 
 	WARNING("Unknown breakpoint");
@@ -462,8 +497,7 @@ static void unset_all_breakpoints()
 	for (i = 0; i < GB.Count(_breakpoints); i++)
 	{
 		brk = &_breakpoints[i];
-		if (brk->addr)
-			*(brk->addr) = PCODE_BREAKPOINT(0);
+		free_breakpoint(brk);
 	}
 
 	GB.Remove(&_breakpoints, 0, GB.Count(_breakpoints));
@@ -475,18 +509,18 @@ void DEBUG_init_breakpoints(CLASS *class)
 	int i;
 	DEBUG_BREAK *brk;
 
-	#ifdef DEBUG_ME
-	fprintf(stderr, "DEBUG_init_breakpoints: %p %s\n", class, class->name);
-	#endif
+	//fprintf(stderr, "DEBUG_init_breakpoints: %s / %d\n", class->name, GB.Count(_breakpoints));
 	
 	for (i = 0; i < GB.Count(_breakpoints); i++)
 	{
 		brk = &_breakpoints[i];
-		if (brk->class == class)
-		{
-			//fprintf(stderr, "DEBUG_init_breakpoints: %s\n", class->name);
-			init_breakpoint(brk);
-		}
+		//fprintf(stderr, "%s / %s\n", brk->name, class->name);
+		if (strcmp(brk->name, class->name))
+			continue;
+		if (!same_component(brk->comp, class->component ? class->component->name : NULL))
+			continue;
+		brk->class = class;
+		init_breakpoint(brk);
 	}
 }
 
@@ -666,11 +700,15 @@ void DEBUG_set_breakpoint(bool set, char *cmd)
 	}
 
 	if (sscanf(cmd, "%256[^.].%hu", class_name, &line) != 2)
+	{
 		WARNING("Cannot %s breakpoint: syntax error", set ? "add" : "remove");
-	else if (set)
-		set_breakpoint((CLASS *)GB_DEBUG.FindClass(comp, class_name), line);
+		return;
+	}
+	
+	if (set)
+		set_breakpoint(comp, class_name, line);
 	else
-		unset_breakpoint((CLASS *)GB_DEBUG.FindClass(comp, class_name), line);
+		unset_breakpoint(comp, class_name, line);
 }
 
 static void command_breakpoint(char *cmd)
@@ -1133,7 +1171,6 @@ static void command_option(char *cmd)
 	switch(cmd[1])
 	{
 		case 'b':
-			
 			GB_DEBUG.BreakOnError(on);
 			break;
 			
