@@ -2,13 +2,11 @@
 
   main.h
 
-  The Debug component
-
-  (c) 2000-2004 Benot Minisini <gambas@freesurf.fr>
+  (c) 2000-2017 Benoît Minisini <benoit.minisini@gambas-basic.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -18,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -29,7 +28,9 @@
 #include "gb_common.h"
 
 #ifndef __MAIN_C
-extern GB_INTERFACE GB;
+extern const GB_INTERFACE *GB_PTR;
 #endif
 
+#define GB (*GB_PTR)
+
 #endif
