@@ -350,12 +350,14 @@ static void analyze(EVAL_ANALYZE *result)
 	int len, i, l;
 	bool preprocessor;
 	uint last;
+	int len_before;
 
 	_colors_len = 0;
 	EVAL_analyze_exit();
 	
 	pattern = EVAL->pattern;
 	preprocessor = FALSE;
+	len_before = 0;
 
 	if (EVAL->len <= 0)
 		return;
@@ -379,12 +381,15 @@ static void analyze(EVAL_ANALYZE *result)
 		
 		if (type == RT_SPACE)
 		{
+			len = PATTERN_index(*pattern);
+			len_before += len;
+
 			if (!EVAL->rewrite || _colors_len == 0 || PATTERN_is_end(pattern[1]) || PATTERN_is_comment(pattern[1]))
 			{
-				len = PATTERN_index(*pattern);
 				add_data(RT_SPACE, len);
 				add_result_spaces(result, len);
 			}
+
 			goto __NEXT_PATTERN;
 		}
 
@@ -522,6 +527,16 @@ static void analyze(EVAL_ANALYZE *result)
 					//space_before = FALSE;
 					space_after = FALSE;
 				}
+				else if (*symbol == '?')
+				{
+					if (EVAL->rewrite)
+					{
+						symbol = "Print";
+						len = 5;
+						type = RT_RESERVED;
+						space_after = TRUE;
+					}
+				}
 				else if (*symbol == '-' && len == 1)
 				{
 					if (old_type == RT_OPERATOR && (PATTERN_is(get_last_pattern(pattern), RS_LBRA) || PATTERN_is(get_last_pattern(pattern),RS_LSQR)))
@@ -552,6 +567,33 @@ static void analyze(EVAL_ANALYZE *result)
 
 					space_after = TRUE;
 				}
+				else if (PATTERN_is(*pattern, RS_WEBPAGE_LIMIT))
+				{
+					if (EVAL->limit)
+					{
+						add_result(result, symbol, len);
+						add_data(RT_OPERATOR, len);
+						len_before += len;
+
+						/*for(;;)
+						{
+							pattern++;
+							if (get_type(pattern) == RT_END)
+								break;
+
+							get_symbol(*pattern, &symbol, &len);
+							add_result(result, symbol, len);
+							add_data(RT_ERROR, len);
+						}*/
+
+						goto __END_PATTERN;
+					}
+					else
+					{
+						space_before = FALSE;
+						space_after = FALSE;
+					}
+				}
 				else
 				{
 					space_before = TRUE;
@@ -596,6 +638,8 @@ static void analyze(EVAL_ANALYZE *result)
 			len += 2;
 		}
 
+		len_before += len;
+
 		if (EVAL->rewrite)
 		{
 			if (type == RT_STRING)
@@ -676,9 +720,14 @@ static void analyze(EVAL_ANALYZE *result)
 		pattern++;
 	}
 
+__END_PATTERN:
+
 	flush_result(result);
 	flush_colors(result);
 
+	result->len_before = len_before;
+
+
 	//fprintf(stderr, "analyze: %d %s\n", strlen(result->str), result->str);
 }
 
@@ -702,7 +751,7 @@ static void add_end_pattern(void)
 }
 
 
-PUBLIC void EVAL_analyze(const char *src, int len, int state, EVAL_ANALYZE *result, bool rewrite)
+PUBLIC void EVAL_analyze(const char *src, int len, int state, EVAL_ANALYZE *result, bool rewrite, bool limit)
 {
 	//int nspace = 0;
 
@@ -733,6 +782,7 @@ PUBLIC void EVAL_analyze(const char *src, int len, int state, EVAL_ANALYZE *resu
 		
 		EVAL->analyze = TRUE;
 		EVAL->rewrite = rewrite;
+		EVAL->limit = limit;
 		EVAL->comment = state == RT_COMMENT;
 		
 		//fprintf(stderr, "EVAL_analyze: [%d] %.*s\n", EVAL->comment, len, src);
