@@ -1,14 +1,12 @@
 /***************************************************************************
 
-  alloc.h
+  gb_alloc_override.h
 
-  Memory management routines
-
-  (c) 2000-2007 Benoit Minisini <gambas@users.sourceforge.net>
+  (c) 2000-2017 Benoît Minisini <benoit.minisini@gambas-basic.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -18,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -27,9 +26,9 @@
 
 #include "main.h"
 
-#define ALLOC(_ptr, _len, _where) GB.Alloc((void **)(void *)_ptr, _len)
-#define FREE(_ptr, _where) GB.Free((void **)(void *)_ptr)
-#define REALLOC(_ptr, _len, _where) GB.Realloc((void **)(void *)_ptr, _len)
+#define ALLOC(_ptr, _len) GB.Alloc((void **)(void *)_ptr, _len)
+#define FREE(_ptr) GB.Free((void **)(void *)_ptr)
+#define REALLOC(_ptr, _len) GB.Realloc((void **)(void *)_ptr, _len)
 
 #endif
 
