@@ -32,7 +32,7 @@ GB_DESC *GB_CLASSES[] EXPORT =
   NULL
 };
 
-char *GB_INCLUDE EXPORT = "gb.qt4.opengl|gb.qt5.opengl|gb.gtk.opengl|gb.gtk3.opengl";
+char *GB_INCLUDE EXPORT = "gb.qt6.opengl|gb.qt4.opengl|gb.qt5.opengl|gb.gtk.opengl|gb.gtk3.opengl";
 
 int EXPORT GB_INIT(void)
 {
@@ -46,6 +46,8 @@ int EXPORT GB_INIT(void)
 			comp = "gb.qt4.opengl";
 		else if (strcmp(env, "gb.qt5") == 0)
 			comp = "gb.qt5.opengl";
+		else if (strcmp(env, "gb.qt6") == 0)
+			comp = "gb.qt6.opengl";
 		else if (strcmp(env, "gb.gtk") == 0)
 			comp = "gb.gtk.opengl";
 		else if (strcmp(env, "gb.gtk3") == 0)
