@@ -32,7 +32,7 @@ GB_DESC *GB_CLASSES[] EXPORT =
   NULL
 };
 
-char *GB_INCLUDE EXPORT = "gb.qt5.webview|gb.gtk3.webview|gb.qt4.webview";
+char *GB_INCLUDE EXPORT = "gb.qt6.webview|gb.qt5.webview|gb.gtk3.webview|gb.qt4.webview";
 
 int EXPORT GB_INIT(void)
 {
@@ -42,7 +42,9 @@ int EXPORT GB_INIT(void)
 	env = getenv("GB_GUI");
 	if (env)
 	{
-		if (strcmp(env, "gb.qt5") == 0)
+		if (strcmp(env, "gb.qt6") == 0)
+			comp = "gb.qt6.webview";
+		else if (strcmp(env, "gb.qt5") == 0)
 			comp = "gb.qt5.webview";
 		else if (strcmp(env, "gb.qt4") == 0)
 			comp = "gb.qt4.webview";
