@@ -31,7 +31,8 @@ enum
 	HASH_MD5,
 	HASH_SHA1,
 	HASH_SHA256,
-	HASH_SHA512
+	HASH_SHA512,
+	HASH_CRC32
 };
 
 #define HASH_INTERFACE_VERSION 1
