@@ -132,6 +132,13 @@ typedef
 		}
 	GB_ARRAY_IMPL;
 
+typedef
+	struct {
+		GB_CLASS class;
+		intptr_t ref;
+		}
+	OBJECT;
+
 #define SP (*psp)
 #define PC (JIT.exec->pc)
 #define CP (JIT.exec->cp)
