@@ -59,12 +59,16 @@ enum
 EXTERN char *JIT_prefix;
 EXTERN CLASS *JIT_class;
 EXTERN bool JIT_last_print_is_label;
+EXTERN void **JIT_pointers;
+EXTERN bool JIT_trace;
+EXTERN char *JIT_buffer;
 #endif
 
+#define JITPTR(_p) JIT_pointer((void *)_p)
 
 // jit.c
 
-char *JIT_translate(const char *name, const char *from);
+bool JIT_translate(const char *name, const char *from, bool trace, bool cache, char **result, char **pointers);
 
 void JIT_section(const char *str);
 
@@ -85,6 +89,8 @@ int JIT_get_code_size(FUNCTION *func);
 int JIT_find_symbol(CLASS *class, const char *name);
 void JIT_load_class_without_init(CLASS *class);
 
+const char *JIT_pointer(void *p);
+
 // jit_body.c
 
 bool JIT_translate_body(FUNCTION *func, int index);
