@@ -29,19 +29,47 @@
 GB_INTERFACE *GB_PTR EXPORT;
 JIT_INTERFACE *JIT_PTR EXPORT;
 
+static char *_translation = NULL;
+static char *_pointers = NULL;
 
-BEGIN_METHOD(Jit_Translate, GB_STRING klass; GB_STRING from)
 
-	GB.ReturnString(JIT_translate(GB.ToZeroString(ARG(klass)), GB.ToZeroString(ARG(from))));
-	
+BEGIN_METHOD(Jit_Translate, GB_STRING klass; GB_STRING from; GB_BOOLEAN trace; GB_BOOLEAN cache)
+
+	GB.FreeString(&_translation);
+	GB.FreeString(&_pointers);
+
+	GB.ReturnBoolean(JIT_translate(GB.ToZeroString(ARG(klass)), GB.ToZeroString(ARG(from)), VARG(trace), VARG(cache), &_translation, &_pointers));
+
 END_METHOD
 
+BEGIN_PROPERTY(Jit_Translation)
+
+	GB.ReturnString(_translation);
+
+END_PROPERTY
+
+BEGIN_PROPERTY(Jit_Pointers)
+
+	GB.ReturnString(_pointers);
+
+END_PROPERTY
+
+BEGIN_METHOD_VOID(Jit_exit)
+
+	GB.FreeString(&_translation);
+	GB.FreeString(&_pointers);
+
+END_METHOD
 
 GB_DESC JitDesc[] =
 {
 	GB_DECLARE_STATIC("__Jit"),
 
-	GB_STATIC_METHOD("Translate", "s", Jit_Translate, "(Class)s(From)s"),
+	GB_STATIC_METHOD("Translate", "b", Jit_Translate, "(Class)s(From)s(Trace)b(Cache)b"),
+	GB_STATIC_PROPERTY_READ("Translation", "s", Jit_Translation),
+	GB_STATIC_PROPERTY_READ("Pointers", "s", Jit_Pointers),
+
+	GB_STATIC_METHOD("_exit", NULL, Jit_exit, NULL),
 
 	GB_END_DECLARE
 };
