@@ -2,13 +2,11 @@
 
   vb.c
 
-  Visual Basic compatibility Component
-
-  (c) 2000-2007 Benoit Minisini <gambas@users.sourceforge.net>
+  (c) 2000-2017 Benoît Minisini <benoit.minisini@gambas-basic.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -18,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -27,7 +26,13 @@
 #include "vb.h"
 #include "vbdate.h"
 #include <stdio.h>
-#include <strings.h>
+
+#ifdef OS_CYGWIN
+  #include <string.h>
+#else
+  #include <strings.h>
+#endif
+
 #include <math.h>
 
 BEGIN_METHOD(CVB_val, GB_STRING str)
@@ -44,6 +49,8 @@ BEGIN_METHOD(CVB_val, GB_STRING str)
     GB.ReturnFloat(((GB_FLOAT *)(void *)&result)->value);
   else
     GB.ReturnInteger(0);
+	
+	GB.ReturnConvVariant();
 
 END_METHOD
 
