@@ -53,17 +53,18 @@
 
 #ifdef PROJECT_EXEC
 
-static DIR *file_dir = NULL;
-static char *file_pattern = NULL;
-static char *file_path = NULL;
-static bool file_dir_arch = FALSE;
-static int file_attr;
+static DIR *_file_dir = NULL;
+static char *_file_pattern = NULL;
+static char *_file_path = NULL;
+static bool _file_dir_arch = FALSE;
+static bool _file_dir_filter = FALSE;
+static uchar _file_attr;
 static bool _temp_used = FALSE;
 
 #endif
 
-static char file_buffer[PATH_MAX + 16];
-static int file_buffer_length;
+static char _file_buffer[PATH_MAX + 16];
+static int _file_buffer_length;
 
 #ifdef _DIRENT_HAVE_D_TYPE
 #undef _DIRENT_HAVE_D_TYPE
@@ -131,14 +132,14 @@ static char *pop_path(void **list)
 
 static void dir_exit(void)
 {
-	if (file_dir != NULL)
+	if (_file_dir != NULL)
 	{
-		closedir(file_dir);
-		file_dir = NULL;
+		closedir(_file_dir);
+		_file_dir = NULL;
 	}
 
-	STRING_free(&file_pattern);
-	STRING_free(&file_path);
+	STRING_free(&_file_pattern);
+	STRING_free(&_file_path);
 }
 
 
@@ -151,17 +152,17 @@ char *FILE_make_temp(int *len, const char *pattern)
 	if (len)
 	{
 		if (pattern)
-			*len = snprintf(file_buffer, sizeof(file_buffer), FILE_TEMP_PATTERN, (int)getuid(), (int)getpid(), pattern);
+			*len = snprintf(_file_buffer, sizeof(_file_buffer), FILE_TEMP_PATTERN, (int)getuid(), (int)getpid(), pattern);
 		else
 		{
 			count++;
-			*len = snprintf(file_buffer, sizeof(file_buffer), FILE_TEMP_FILE, (int)getuid(), (int)getpid(), count);
+			*len = snprintf(_file_buffer, sizeof(_file_buffer), FILE_TEMP_FILE, (int)getuid(), (int)getpid(), count);
 		}
 	}
 	else
-		snprintf(file_buffer, sizeof(file_buffer), FILE_TEMP_DIR, (int)getuid(), (int)getpid());
+		snprintf(_file_buffer, sizeof(_file_buffer), FILE_TEMP_DIR, (int)getuid(), (int)getpid());
 
-	return file_buffer;
+	return _file_buffer;
 }
 
 static void remove_temp_file(const char *path)
@@ -188,10 +189,10 @@ void FILE_remove_temp_file(void)
 
 void FILE_remove_temp_file_pid(pid_t pid)
 {
-	snprintf(file_buffer, sizeof(file_buffer), FILE_TEMP_DIR, (int)getuid(), (int)pid);
-	FILE_recursive_dir(file_buffer, NULL, remove_temp_file, 0, FALSE);
-	snprintf(file_buffer, sizeof(file_buffer), FILE_TEMP_DIR, (int)getuid(), (int)pid);
-	rmdir(file_buffer);
+	snprintf(_file_buffer, sizeof(_file_buffer), FILE_TEMP_DIR, (int)getuid(), (int)pid);
+	FILE_recursive_dir(_file_buffer, NULL, remove_temp_file, 0, FALSE);
+	snprintf(_file_buffer, sizeof(_file_buffer), FILE_TEMP_DIR, (int)getuid(), (int)pid);
+	rmdir(_file_buffer);
 }
 
 void FILE_init(void)
@@ -201,14 +202,14 @@ void FILE_init(void)
 	_temp_used = TRUE;
 	FILE_remove_temp_file();
 
-	snprintf(file_buffer, sizeof(file_buffer), FILE_TEMP_PREFIX, (int)getuid());
-	(void)mkdir(file_buffer, S_IRWXU);
+	snprintf(_file_buffer, sizeof(_file_buffer), FILE_TEMP_PREFIX, (int)getuid());
+	(void)mkdir(_file_buffer, S_IRWXU);
 
-	if (lstat(file_buffer, &info) == 0 && S_ISDIR(info.st_mode) && chown(file_buffer, getuid(), getgid()) == 0 && chmod(file_buffer, S_IRWXU) == 0)
+	if (lstat(_file_buffer, &info) == 0 && S_ISDIR(info.st_mode) && chown(_file_buffer, getuid(), getgid()) == 0 && chmod(_file_buffer, S_IRWXU) == 0)
 	{
-		snprintf(file_buffer, sizeof(file_buffer), FILE_TEMP_DIR, (int)getuid(), (int)getpid());
-		(void)mkdir(file_buffer, S_IRWXU);
-		if (lstat(file_buffer, &info) == 0 && S_ISDIR(info.st_mode) && chown(file_buffer, getuid(), getgid()) == 0 && chmod(file_buffer, S_IRWXU) == 0)
+		snprintf(_file_buffer, sizeof(_file_buffer), FILE_TEMP_DIR, (int)getuid(), (int)getpid());
+		(void)mkdir(_file_buffer, S_IRWXU);
+		if (lstat(_file_buffer, &info) == 0 && S_ISDIR(info.st_mode) && chown(_file_buffer, getuid(), getgid()) == 0 && chmod(_file_buffer, S_IRWXU) == 0)
 			return;
 	}
 
@@ -271,14 +272,14 @@ const char *FILE_cat(const char *path, ...)
 
 	va_start(args, path);
 
-	p = file_buffer;
+	p = _file_buffer;
 
-	if (path != file_buffer)
+	if (path != _file_buffer)
 		*p = 0;
 
 	for(;;)
 	{
-		if (*path == '/' && p != file_buffer)
+		if (*path == '/' && p != _file_buffer)
 			path++;
 
 		len = strlen(path);
@@ -287,7 +288,7 @@ const char *FILE_cat(const char *path, ...)
 
 		if (len > 0)
 		{
-			if ((p + len) > &file_buffer[PATH_MAX])
+			if ((p + len) > &_file_buffer[PATH_MAX])
 				THROW(E_TOOLONG);
 
 			if (p != path)
@@ -312,30 +313,30 @@ const char *FILE_cat(const char *path, ...)
 
 	va_end(args);
 
-	file_buffer_length = p - file_buffer;
-	return file_buffer;
+	_file_buffer_length = p - _file_buffer;
+	return _file_buffer;
 }
 
 
 char *FILE_buffer(void)
 {
-	return file_buffer;
+	return _file_buffer;
 }
 
 
 int FILE_buffer_length(void)
 {
-	if (file_buffer_length < 0)
-		file_buffer_length = strlen(file_buffer);
+	if (_file_buffer_length < 0)
+		_file_buffer_length = strlen(_file_buffer);
 
-	return file_buffer_length;
+	return _file_buffer_length;
 }
 
 static void init_file_buffer(const char *path)
 {
 	int len;
 
-	if (path == file_buffer)
+	if (path == _file_buffer)
 		return;
 
 	len = strlen(path);
@@ -343,11 +344,11 @@ static void init_file_buffer(const char *path)
 	if (len > PATH_MAX)
 		THROW(E_TOOLONG);
 
-	strcpy(file_buffer, path);
-	file_buffer_length = len;
+	strcpy(_file_buffer, path);
+	_file_buffer_length = len;
 }
 
-//#define INIT_FILE_BUFFER(_path) (init_file_buffer(), _path = file_buffer)
+//#define INIT_FILE_BUFFER(_path) (init_file_buffer(), _path = _file_buffer)
 
 const char *FILE_get_dir(const char *path)
 {
@@ -361,20 +362,20 @@ const char *FILE_get_dir(const char *path)
 
 	init_file_buffer(path);
 
-	p = rindex(file_buffer, '/');
+	p = rindex(_file_buffer, '/');
 
 	if (p == NULL)
-		*file_buffer = 0;
+		*_file_buffer = 0;
 	else
 	{
 		*p = 0;
 
-		if (file_buffer[0] == 0 && path[0] == '/')
-			strcpy(file_buffer, "/");
+		if (_file_buffer[0] == 0 && path[0] == '/')
+			strcpy(_file_buffer, "/");
 	}
 
-	file_buffer_length = -1;
-	return file_buffer;
+	_file_buffer_length = -1;
+	return _file_buffer;
 }
 
 
@@ -412,21 +413,21 @@ const char *FILE_set_ext(const char *path, const char *ext)
 
 	init_file_buffer(path);
 
-	p = (char *)FILE_get_ext(file_buffer);
+	p = (char *)FILE_get_ext(_file_buffer);
 
 	if (!ext)
 	{
-		if (p > file_buffer && p[-1] == '.')
+		if (p > _file_buffer && p[-1] == '.')
 			p[-1] = 0;
 		else
 			*p = 0;
-		return file_buffer;
+		return _file_buffer;
 	}
 
-	if (&p[strlen(ext)] >= &file_buffer[PATH_MAX])
+	if (&p[strlen(ext)] >= &_file_buffer[PATH_MAX])
 		THROW(E_TOOLONG);
 
-	if (p == file_buffer || p[-1] != '.')
+	if (p == _file_buffer || p[-1] != '.')
 		*p++ = '.';
 
 	if (*ext == '.')
@@ -434,8 +435,8 @@ const char *FILE_set_ext(const char *path, const char *ext)
 
 	strcpy(p, ext);
 
-	file_buffer_length = -1;
-	return file_buffer;
+	_file_buffer_length = -1;
+	return _file_buffer;
 }
 
 
@@ -447,12 +448,12 @@ const char *FILE_get_basename(const char *path)
 
 	init_file_buffer(path);
 
-	p = rindex(file_buffer, '.');
+	p = rindex(_file_buffer, '.');
 	if (p)
 		*p = 0;
 
-	file_buffer_length = -1;
-	return file_buffer;
+	_file_buffer_length = -1;
+	return _file_buffer;
 }
 
 bool FILE_is_dir(const char *path)
@@ -554,7 +555,7 @@ bool FILE_stat(const char *path, FILE_STAT *info, bool follow)
 
 char *FILE_mode_to_string(mode_t mode)
 {
-	char *str = file_buffer;
+	char *str = _file_buffer;
 
   str[0] = mode & S_IRUSR ? 'r' : '-';
   str[1] = mode & S_IWUSR ? 'w' : '-';
@@ -573,7 +574,7 @@ char *FILE_mode_to_string(mode_t mode)
             : (mode & S_IXOTH ? 'x' : '-'));
 	str[9] = 0;
 
-	file_buffer_length = 9;
+	_file_buffer_length = 9;
 
 	return str;
 }
@@ -692,10 +693,11 @@ void FILE_dir_first(const char *path, const char *pattern, int attr)
 	if (!path || *path == 0)
 		path = ".";
 
-	if (attr == (GB_STAT_FILE | GB_STAT_DIRECTORY))
-		attr = 0;
+	_file_attr = (uchar)attr;
+	
+	if (_file_attr == (GB_STAT_FILE | GB_STAT_DIRECTORY))
+		_file_attr = 0;
 
-	file_attr = attr;
 
 	if (FILE_is_relative(path))
 	{
@@ -706,18 +708,20 @@ void FILE_dir_first(const char *path, const char *pattern, int attr)
 				goto _OK;
 		}*/
 
-		file_dir_arch = TRUE;
-		ARCHIVE_dir_first(NULL, path, pattern, attr);
+		_file_dir_arch = TRUE;
+		_file_dir_filter = (ARCHIVE_dir_first(NULL, path, pattern, attr));
+			
 		return;
 	}
 
-	file_dir_arch = FALSE;
-	file_dir = opendir(path);
-	if (file_dir == NULL)
+	_file_dir_arch = FALSE;
+	_file_dir_filter = FALSE;
+	_file_dir = opendir(path);
+	if (_file_dir == NULL)
 		THROW_SYSTEM(errno, path);
 
-	file_pattern = STRING_new_zero(pattern);
-	file_path = STRING_new_zero(path);
+	_file_pattern = STRING_new_zero(pattern);
+	_file_path = STRING_new_zero(path);
 }
 
 #if OPT_FSTATAT
@@ -736,31 +740,31 @@ bool FILE_dir_next(char **path, int *len)
 	#ifndef _DIRENT_HAVE_D_TYPE
 	struct stat info;
 		#ifndef HAVE_FSTATAT
-		char *p = file_buffer;
+		char *p = _file_buffer;
 		#endif
 	#endif
 
 	//fprintf(stderr, "FILE_dir_next: %p %d %d\n", file_dir, file_dir_arch, file_attr);
 
-	if (file_dir_arch)
+	if (_file_dir_arch)
 	{
-		ret = ARCHIVE_dir_next(path, len, file_attr);
+		ret = ARCHIVE_dir_next(path, len, _file_attr);
 		if (ret)
-			file_dir_arch = FALSE;
+			_file_dir_arch = FALSE;
 		return ret;
 	}
 
-	if (file_dir == NULL)
+	if (_file_dir == NULL)
 		return TRUE;
 
 	#ifndef _DIRENT_HAVE_D_TYPE
 		#ifndef HAVE_FSTATAT
-		if (file_attr)
+		if (_file_attr)
 		{
-			init_file_buffer(file_path);
-			p += file_buffer_length;
+			init_file_buffer(_file_path);
+			p += _file_buffer_length;
 
-			if (p[-1] != '/' && (file_buffer[1] || file_buffer[0] != '/'))
+			if (p[-1] != '/' && (_file_buffer[1] || _file_buffer[0] != '/'))
 				*p++ = '/';
 		}
 		#endif
@@ -768,7 +772,7 @@ bool FILE_dir_next(char **path, int *len)
 
 	for(;;)
 	{
-		entry = readdir(file_dir);
+		entry = readdir(_file_dir);
 		if (entry == NULL)
 		{
 			//fprintf(stderr, "readdir: NULL\n");
@@ -783,34 +787,40 @@ bool FILE_dir_next(char **path, int *len)
 			continue;
 
 		len_entry = strlen(name);
-		if ((len_entry + file_buffer_length) > PATH_MAX)
+		if ((len_entry + _file_buffer_length) > PATH_MAX)
 			continue;
+		
+		if (_file_dir_filter)
+		{
+			if (name[len_entry - 1] == '~')
+				continue;
+		}
 
-		if (file_attr)
+		if (_file_attr)
 		{
 			#ifdef _DIRENT_HAVE_D_TYPE
-			if ((file_attr == GB_STAT_DIRECTORY) ^ (entry->d_type == DT_DIR))
+			if ((_file_attr == GB_STAT_DIRECTORY) ^ (entry->d_type == DT_DIR))
 				continue;
 			#else
 				#if HAVE_FSTATAT
-				if (fstatat(dirfd(file_dir), name, &info, 0))
+				if (fstatat(dirfd(_file_dir), name, &info, 0))
 				#else
 				strcpy(p, name);
-				if (stat(file_buffer, &info))
+				if (stat(_file_buffer, &info))
 				#endif
 				{
-					if (file_attr == GB_STAT_DIRECTORY)
+					if (_file_attr == GB_STAT_DIRECTORY)
 						continue;
 				}
-				else if ((file_attr == GB_STAT_DIRECTORY) ^ (S_ISDIR(info.st_mode) != 0))
+				else if ((_file_attr == GB_STAT_DIRECTORY) ^ (S_ISDIR(info.st_mode) != 0))
 					continue;
 			#endif
 		}
 
-		if (file_pattern == NULL)
+		if (_file_pattern == NULL)
 			break;
 
-		if (REGEXP_match(file_pattern, STRING_length(file_pattern), name, len_entry))
+		if (REGEXP_match(_file_pattern, STRING_length(_file_pattern), name, len_entry))
 			break;
 	}
 
@@ -857,10 +867,10 @@ void FILE_recursive_dir(const char *dir, void (*found)(const char *), void (*aft
 		file_rdir_len--;
 
 	#if OPT_NLINK
-	if (file_dir && !FILE_is_relative(dir))
+	if (_file_dir && !FILE_is_relative(dir))
 	{
 		struct stat dinfo;
-		fstat(dirfd(file_dir), &dinfo);
+		fstat(dirfd(_file_dir), &dinfo);
 		// If the number of links N to the directory:
 		// - Is > 2, then the directory has N - 2 sub-directories
 		// - Is = 2, then the directory has no sub-directory
@@ -876,11 +886,11 @@ void FILE_recursive_dir(const char *dir, void (*found)(const char *), void (*aft
 
 		if ((file_rdir_len + len + 1) > PATH_MAX)
 			THROW(E_TOOLONG);
-		memcpy(file_buffer, file_rdir_path, file_rdir_len);
-		file_buffer[file_rdir_len] = '/';
-		memcpy(&file_buffer[file_rdir_len + 1], file, len);
-		file_buffer[file_rdir_len + len + 1] = 0;
-		path = file_buffer;
+		memcpy(_file_buffer, file_rdir_path, file_rdir_len);
+		_file_buffer[file_rdir_len] = '/';
+		memcpy(&_file_buffer[file_rdir_len + 1], file, len);
+		_file_buffer[file_rdir_len + len + 1] = 0;
+		path = _file_buffer;
 
 		#if OPT_NLINK
 		if (nsubdir || follow)
@@ -991,14 +1001,14 @@ void FILE_make_path_dir(const char *path)
 
 	for (i = 1;; i++)
 	{
-		c = file_buffer[i];
+		c = _file_buffer[i];
 		if (c == 0)
 			break;
 		if (c == '/')
 		{
-			file_buffer[i] = 0;
-			(void)mkdir(file_buffer, S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
-			file_buffer[i] = c;
+			_file_buffer[i] = 0;
+			(void)mkdir(_file_buffer, S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
+			_file_buffer[i] = c;
 		}
 	}
 }
@@ -1207,28 +1217,28 @@ bool FILE_copy(const char *src, const char *dst)
 
 const char *FILE_getcwd(const char *subdir)
 {
-	if (getcwd(file_buffer, PATH_MAX) == NULL)
+	if (getcwd(_file_buffer, PATH_MAX) == NULL)
 		return NULL;
 
-	file_buffer_length = strlen(file_buffer);
+	_file_buffer_length = strlen(_file_buffer);
 
 	if (subdir != NULL)
-		return FILE_cat(file_buffer, subdir, NULL);
+		return FILE_cat(_file_buffer, subdir, NULL);
 	else
-		return file_buffer;
+		return _file_buffer;
 }
 
 
 const char *FILE_readlink(const char *link)
 {
-	int len = readlink(link, file_buffer, PATH_MAX);
+	int len = readlink(link, _file_buffer, PATH_MAX);
 
 	if (len < 0)
 		return NULL;
 
-	file_buffer[len] = 0;
-	file_buffer_length = len;
-	return file_buffer;
+	_file_buffer[len] = 0;
+	_file_buffer_length = len;
+	return _file_buffer;
 
 }
 
