@@ -2,7 +2,7 @@
 
   gb_limit.h
 
-  (c) 2000-2017 Benoît Minisini <benoit.minisini@gambas-basic.org>
+  (c) Benoît Minisini <benoit.minisini@gambas-basic.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -69,7 +69,7 @@
 /* Maximum number of local variables in a function - CANNOT CHANGE */
 #define MAX_LOCAL_SYMBOL    127
 
-/* Maximum level of control structures imbrication */
+/* Maximum level of control structures imbrication (lower than 255) */
 #define MAX_CTRL_LEVEL      32
 
 /* Maximum number of dimensions in an array */
