@@ -58,8 +58,9 @@ enum {
   T_VARIANT      = 12,
   T_ARRAY        = 13,
   T_STRUCT       = 14,
-  //T_NULL         = 15,
-  T_OBJECT       = 16
+  T_NULL         = 15,
+  T_OBJECT       = 16,
+	T_CLASS        = 17
   };
 
 #else
